<?xml version="1.0"?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:doj="http://www.doj.state.wi.us/dles/cib/ccap/response" xmlns:ccap-ext="http://www.doj.state.wi.us/dles/cib/ccap/response/extension" xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" xmlns:xalan="http://xml.apache.org/xslt" exclude-result-prefixes="xsl xsi doj j xalan">
	<xsl:import href="../util.xsl"/>
	<xsl:param name="from"/>
	<xsl:param name="imageBase">
		<xsl:text>../../images/</xsl:text>
	</xsl:param>
	<xsl:template match="doj:CCAPCaseDetailResponse">
		<h2 class="filetype">
			<xsl:text>WI CCAP Case Detail</xsl:text>
		</h2>
		<hr/>
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:InquiryResult/ccap-ext:CriminalCaseDetails|doj:InquiryResult/ccap-ext:CivilCaseDetails"/>
		<xsl:apply-templates select="doj:InquiryResult/ccap-ext:CourtRecord"/>
		<xsl:if test="doj:InquiryResult/ccap-ext:CriminalCaseDetails|ccap-ext:CivilCaseDetails/ccap-ext:CourtCaseDocument or doj:InquiryResult/ccap-ext:CivilCaseDetails/ccap-ext:CourtCaseDocument">
			<div class="newsection width70">
				<p class="blackBoldSmall paddingZero">
				DOCUMENTS:
				</p>
				<xsl:apply-templates select="doj:InquiryResult/ccap-ext:CriminalCaseDetails/ccap-ext:CourtCaseDocument | doj:InquiryResult/ccap-ext:CivilCaseDetails/ccap-ext:CourtCaseDocument"/>
			</div>
			<xsl:apply-templates select="doj:InquiryResult/ccap-ext:CriminalCaseDetails/ccap-ext:CaseSummary|doj:InquiryResult/ccap-ext:CivilCaseDetails/ccap-ext:CivilCaseSummary/ccap-ext:CaseSummary" mode="detail"/>
			<xsl:apply-templates select="doj:InquiryResult/ccap-ext:CriminalCaseDetails/ccap-ext:CaseSummaryMaintenance| doj:InquiryResult/ccap-ext:CivilCaseDetails/ccap-ext:CaseSummaryMaintenance"/>
			<xsl:if test="$from='firearm'">
				<xsl:apply-templates select="ancestor::doj:CCAPResponseDocument" mode="request"/>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilCaseSummary">
		<div class="newsection">
			<p class="blackBoldSmall paddingZero">
        DISPOSITION:
      </p>
			<table class="tealRegular" width="55%">
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Court Official:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="ccap-ext:CaseSummary/ccap-ext:CourtOfficialPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Disposition:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:value-of select="ccap-ext:CaseDispositionHistoryDetail/ccap-ext:DispositionCode"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Disposition Date:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="ccap-ext:CaseDispositionHistoryDetail/ccap-ext:DispositionDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
					<xsl:with-param name="label2">Disposition Reported:</xsl:with-param>
					<xsl:with-param name="value2">
						<xsl:apply-templates select="ccap-ext:CaseDispositionHistoryDetail/ccap-ext:ChargeDispositionReportedDate" mode="FormatFullDateAsMMDDYYYY"/>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Description Text:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:value-of select="ccap-ext:CaseDispositionHistoryDetail/j:EventDescriptionText"/>
					</xsl:with-param>
				</xsl:call-template>
			</table>
		</div>
	</xsl:template>
	<!-- Request Section -->
	<xsl:template match="doj:CCAPResponseDocument" mode="request">
		<div class="newsection">
			<p class="blackBoldSmall paddingZero">
        YOUR REQUEST:
      </p>
			<p class="tealRegular paddingZero">
				<table class="tealRegular" width="55%">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Initiator Identifier:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="@doj-ext:initiatorID"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1" select="width15"/>
						<xsl:with-param name="value_class_name1" select="width20"/>
						<xsl:with-param name="label2">Response Identifier:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:value-of select="@doj-ext:responseID"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name2" select="width10"/>
						<xsl:with-param name="value_class_name2" select="width10"/>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Date &amp; Time:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionReceivedDate" mode="FormatFullDateAsMMDDYYYY"/>;
              <xsl:value-of select="substring(doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionReceivedTime, 1, 5)"/>
						</xsl:with-param>
					</xsl:call-template>
				</table>
			</p>
		</div>
	</xsl:template>
	<!-- Maintenance section not tested-->
	<xsl:template match="ccap-ext:CaseSummaryMaintenance">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">
        MAINTENANCE:
      </p>
			<div class="tealRegular paddingZero">
        Date: <xsl:apply-templates select="j:EventDate" mode="FormatFullDateAsMMDDYYYY"/>
				<table class="tealRegular paddingLeft2">
					<tr>
						<td width="20em">Maintenance: </td>
						<td>
							<xsl:value-of select="ccap-ext:NewCourtCaseMaintenanceCode"/>
							<xsl:if test="ccap-ext:NewCourtCaseMaintenanceCode and ccap-ext:CourtCaseMaintenanceText">;</xsl:if>
							<xsl:value-of select="ccap-ext:CourtCaseMaintenanceText"/>
						</td>
					</tr>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Text:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:CourtCaseHistoryEventDescriptionText"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Party ID:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:PartyID/j:ID"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Party Name:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:CaseParty/ccap-ext:PartyName"/>
						</xsl:with-param>
					</xsl:call-template>
				</table>
			</div>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:PartyName">
		<xsl:call-template name="personName">
			<xsl:with-param name="givenName" select="ccap-ext:PartyGivenName"/>
			<xsl:with-param name="middleName" select="ccap-ext:PartyMiddleName"/>
			<xsl:with-param name="lastName" select="ccap-ext:PartyLastName"/>
			<xsl:with-param name="suffix" select="ccap-ext:PartyNameSuffix"/>
		</xsl:call-template>
	</xsl:template>
	<!-- DETAILS section -->
	<xsl:template match="ccap-ext:CaseSummary" mode="detail">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">
        DETAILS:
      </p>
			<p class="tealRegular paddingZero">
				<table class="tealRegular" width="60%">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Old Case:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:OldCaseDocketID/j:ID"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1">width15</xsl:with-param>
						<xsl:with-param name="value_class_name1">width15</xsl:with-param>
						<xsl:with-param name="label2">Renumbered from:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:value-of select="ccap-ext:RenumberedCaseDocketID/j:ID"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name2">width15</xsl:with-param>
						<xsl:with-param name="value_class_name2">width15</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Cross Referenced:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:CrossReferencedCase"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1">width15</xsl:with-param>
						<xsl:with-param name="value_class_name1">width15</xsl:with-param>
						<xsl:with-param name="label2">Consolidated with:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:value-of select="ccap-ext:ConsolidatedCaseDocketID/j:ID"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name2">width15</xsl:with-param>
						<xsl:with-param name="value_class_name2">width15</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Appeal Remand:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false">
									<xsl:value-of select="ccap-ext:RemandfromAppealIndicator"/>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1">width15</xsl:with-param>
						<xsl:with-param name="value_class_name1">width15</xsl:with-param>
						<xsl:with-param name="label2">Pardoned:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false">
									<xsl:value-of select="ccap-ext:PardonedIndicator"/>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:with-param>
						<xsl:with-param name="label_class_name2">width15</xsl:with-param>
						<xsl:with-param name="value_class_name2">width15</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Converted:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false">
									<xsl:value-of select="ccap-ext:ConvertedIndicator"/>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Maintenance:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:CourtCaseMaintenanceCode"/>
							<xsl:if test="ccap-ext:CourtCaseMaintenanceCode and ccap-ext:CourtCaseMaintenanceText">
                ;&#160;
              </xsl:if>
							<xsl:value-of select="ccap-ext:CourtCaseMaintenanceText"/>
						</xsl:with-param>
					</xsl:call-template>
				</table>
				<xsl:if test="parent::ccap-ext:CriminalCaseDetails/ccap-ext:CaseControlFeature">
					<p class="tealRegular paddingZero">
          &#160;Case Control Info:
          <xsl:apply-templates select="parent::ccap-ext:CriminalCaseDetails/ccap-ext:CaseControlFeature"/>
					</p>
				</xsl:if>
			</p>
		</div>
	</xsl:template>
	<!-- CaseControlFeature Not tested-->
	<xsl:template match="ccap-ext:CaseControlFeature">
		<p class="paddingLeft2">
			<table class="tealRegular">
				<tr>
					<td>County:</td>
					<td>
						<xsl:value-of select="ccap-ext:CountyNumber"/>
					</td>
					<td>Control Feature On: </td>
					<td>
						<xsl:call-template name="true-false_to_Yes-No">
							<xsl:with-param name="true-false" select="ccap-ext:CaseControlFeatureOnIndicator"/>
						</xsl:call-template>
					</td>
				</tr>
				<tr>
					<td>Control Name: </td>
					<td>
						<xsl:value-of select="ccap-ext:CaseControlFeatureName"/>
					</td>
					<td colspan="2"/>
				</tr>
				<tr>
					<td>Text: </td>
					<td>
						<xsl:value-of select="ccap-ext:CaseControlFeatureDescription"/>
					</td>
					<td colspan="2"/>
				</tr>
			</table>
		</p>
	</xsl:template>
	<!-- Case Document not tested -->
	<xsl:template match="ccap-ext:CourtCaseDocument">
		<p class="tealRegular paddingZero">
			<table class="tealRegular paddingZero" width="50%">
				<tr>
					<td>Document: </td>
					<td>
						<xsl:value-of select="j:DocumentTitleText"/>
					</td>
				</tr>
				<tr>
					<td width="10%">
						<span class="paddingLeft2">Document ID:</span>
					</td>
					<td width="15%">
						<xsl:value-of select="j:DocumentID/j:ID"/>
					</td>
				</tr>
				<tr class="paddingLeft2">
					<td>
						<span class="paddingLeft2">Created Date:</span>
					</td>
					<td>
						<xsl:apply-templates select="j:DocumentCreationDate" mode="FormatFullDateAsMMDDYYYY"/>
					</td>
				</tr>
			</table>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:CourtRecord">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">
        COURT EVENTS:
      </p>
			<xsl:apply-templates select="ccap-ext:CourtRecordEventCaseHistory"/>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:CourtRecordEventCaseHistory">
		<p class="tealRegular paddingZero">
			<span>
        Event #:
        <xsl:value-of select="ccap-ext:CourtEvent/j:CourtEventSequenceID/j:ID"/>
			</span>
			<span class="paddingLeft4">
				<xsl:value-of select="ccap-ext:CourtEvent/j:EventTypeText"/>; &#160;
          <xsl:value-of select="ccap-ext:CourtEvent/ccap-ext:CourtEventTypeDescriptionText"/>
			</span>
			<table class="tealRegular paddingLeft2 width70" cellspacing="0" cellpadding="0">
				<tr>
					<td width="12%">Date: </td>
					<td width="28%">
						<xsl:apply-templates select="ccap-ext:CourtEvent/j:EventDate" mode="FormatFullDateAsMMDDYYYY"/>
					</td>
					<td width="10%">Amount:</td>
					<td width="10%">$<xsl:value-of select="ccap-ext:CourtEvent/ccap-ext:CourtCaseEventAmount"/>
					</td>
				</tr>
				<xsl:if test="ccap-ext:CourtOfficialDetail">
					<tr>
						<td>Court Official:</td>
						<td>
							<xsl:apply-templates select="ccap-ext:CourtOfficialDetail/ccap-ext:CourtOfficialPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
						</td>
						<td colspan="2"/>
					</tr>
				</xsl:if>
				<xsl:if test="ccap-ext:ActivityReporter">
					<tr>
						<td>Reported By:</td>
						<td>
							<xsl:apply-templates select="ccap-ext:ActivityReporter/j:PersonName" mode="FirstMiddleLastSuffix"/>
						</td>
						<td colspan="2"/>
					</tr>
				</xsl:if>
			</table>
			<xsl:if test="ccap-ext:CourtEvent/j:EventDescriptionText">
				<table class="tealRegular paddingLeft4" cellspacing="0" width="90%">
					<tr>
						<td valign="top" width="12%">Comments:</td>
						<td>
							<xsl:value-of select="ccap-ext:CourtEvent/j:EventDescriptionText"/>
						</td>
					</tr>
				</table>
			</xsl:if>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:CriminalCaseDetails|ccap-ext:CivilCaseDetails">
		<xsl:apply-templates select="ccap-ext:CaseSummary|ccap-ext:CivilCaseSummary/ccap-ext:CaseSummary"/>
		<xsl:if test="ccap-ext:CaseSummary/ccap-ext:CourtOfficialPerson/j:PersonName">
			<p class="tealRegular paddingZero">
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Court Official:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="ccap-ext:CaseSummary/ccap-ext:CourtOfficialPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
					</xsl:with-param>
				</xsl:call-template>
			</p>
		</xsl:if>
		<xsl:apply-templates select="ccap-ext:CaseDefendant"/>
		<xsl:if test="ccap-ext:JuvenileCaseParty">
			<div class="newsection width70">
				<p class="blackBoldSmall paddingZero">
						PARTIES:
					</p>
				<p class="tealRegular paddingZero">
						Juvenile Case Party Info: 
					</p>
				<xsl:apply-templates select="ccap-ext:JuvenileCaseParty"/>
			</div>
		</xsl:if>
		<xsl:if test="ccap-ext:CaseCharge">
			<div class="newsection width70">
				<p class="blackBoldSmall paddingZero">
          CHARGES:
        </p>
				<xsl:apply-templates select="ccap-ext:CaseCharge"/>
			</div>
		</xsl:if>
		<xsl:apply-templates select="ccap-ext:Citation"/>
		<xsl:apply-templates select="ccap-ext:Assessment"/>
		<xsl:if test="ccap-ext:CivilCaseParty">
			<div class="newsection width70">
				<p class="blackBoldSmall paddingZero">
          PARTIES:
        </p>
				<p class="tealRegular paddingZero">
          Case Party Info: 
          <xsl:apply-templates select="ccap-ext:CivilCaseParty"/>
				</p>
				<xsl:apply-templates select="ccap-ext:CaseCharge"/>
			</div>
		</xsl:if>
		<xsl:apply-templates select="ccap-ext:CivilCaseSummary"/>
		<xsl:apply-templates select="ccap-ext:CivilJudgementDetail"/>
		<xsl:apply-templates select="ccap-ext:CaseSummary/ccap-ext:ProsecutorDetail"/>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilCaseParty">
		<table class="tealRegular paddingLeft2" width="50%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Party ID: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyID/j:ID"/>
				</xsl:with-param>
				<xsl:with-param name="label2">Party Type: </xsl:with-param>
				<xsl:with-param name="value2">
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyTypeCode"/>
					<xsl:if test="ccap-ext:PartyDetail/ccap-ext:PartyTypeCode and ccap-ext:PartyDetail/ccap-ext:PartyTypeText">;</xsl:if>
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyTypeText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				<xsl:with-param name="label_class_name2">width10</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="tealRegular paddingLeft4" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Status: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:value-of select="ccap-ext:Case/ccap-ext:CaseStatus/ccap-ext:StatusCodeDescriptionText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">width10</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Name: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:CaseParty/ccap-ext:PartyName"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="ccap-ext:CaseParty/j:PersonBirthDate | ccap-ext:CaseParty/j:PersonPhysicalDetails/j:PersonSexCode|ccap-ext:CaseParty/j:PersonPhysicalDetails/j:PersonRaceText">
				<tr>
					<td colspan="4">
            Dob: <xsl:apply-templates select="ccap-ext:CaseParty/j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>&#160;&#160;&#160;
            Sex: <xsl:value-of select="ccap-ext:CaseParty/j:PersonPhysicalDetails/j:PersonSexCode"/> &#160;&#160;&#160;
            Race: <xsl:value-of select="ccap-ext:CaseParty/j:PersonPhysicalDetails/j:PersonRaceText"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="ccap-ext:CaseParty/ccap-ext:AddressDetail/j:LocationAddress">
				<tr>
					<td colspan="4">
						<xsl:apply-templates select="ccap-ext:CaseParty/ccap-ext:AddressDetail/j:LocationAddress"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Address Effective:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:CaseParty/ccap-ext:AddressDetail/ccap-ext:AddressEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label2">Address Sealed:</xsl:with-param>
				<xsl:with-param name="value2">
					<xsl:call-template name="true-false_to_Yes-No">
						<xsl:with-param name="true-false">
							<xsl:value-of select="ccap-ext:AddressSealIndicator"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">SSN ID:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:value-of select="ccap-ext:CaseParty/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="tealRegular paddingLeft4" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Alias Names:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:for-each select="ccap-ext:CaseParty/ccap-ext:PersonAliasDetail">
						<xsl:apply-templates select="j:PersonName" mode="FirstMiddleLastSuffix"/>
						<xsl:if test="position() != last()">
							<br/>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<xsl:apply-templates select="ccap-ext:CivilCasePartyAttorney"/>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilCasePartyAttorney">
		<table class="tealRegular paddingLeft4" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Attorney:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AttorneyPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="tealRegular paddingLeft6" width="35%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Guardian Ad Litem: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:call-template name="true-false_to_Yes-No">
						<xsl:with-param name="true-false">
							<xsl:value-of select="ccap-ext:GuardianAtLitemIndicator"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">paddingLeft2</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Entered Date:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AttorneyEnteredDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Withdrew Date:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AttorneyWithdrewDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
	</xsl:template>
	<!-- Judgement Section-->
	<xsl:template match="ccap-ext:CivilJudgementDetail">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">JUDGEMENT:</p>
			<div class="tealRegular">
        Sequence #: <xsl:value-of select="ccap-ext:JudgementSequenceID/j:ID"/>
				<xsl:if test="j:DocumentFiledDate">
					<span class="floatRight">
            Date: 
            <xsl:apply-templates select="j:DocumentFiledDate"/>
					</span>
				</xsl:if>
				<table class="paddingLeft2" width="70%">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Disposition: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:Disposition/ccap-ext:DispositionCode"/>
							<xsl:if test="ccap-ext:Disposition/ccap-ext:DispositionCode and ccap-ext:Disposition/ccap-ext:DispositionCodeText">
								<xsl:text>; </xsl:text>
							</xsl:if>
							<xsl:value-of select="ccap-ext:Disposition/ccap-ext:DispositionCodeText"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Disposition Date: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:Disposition/ccap-ext:DispositionDate" mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Court Event: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:CourtEvent/ccap-ext:CourtEventTypeDescriptionText"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Event Amount Due: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:if test="ccap-ext:CourtEvent/ccap-ext:CourtCaseEventAmount">$</xsl:if>
							<xsl:value-of select="ccap-ext:CourtEvent/ccap-ext:CourtCaseEventAmount"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Total Amount Due: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:if test="j:FinancialObligationTotalAmount">$</xsl:if>
							<xsl:value-of select="j:FinancialObligationTotalAmount"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Judgment Satisfaction: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:JudgementSatisfactionCode"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Satisfaction Date: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:JudgementFullSatisfactionDate" mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Order Starts: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:CourtOrderServiceStartDate " mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
						<xsl:with-param name="label2">Order Ends: </xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:apply-templates select="ccap-ext:CourtOrderServiceEndDate " mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Warrant ID: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:WarrantID/j:ID"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Debtor: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:JudgementDebtor/j:PersonName " mode="FirstMiddleLastSuffix"/>
						</xsl:with-param>
						<xsl:with-param name="label2">Multiple Debtors: </xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false" select="ccap-ext:JudgementMultipleDebtorsIndicator"/>
							</xsl:call-template>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Case Sealed: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false" select="ccap-ext:SealIndicator"/>
							</xsl:call-template>
						</xsl:with-param>
						<xsl:with-param name="label2">Petitioner Sealed: </xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false" select="ccap-ext:PetitionerSealIndicator"/>
							</xsl:call-template>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Property Desc: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:PropertyDescriptionText"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Judgement Tax Type: </xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:JudgementTaxTypeText"/>
						</xsl:with-param>
					</xsl:call-template>
				</table>
				<xsl:if test="ccap-ext:CivilJudgementEventDetail">
					<p class="paddingLeft2">
            Judgement Events
            <table class="paddingLeft4" cellspacing="0">
							<xsl:apply-templates select="ccap-ext:CivilJudgementEventDetail"/>
						</table>
					</p>
				</xsl:if>
				<xsl:if test="ccap-ext:CivilJudgementAmountDetail">
					<p class="paddingLeft2">
            Judgement Amounts
            <table class="paddingLeft4" cellspacing="0">
							<xsl:apply-templates select="ccap-ext:CivilJudgementAmountDetail"/>
						</table>
					</p>
				</xsl:if>
				<xsl:if test="ccap-ext:CivilJudgementPartyDetail">
					<div class="paddingLeft2">
            Case Party Info:
            <xsl:for-each select="ccap-ext:CivilJudgementPartyDetail">
							<xsl:sort select="ccap-ext:PartyDetail/ccap-ext:PartyID/j:ID"/>
							<xsl:apply-templates select="."/>
						</xsl:for-each>
					</div>
				</xsl:if>
			</div>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilJudgementPartyDetail">
		<table class="paddingLeft2" cellspacing="0" width="50%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Party Id: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyID/j:ID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				<xsl:with-param name="value_class_name1">width20</xsl:with-param>
				<xsl:with-param name="label_class_name2">width10</xsl:with-param>
				<xsl:with-param name="label2">Party Type: </xsl:with-param>
				<xsl:with-param name="value2">
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyTypeCode"/>
					<xsl:if test="ccap-ext:PartyDetail/ccap-ext:PartyTypeCode and ccap-ext:PartyDetail/ccap-ext:PartyTypeText">
						<xsl:text>; </xsl:text>; 
            </xsl:if>
					<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyTypeText"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="paddingLeft4" cellspacing="0" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Dismissed: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:call-template name="true-false_to_Yes-No">
						<xsl:with-param name="true-false" select="ccap-ext:DismissedIndicator"/>
					</xsl:call-template>
				</xsl:with-param>
				<xsl:with-param name="label2">Status: </xsl:with-param>
				<xsl:with-param name="value2">
					<xsl:value-of select="ccap-ext:JudgementPartyStatusCode"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				<xsl:with-param name="label_class_name2">width10</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Name:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:call-template name="personName">
						<xsl:with-param name="givenName">
							<xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyGivenName"/>
						</xsl:with-param>
						<xsl:with-param name="middleName">
							<xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyMiddleName"/>
						</xsl:with-param>
						<xsl:with-param name="lastName">
							<xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyLastName"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<p class="paddingLeft4">
			<xsl:apply-templates select="ccap-ext:CaseParty/ccap-ext:AddressDetail/j:LocationAddress"/>
			<xsl:if test="ccap-ext:AddressSealIndicator">
				<br/>Address Sealed:
          <xsl:call-template name="true-false_to_Yes-No">
					<xsl:with-param name="true-false">
						<xsl:value-of select="ccap-ext:AddressSealIndicator"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="ccap-ext:AttorneyPerson/j:PersonName">
				<br/>Attorney: 
          <xsl:apply-templates select="ccap-ext:AttorneyPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
			</xsl:if>
		</p>
	</xsl:template>
	<xsl:template match="j:LocationAddress">
		<xsl:if test="j:LocationStreet/j:StreetFullText">
			<xsl:value-of select="j:LocationStreet/j:StreetFullText"/>
		</xsl:if>
		<xsl:if test="j:LocationCityName">
      ,&#160; <xsl:value-of select="j:LocationCityName"/>
		</xsl:if>
		<xsl:if test="j:LocationStateCode.USPostalService">
      , <xsl:value-of select="j:LocationStateCode.USPostalService"/>
		</xsl:if>
		<xsl:if test="j:LocationPostalCodeID">
      &#160;<xsl:value-of select="j:LocationPostalCodeID"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilJudgementEventDetail">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Description:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:value-of select="ccap-ext:CourtCaseEventDescriptionText"/>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Date:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:apply-templates select="j:EventDate" mode="FormatFullDateAsMMDDYYYY"/>
			</xsl:with-param>
			<xsl:with-param name="label2">Satisfaction Amt:</xsl:with-param>
			<xsl:with-param name="value2">
				<xsl:if test="ccap-ext:JudgmentSatisfactionAmount">$</xsl:if>
				<xsl:value-of select="ccap-ext:JudgmentSatisfactionAmount"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="ccap-ext:CivilJudgementAmountDetail">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Description:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:value-of select="ccap-ext:JudgementAmountDescriptionText"/>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Amount Due:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:if test="j:FinancialObligationTotalAmount">$</xsl:if>
				<xsl:value-of select="j:FinancialObligationTotalAmount"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="ccap-ext:Citation">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">CITATION:</p>
			<div class="tealRegular">
        ID: <xsl:value-of select="ccap-ext:CitationID/j:ID"/>
				<br/>
				<table class="paddingLeft2">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Charge:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:Charge/j:Statute/j:StatuteCodeID"/>
							<xsl:if test="ccap-ext:Charge/j:StatuteText">
                ;<xsl:value-of select="ccap-ext:Charge/j:StatuteText"/>
							</xsl:if>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1">width10</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Date:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="j:Event/j:EventDate" mode="FormatFullDateAsMMDDYYYY"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Issued By:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:apply-templates select="ccap-ext:CitationIssuingOfficer/j:PersonName" mode="FirstMiddleLastSuffix"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Agency:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:CitationAgency/j:OrganizationName"/>
						</xsl:with-param>
					</xsl:call-template>
				</table>
				<table class="paddingLeft2" width="90%">
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Court Date:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="j:CourtAppearanceDate"/>
						</xsl:with-param>
						<xsl:with-param name="label2">Deposit:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:if test="ccap-ext:DepositAmount">$</xsl:if>
							<xsl:value-of select="ccap-ext:DepositAmount"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Mandatory Appear:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false">
									<xsl:value-of select="ccap-ext:MandatoryAppearIndicator"/>
								</xsl:with-param>
							</xsl:call-template>
						</xsl:with-param>
						<xsl:with-param name="label2">Fine:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:if test="j:CitationFineAmount">$</xsl:if>
							<xsl:value-of select="j:CitationFineAmount"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Plaintiff:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:PlaintiffAgencyName"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name1">width10</xsl:with-param>
						<xsl:with-param name="value_class_name1">width25</xsl:with-param>
						<xsl:with-param name="label2">Amt Due:</xsl:with-param>
						<xsl:with-param name="value2">
							<xsl:if test="j:FinancialObligationDueAmount">$</xsl:if>
							<xsl:value-of select="j:FinancialObligationDueAmount"/>
						</xsl:with-param>
						<xsl:with-param name="label_class_name2">width10</xsl:with-param>
						<xsl:with-param name="value_class_name2">width25</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Severity:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:SeverityCode"/>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="ConditionalRow">
						<xsl:with-param name="label1">Speed Limit Exceeded by:</xsl:with-param>
						<xsl:with-param name="value1">
							<xsl:value-of select="ccap-ext:SpeedLimitExceededby"/>
							<xsl:if test="ccap-ext:SpeedLimitExceededby"> Miles</xsl:if>
						</xsl:with-param>
					</xsl:call-template>
				</table>
			</div>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:ProsecutorDetail">
		<div class="newsection">
			<p class="blackBoldSmall paddingZero">
        PROSECUTOR:
      </p>
			<p class="tealRegular paddingZero">
				<xsl:apply-templates select="ccap-ext:ProsecutingAttorney/j:PersonName" mode="FirstMiddleLastSuffix"/>
				<xsl:if test="ccap-ext:ProsecutingAgencyName">
          &#160; of &#160;
          <xsl:value-of select="ccap-ext:ProsecutingAgencyName"/>
				</xsl:if>
			</p>
			<p class="tealRegular paddingZero">
        Prosecutor Case #: &#160;
        <xsl:value-of select="ccap-ext:ProsecutingAgencyCaseID/j:ID"/>
			</p>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:Assessment">
		<div class="newsection width70">
			<p class="blackBoldSmall paddingZero">
        FINANCIAL OBLIGATION:
      </p>
			<p class="tealRegular paddingZero">
				<table class="tealRegular paddingZero width60">
					<tr>
						<td width="15%">Due Date: </td>
						<td width="20%">
							<xsl:apply-templates select="j:ObligationDueDate" mode="FormatFullDateAsMMDDYYYY"/>
						</td>
						<td width="15%">Amount:</td>
						<td width="15%" align="right">
              $<xsl:value-of select="j:FinancialObligationTotalAmount"/>
						</td>
					</tr>
					<tr>
						<td colspan="2"/>
						<td>Probation:</td>
						<td align="right">$<xsl:value-of select="ccap-ext:FinancialObligationProbationAmount"/>
						</td>
					</tr>
					<tr>
						<td colspan="2"/>
						<td>Probation:</td>
						<td align="right">$<xsl:value-of select="ccap-ext:FinancialObligationProbationAmount"/>
						</td>
					</tr>
					<tr>
						<td colspan="2"/>
						<td>Adjustment:</td>
						<td align="right">$<xsl:value-of select="ccap-ext:FinancialObligationAdjustmentsAmount"/>
						</td>
					</tr>
					<tr>
						<td colspan="2"/>
						<td>Paid:</td>
						<td align="right">$<xsl:value-of select="j:FinancialObligationPaidAmount"/>
						</td>
					</tr>
					<tr>
						<td colspan="2"/>
						<td>Due:</td>
						<td align="right">$<xsl:value-of select="j:FinancialObligationDueAmount"/>
						</td>
					</tr>
					<tr>
						<td width="20%">Civil Judgment:</td>
						<td colspan="3">
							<xsl:call-template name="true-false_to_Yes-No">
								<xsl:with-param name="true-false">
									<xsl:value-of select="ccap-ext:CivilJudgementIndicator"/>
								</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</table>
			</p>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:CaseSummary">
		<xsl:variable name="alignValue" select="right" />
		<xsl:variable name="alignValue"> 
			<xsl:choose>
				<xsl:when test="$from='firearm'">
					<xsl:value-of select="right"/>
				</xsl:when>
				<xsl:when test="$from='ebc' or $from='mrs'">
					<xsl:value-of select="left"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="right"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<div style="align:{$alignValue};">
			<table>
				<tr>
					<td>
						<xsl:element name="img">
							<xsl:if test="$from='firearm'">
								<xsl:attribute name="class">pagerefimage</xsl:attribute>
							</xsl:if>
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">Record Details</xsl:attribute>
						</xsl:element>
					</td>
					<td></td>
				</tr>
				<xsl:if test="$from='ebc' or $from='mrs'">
					<tr><td colspan="2"> &#160; </td></tr>
				</xsl:if>
				<tr>
					<td class="blackBoldSmall">CASE:</td>
					<td class="tealRegular">
						<xsl:value-of select="ccap-ext:Case/j:CaseDocketID"/>;
						<xsl:value-of select="ccap-ext:Case/j:CaseCategoryText"/>
					</td>
				</tr>
				<tr>
					<td class="blackBoldSmall">CASE TITLE:</td>
					<td class="tealRegular">
						<xsl:value-of select="ccap-ext:Case/j:CaseTitleText"/>
					</td>
				</tr>
				<tr>
					<td class="blackBoldSmall">STATUS:</td>
					<td class="tealRegular">
						<xsl:value-of select="ccap-ext:Case/ccap-ext:CaseStatus/ccap-ext:StatusCodeDescriptionText"/>
					</td>
				</tr>
				<tr>
					<td class="blackBoldSmall">FILED:</td>
					<td class="tealRegular">
						<xsl:apply-templates select="ccap-ext:Case/ccap-ext:CourtCaseFilingDate" mode="FormatFullDateAsMMDDYYYY"/>
						<xsl:text> in </xsl:text>
						<xsl:value-of select="j:LocationCountyName"/>
					</td>
				</tr>
			</table>
		</div>
		<xsl:if test="$from != 'firearm'">
		<div>
			<font size="1">
				  <b>
				  <br/>
				  Please note :
				  </b>
					 <i>
						<p>
						Wisconsin Circuit Court Access (WCCA) information provided here is only a snapshot of the information maintained in the State Courts Office Consolidated Court Automation Program (CCAP) case management system.  Access 	to and use of this data is governed by state statute.  
						</p>
						<br/>
						<p>
						Access to juvenile data in accordance with 2011 Act 270 must comply with allowable purposes for access as set forth by Wisconsin Statute 938.296 (2m)(c).  Any person who intentionally uses or discloses information in violation of this section may be required to forfeit up to $5,000.   Additional criminal penalties for unauthorized access, use, or disclosure of data may be applicable in accordance with Wisconsin Statute 943.70.
						</p>
						<br/>
						<p>
						Notice to employers: It may be a violation of state law to discriminate against a job applicant because of an arrest or conviction record.  Generally speaking, an employer may refuse to hire an applicant on the basis of a conviction only if the circumstances of the conviction substantially relate to the particular job.  For more information, see Wisconsin Statute 111.335 and the Department of Workforce Development's Arrest and conviction Records under the Law publication.
						</p>
						<br/>
					</i>
			</font>
		</div>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ccap-ext:CaseDefendant">
		<div class="newsection paddingOne">
			<xsl:choose>
				<xsl:when test="$from='ebc' or $from='mrs'">
					<table width="70%" border="0">
						<tr>
							<td>
								<p class="subject_name">
									<xsl:call-template name="personName">
										<xsl:with-param name="givenName">
											<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyGivenName"/>
										</xsl:with-param>
										<xsl:with-param name="middleName">
											<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyMiddleName"/>
										</xsl:with-param>
										<xsl:with-param name="lastName">
											<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyLastName"/>
										</xsl:with-param>
									</xsl:call-template>
								</p>
							</td>
							<td>
								<xsl:element name="img">
									<xsl:attribute name="border">0</xsl:attribute>
									<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/></xsl:attribute>
									<xsl:attribute name="alt">aliases</xsl:attribute>
								</xsl:element>
							</td>
						</tr>
					</table>
				</xsl:when>
				<xsl:when test="$from='firearm'">
					<p class="tealBold paddingZero">
						<xsl:call-template name="personName">
							<xsl:with-param name="givenName">
								<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyGivenName"/>
							</xsl:with-param>
							<xsl:with-param name="middleName">
								<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyMiddleName"/>
							</xsl:with-param>
							<xsl:with-param name="lastName">
								<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyLastName"/>
							</xsl:with-param>
						</xsl:call-template>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<p class="tealBold paddingZero">
							<xsl:call-template name="personName">
								<xsl:with-param name="givenName">
									<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyGivenName"/>
								</xsl:with-param>
								<xsl:with-param name="middleName">
									<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyMiddleName"/>
								</xsl:with-param>
								<xsl:with-param name="lastName">
									<xsl:value-of select="ccap-ext:CaseDefendantParty/ccap-ext:PartyName/ccap-ext:PartyLastName"/>
								</xsl:with-param>
							</xsl:call-template>
						</p>
				</xsl:otherwise>
			</xsl:choose>
			<p class="paddingZero tealRegular">
				<xsl:value-of select="ccap-ext:PartyDetail/ccap-ext:PartyTypeText"/>
				<br/>
				<xsl:apply-templates select="ccap-ext:CaseDefendantParty/j:PersonPhysicalDetails"/>
				<br/>
				<xsl:apply-templates select="ccap-ext:CaseDefendantParty/j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>
				<br/>
				<xsl:apply-templates select="ccap-ext:CaseDefendantParty/ccap-ext:AddressDetail/j:LocationAddress"/>
				<xsl:if test="ccap-ext:CaseDefendantParty/ccap-ext:AddressDetail/ccap-ext:AddressEffectiveDate">
					<xsl:text> as of </xsl:text>
					<xsl:apply-templates select="ccap-ext:CaseDefendantParty/ccap-ext:AddressDetail/ccap-ext:AddressEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/><br/>
				</xsl:if>
				<xsl:if test="ccap-ext:DefendantAttorney">
					<xsl:variable name="borderValue" select="1" />
					<xsl:variable name="borderValue"> 
						<xsl:choose>
							<xsl:when test="$from='firearm'">
								<xsl:value-of select="1"/>
							</xsl:when>
							<xsl:when test="$from='ebc' or $from='mrs'">
								<xsl:value-of select="0"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="1"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<table class="tealRegular" border="{$borderValue}">
						<thead>
							<tr>
							<xsl:choose>
								<xsl:when test="$from='firearm'">
									<td>Attorney</td>
									<td>Entered</td>
									<td>Withdrew</td>
								</xsl:when>
								<xsl:when test="$from='ebc' or $from='mrs'">
									<td class="blackBoldSmall">Attorney</td>
									<td class="blackBoldSmall">Entered</td>
									<td class="blackBoldSmall">Withdrew</td>
									<td class="blackBoldSmall" width="50%"></td>
								</xsl:when>
								<xsl:otherwise>
									<td>Attorney</td>
									<td>Entered</td>
									<td>Withdrew</td>
								</xsl:otherwise>
							</xsl:choose>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="ccap-ext:DefendantAttorney">
								<xsl:apply-templates select="."/>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>
			</p>
			<xsl:if test="parent::ccap-ext:CriminalCaseDetails/ccap-ext:Citation">
				<xsl:apply-templates select="parent::ccap-ext:CriminalCaseDetails/ccap-ext:Citation" mode="header"/>
			</xsl:if>
			<xsl:if test="ccap-ext:CaseDefendantParty/ccap-ext:PersonAliasDetail">
				<p class="newsection">
					<xsl:choose>
						<xsl:when test="$from='ebc' or $from='mrs'">
							<span style="color:#000; font-weight: bold; font-size:75%">ALIAS NAMES/FRAUDULENT DATA</span>
						</xsl:when>
						<xsl:when test="$from='firearms'">
							<span class="blackBoldSmall">ALIAS NAMES/FRAUDULENT DATA</span>
						</xsl:when>
						<xsl:otherwise>
							<span class="blackBoldSmall">ALIAS NAMES/FRAUDULENT DATA</span>
						</xsl:otherwise>
					</xsl:choose>
					<br/>
					<span class="tealRegular">
						<span class="blackBoldSmall">
						<xsl:choose>
							<xsl:when test="$from='ebc' or $from='mrs'">
								Alias Names:
							</xsl:when>
							<xsl:when test="$from='firearms'"><!--just keep no change in firearms-->
								AliasNames:
							</xsl:when>
							<xsl:otherwise>
								Alias Names:
							</xsl:otherwise>
						</xsl:choose>
							</span>
						<xsl:for-each select="ccap-ext:CaseDefendantParty/ccap-ext:PersonAliasDetail">
							<xsl:apply-templates select="j:PersonName" mode="FirstMiddleLastSuffix"/>
							<xsl:if test="position() != last()">
								<xsl:text>,&#160;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</span>
				</p>
			</xsl:if>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:Citation" mode="header">
		<xsl:if test="ccap-ext:VehicleDetail">
			<div class="newsection">
				<table class="tealRegular paddingZero">
					<xsl:if test="ccap-ext:VehicleDetail/j:VehicleID/j:ID">
						<tr>
							<td>
								<xsl:element name="img">
									<xsl:attribute name="class">pagerefimage</xsl:attribute>
									<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'VehicleIcon.jpg')"/></xsl:attribute>
									<xsl:attribute name="alt">Vehicle Icon</xsl:attribute>
								</xsl:element>
							</td>
							<td valign="middle">
                VIN <xsl:value-of select="ccap-ext:VehicleDetail/j:VehicleID/j:ID"/>
							</td>
						</tr>
					</xsl:if>
					<tr>
						<td>
							<xsl:element name="img">
								<xsl:attribute name="class">pagerefimage</xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'Plate1.jpg')"/></xsl:attribute>
								<xsl:attribute name="alt">License Plate Icon</xsl:attribute>
							</xsl:element>
						</td>
						<td valign="middle">
							<xsl:value-of select="ccap-ext:VehicleDetail/j:VehicleLicensePlateID/j:ID"/>
							<xsl:if test="ccap-ext:VehicleDetail/ccap-ext:RegistrationJurisdictionName">
                , <xsl:value-of select="ccap-ext:VehicleDetail/ccap-ext:RegistrationJurisdictionName"/>
							</xsl:if>
							<xsl:if test="ccap-ext:VehicleDetail/ccap-ext:RegistrationExpirationYear">
                , Exp. <xsl:value-of select="ccap-ext:VehicleDetail/ccap-ext:RegistrationExpirationYear"/>
							</xsl:if>
						</td>
					</tr>
				</table>
			</div>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ccap-ext:DefendantAttorney">
		<tr>
			<td>
				<xsl:apply-templates select="ccap-ext:AttorneyPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
			</td>
			<td>
				<xsl:apply-templates select="ccap-ext:AttorneyEnteredDate" mode="FormatFullDateAsMMDDYYYY"/>
			</td>
			<td>
				<xsl:apply-templates select="ccap-ext:AttorneyWithdrewDate" mode="FormatFullDateAsMMDDYYYY"/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ccap-ext:JuvenileCaseParty">
		<table class="tealRegular paddingLeft2" width="50%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Party Type: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:value-of select="ccap-ext:PartyDescriptionText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1">width10</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="tealRegular paddingLeft4" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Name: </xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:PartyName"/>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:if test="j:PersonBirthDate | j:PersonPhysicalDetails/j:PersonSexCode | j:PersonPhysicalDetails/j:PersonRaceText">
				<tr>
					<td colspan="2">
            Dob: <xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>&#160;&#160;&#160;
            Sex: <xsl:value-of select="j:PersonPhysicalDetails/j:PersonSexCode"/> &#160;&#160;&#160;
            Race: <xsl:value-of select="j:PersonPhysicalDetails/j:PersonRaceText"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="ccap-ext:AddressDetail/j:LocationAddress">
				<tr>
					<td colspan="2">
						<xsl:apply-templates select="ccap-ext:AddressDetail/j:LocationAddress"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Address Effective:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AddressDetail/ccap-ext:AddressEffectiveDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<xsl:apply-templates select="ccap-ext:PartyAttorney"/>
	</xsl:template>
	<xsl:template match="ccap-ext:PartyAttorney">
		<table class="tealRegular paddingLeft4" width="70%">
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Attorney:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AttorneyPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
		<table class="tealRegular paddingLeft6" width="80%">
			<xsl:if test="ccap-ext:AttorneyPerson/ccap-ext:Residence/j:LocationAddress">
				<tr>
					<td colspan="2">
						<xsl:apply-templates select="ccap-ext:AttorneyPerson/ccap-ext:Residence/j:LocationAddress"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1">Entered Date:</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="ccap-ext:AttorneyEnteredDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
			</xsl:call-template>
		</table>
	</xsl:template>
	<xsl:template match="ccap-ext:CaseCharge">
		<p class="tealRegular paddingZero">
			<span>
          Charge Seq No: 
          <xsl:value-of select="ccap-ext:Charge/j:ChargeID"/>
				<xsl:if test="j:ActivityDate">
					<span style="float:right;">
            Charge Date:
            <xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
					</span>
				</xsl:if>
			</span>
			<br/>
			<p class="tealRegular paddingLeft2 ">
				<xsl:value-of select="ccap-ext:Charge/j:Statute/j:StatuteCodeID"/>, &#160; 
          <xsl:value-of select="ccap-ext:Charge/j:Statute/j:StatuteText"/>
				<span class="floatRight">
					<xsl:value-of select="ccap-ext:SeverityCode"/>, <xsl:value-of select="ccap-ext:SeverityCodeText"/>
				</span>
				<xsl:apply-templates select="ccap-ext:ChargeModifier/ccap-ext:Charge/j:Statute"/>
			</p>
			<p class="tealRegular paddingLeft2">
				<xsl:if test="ccap-ext:PleaDetail">
					<span>
              Plea: &#160;<xsl:value-of select="ccap-ext:PleaDetail/j:PleaDescriptionText"/>
						<span class="floatRight">
                Plea Date:
                <xsl:apply-templates select="ccap-ext:PleaDetail/ccap-ext:PleaDate" mode="FormatFullDateAsMMDDYYYY"/>
						</span>
					</span>
					<br/>
				</xsl:if>
				<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:Judgement"/>
				<xsl:if test="ccap-ext:JudgementDetail/ccap-ext:SuperVisionDetail |
            ccap-ext:JudgementDetail/TimeCondition | 
            ccap-ext:JudgementDetail/MiscellaneousCondition |
            ccap-ext:JudgementDetail/ccap-ext:ProbationDetail |
            ccap-ext:JudgementDetail/ccap-ext:ProvisionText">
					<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:SuperVisionDetail/ccap-ext:Sentence"/>
					<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:SentenceTimeCondition"/>
					<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:SentenceMiscellaneousCondition"/>
					<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:ProbationDetail"/>
					<xsl:apply-templates select="ccap-ext:JudgementDetail/ccap-ext:ProvisionText"/>
				</xsl:if>
			</p>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:ProvisionText">
		<p class="tealRegular paddingLeft2">
				<span class="paddingLeft2">
		          Provision Text: &#160;
		          <xsl:value-of select="."/>
				</span>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:ProbationDetail">
		<p class="tealRegular paddingLeft2">
			<span>Probation:</span>
			<br/>
			<xsl:if test="ccap-ext:SentenceDuration/ccap-ext:SentenceLength | ccap-ext:SentenceDuration/ccap-ext:SentenceLengthPeriodDescriptionText | ccap-ext:DispositionDate">
				<span class="paddingLeft2">
        Duration: &#160;
        <xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLength"/> &#160; 
        <xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLengthPeriodDescriptionText"/>
					<xsl:if test="ccap-ext:DispositionDate">
						<span class="floatRight">
            Date:
            <xsl:apply-templates select="ccap-ext:DispositionDate" mode="FormatFullDateAsMMDDYYYY"/>
						</span>
					</xsl:if>
				</span>
				<br/>
			</xsl:if>
			<xsl:if test="j:SupervisionAgency/j:OrganizationName | ccap-ext:JudgementIndicator">
				<span class="paddingLeft2">
        Supv Agy: &#160;
        <xsl:value-of select="j:SupervisionAgency/j:OrganizationName"/>
					<span class="floatRight">
          Judgment: &#160;
          <xsl:call-template name="true-false_to_Yes-No">
							<xsl:with-param name="true-false">
								<xsl:value-of select="ccap-ext:JudgementIndicator"/>
							</xsl:with-param>
						</xsl:call-template>
					</span>
				</span>
				<br/>
			</xsl:if>
			<xsl:if test="ccap-ext:ProbationDescriptionText">
				<span class="paddingLeft2">
          Probation Text: &#160;
          <xsl:value-of select="ccap-ext:ProbationDescriptionText"/>
				</span>
			</xsl:if>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:SentenceMiscellaneousCondition | ccap-ext:SupervisionMiscellaneousCondition">
		<p class="tealRegular paddingLeft2">
      Misc Condition: &#160;
      <xsl:value-of select="ccap-ext:SentenceMiscConditionDescriptionText"/>
			<table class="tealRegular paddingLeft4" cellspacing="0" width="90%">
				<tr>
					<td valign="top" width="10%">Text:</td>
					<td>
						<xsl:value-of select="ccap-ext:SentenceMiscConditionText"/>
					</td>
				</tr>
			</table>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:SentenceTimeCondition | ccap-ext:SupervisionTimeCondition">
		<p class="tealRegular paddingLeft2">
      Time Condition: &#160;
      <xsl:value-of select="ccap-ext:SentenceTimeConditionDescriptionText"/>
			<table class="tealRegular paddingLeft4" cellpadding="0" cellspacing="0" width="90%">
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Duration:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLength"/>&#160;
              <xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLengthPeriodDescriptionText"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Text:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:value-of select="ccap-ext:SentenceText"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				</xsl:call-template>
				<xsl:apply-templates select="ccap-ext:ConcurrentConsecutiveSentenceCondition"/>
			</table>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:Sentence">
		<p class="tealRegular paddingLeft2">
      Sentence: &#160;
      <xsl:if test="ccap-ext:SentenceCode | j:SentenceDescriptionText | ccap-ext:SentenceDate">
				<xsl:value-of select="ccap-ext:SentenceCode"/>; 
      <xsl:value-of select="j:SentenceDescriptionText"/>
				<span class="floatRight">
        Date:
        <xsl:apply-templates select="ccap-ext:SentenceDate" mode="FormatFullDateAsMMDDYYYY"/>
				</span>
			</xsl:if>
			<br/>
			<table class="tealRegular paddingLeft4" cellpadding="0" cellspacing="0" width="90%">
				<xsl:if test="ccap-ext:SentenceDuration | ccap-ext:SentenceBegingDate">
					<tr>
						<td width="11%">Duration:</td>
						<td>
							<xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLength"/>&#160;
              <xsl:value-of select="ccap-ext:SentenceDuration/ccap-ext:SentenceLengthPeriodDescriptionText"/>
							<xsl:if test="ccap-ext:SentenceBegingDate">
								<span class="floatRight">
                  Sent Begin: 
                </span>
							</xsl:if>
						</td>
					</tr>
				</xsl:if>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1">Text:</xsl:with-param>
					<xsl:with-param name="value1">
						<xsl:value-of select="ccap-ext:SentenceText"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name1">width10</xsl:with-param>
				</xsl:call-template>
				<xsl:apply-templates select="parent::ccap-ext:SuperVisionDetail/ccap-ext:ConcurrentConsecutiveSentenceCondition[ccap-ext:OrderSequenceID/j:ID=./ccap-ext:OrderSequenceID/j:ID]"/>
			</table>
			<xsl:apply-templates select="parent::ccap-ext:SuperVisionDetail/ccap-ext:SupervisionTimeCondition[ccap-ext:OrderSequenceID/j:ID=./ccap-ext:OrderSequenceID/j:ID]" mode="wrapper"/>
			<xsl:apply-templates select="parent::ccap-ext:SuperVisionDetail/ccap-ext:SupervisionMiscellaneousCondition[ccap-ext:OrderSequenceID/j:ID=./ccap-ext:OrderSequenceID/j:ID]" mode="wrapper"/>
		</p>
	</xsl:template>
	<xsl:template match="ccap-ext:SupervisionTimeCondition | ccap-ext:SupervisionMiscellaneousCondition" mode="wrapper">
		<div class="tealRegular paddingLeft2">
			<xsl:apply-templates select="."/>
		</div>
	</xsl:template>
	<xsl:template match="ccap-ext:ConcurrentConsecutiveSentenceCondition">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Conc/Cons:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:call-template name="resolveConcConsCode">
					<xsl:with-param name="concConsCode" select="ccap-ext:SentenceGroupingCode"/>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1"/>
		</xsl:call-template>
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">Conc/Cons Text:</xsl:with-param>
			<xsl:with-param name="value1">
				<xsl:value-of select="ccap-ext:SentenceGroupingDescriptionText"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1">width15</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="ccap-ext:Judgement">
		<span>
      Disposition:
      <xsl:value-of select="ccap-ext:Disposition/ccap-ext:DispositionCode"/>,
      <xsl:value-of select="ccap-ext:Disposition/ccap-ext:DispositionCodeText"/>
			<xsl:if test="ccap-ext:Disposition/ccap-ext:DispositionDate">
				<span class="floatRight">
        Date:
        <xsl:apply-templates select="ccap-ext:Disposition/ccap-ext:DispositionDate" mode="FormatFullDateAsMMDDYYYY"/>
				</span>
			</xsl:if>
		</span>
		<br/>
		<xsl:if test="ccap-ext:CourtOfficialPerson/j:PersonName | ccap-ext:JudgementOrderDate">
			<span class="paddingLeft2">
      Crt Off:
      <xsl:apply-templates select="ccap-ext:CourtOfficialPerson/j:PersonName" mode="FirstMiddleLastSuffix"/>
				<span class="floatRight">
        Date:
        <xsl:apply-templates select="ccap-ext:JudgementOrderDate" mode="FormatFullDateAsMMDDYYYY"/>
				</span>
			</span>
			<br/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="j:Statute">
		<br/>
		<span class="paddingLeft2">
			<xsl:value-of select="j:StatuteCodeID"/>, <xsl:value-of select="j:StatuteText"/>
		</span>
	</xsl:template>
	<xsl:template match="j:PersonPhysicalDetails">
		<span>
			<xsl:value-of select="j:PersonSexCode"/>, <xsl:value-of select="j:PersonRaceText"/>
		</span>
	</xsl:template>
</xsl:transform>
