<?xml version="1.0"?>
<xsl:transform version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
  xmlns:doj="http://www.doj.state.wi.us/dles/cib/ccap/response"
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
  xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
  xmlns:ccap-ext="http://www.doj.state.wi.us/dles/cib/ccap/response/extension">
    
  <xsl:param name="readOnly"/>
  <xsl:template match="doj:CCAPCaseResponse">
    <!-- Format header information -->
    <h2 class="filetype">
      <xsl:text>WI CCAP Case Info</xsl:text>
    </h2>
    <hr/>
    <xsl:apply-templates select="doj:InquiryResult"/>
  </xsl:template>
  
  <xsl:template match="doj:InquiryResult"> 
    <xsl:choose>
      <xsl:when test="$from='firearm'">
        <xsl:call-template name="casesList">
          <xsl:with-param name="ccapWhiteList" select="'CL|CO|CX|HL|IN|JJ|JT|ML|OL|PA|PR|SC|TR|TW|WC|WL'" />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="casesList">
          <xsl:with-param name="ccapWhiteList" select="''"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
    
  <xsl:template name="casesList">
    <xsl:param name="ccapWhiteList" />
	<xsl:variable name="caseInformation"
      select="ccap-ext:CaseInformation[not(contains($ccapWhiteList, ccap-ext:Case/ccap-ext:CaseCategoryCode))]"/>
    
    <xsl:choose>
      <xsl:when test="$caseInformation">
        <table class="dataTable">
          <thead>
            <tr>
              <xsl:if test="$from='firearm' and $readOnly != 'true'">
                <th><input type='checkbox' class="checkAll"></input></th>
              </xsl:if>
              <th>Case Number</th>      
              <th>Filing Date</th>
              <th>County Name</th>
              <th>Case Status</th>
              <th>Name</th>
              <th>Date of Birth</th>
              <th>Caption</th>
            </tr>
          </thead>
          <tbody>
            <xsl:for-each select="$caseInformation">
              <xsl:sort select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyLastName" order="ascending"/>
              <xsl:sort select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyGivenName" order="ascending"/>
             
              <tr>
                <xsl:if test="$from='firearm' and $readOnly != 'true'">
                  <td>
                    <xsl:element name="input">
                      <xsl:attribute name="type">checkbox</xsl:attribute>
                      <xsl:attribute name="class">courtCase</xsl:attribute>
                      <xsl:attribute name="value">
                        <xsl:value-of select="$executionUrl"/>
                        <xsl:text>&amp;</xsl:text>
                        <xsl:value-of select="ccap-ext:Case/j:CaseDocketID/j:ID"/>
                        <xsl:text>&amp;</xsl:text>
                        <xsl:value-of select="ccap-ext:Case/ccap-ext:CountyNumber"/>
                      </xsl:attribute>
                      <xsl:attribute name="id">
                        <xsl:value-of select="ccap-ext:Case/j:CaseDocketID/j:ID"/>
                      </xsl:attribute>
                    </xsl:element>
                  </td>
                </xsl:if>
                <xsl:choose>
					<xsl:when test="$from='firearm'">
						<td><xsl:value-of select="ccap-ext:Case/j:CaseDocketID/j:ID"/></td>
                	</xsl:when>
					<xsl:when test="$from='ebc' or $from='mrs'">
						<td>
						<xsl:variable name="oboORI" select="/*/*[local-name()='Header']/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID" />
						<xsl:variable name="ccapCountyCode" select="ccap-ext:Case/ccap-ext:CountyNumber" />
						<xsl:variable name="ccapCourtCaseNumber" select="ccap-ext:Case/j:CaseDocketID/j:ID" />
						<form id="{$ccapCourtCaseNumber}" action="/secure/personsearch/buildccapcasedetail.jsp" method="post" style="display:inline" >
							<input name="ccapCountyCode" type="hidden" value="{$ccapCountyCode}" />
							<input name="ccapCourtCaseNumber" type="hidden" value="{$ccapCourtCaseNumber}" />
							<xsl:if test="$oboORI">
								<input name="agencyORI" type="hidden" value="{$oboORI}" />
							</xsl:if>
							<xsl:choose>
								<xsl:when test="ccap-ext:JuvenileCaseIndicator">
									<input name="ccapJuvenileCbx" type="hidden" value="yes" />
									<input name="esid" type="hidden" value="{$searchID}" />	
								</xsl:when>
								<xsl:otherwise>
									<input name="ccapAdultCbx" type="hidden" value="yes" />
								</xsl:otherwise>
							</xsl:choose>
						</form>
						<a href="javascript:document.getElementById('{$ccapCourtCaseNumber}').submit();">
							<xsl:value-of select="$ccapCourtCaseNumber" />
						</a>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td><xsl:value-of select="ccap-ext:Case/j:CaseDocketID/j:ID"/></td>
					</xsl:otherwise>
                  </xsl:choose>
                <td>
				  <xsl:apply-templates select="ccap-ext:Case/ccap-ext:CourtCaseFilingDate" mode="FormatFullDateAsMMDDYYYY"/>
                </td>
                <td><xsl:value-of select="j:LocationCountyName"/></td>
                <td><xsl:value-of select="ccap-ext:Case/ccap-ext:CaseStatus/ccap-ext:StatusCodeDescriptionText"/></td>
                <td>
                  <xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyLastName"/>,
                  <xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyGivenName"/>
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="ccap-ext:CaseParty/ccap-ext:PartyName/ccap-ext:PartyMiddleName"/>
                </td>
                <td>
                  <xsl:apply-templates select="ccap-ext:CaseParty/j:PersonBirthDate" mode="FormatYearMonthAsMMYYYY"/>
                </td>
                <td><xsl:value-of select="ccap-ext:Case/j:CaseTitleText"/></td>
              </tr>
            </xsl:for-each>
            <xsl:if test="$from='firearm' and $readOnly != 'true'">
              <tr>
                <td></td>
                <td colspan='7'>
                  <input type="button" class="launch" value="Launch Detail Search" style="display:none" hidden="true"/>
                </td>
              </tr>
            </xsl:if>
          </tbody>
        </table>         
      </xsl:when>
      <xsl:otherwise>
        <p class="tealBold">The response contains white list item(s) only.</p> 
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
</xsl:transform>