
<xsl:stylesheet 
    version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    exclude-result-prefixes="xsl xsi">
    
    <xsl:output method="html"
        version="4.01"
        encoding="UTF-8" 
        omit-xml-declaration="yes"
        indent="yes"
        media-type="text/html"/>
    <xsl:param name="modifierList"/>
    <xsl:param name="transID"/>
   
    <xsl:template match="case">
        <style type="text/css">
            
            p, div{
            padding:0; 
            margin:0;
            }
            
            b{
            color: #04B4AE;
            font-weight: bold;
            }
            
            .newsection {
            margin-top: 15px;
            }
            
            .filetype {
            float: none;  /* Override the float setting inherited from external stylesheets */
            }
            
            .caveat {
            color: teal;  /* Override the color inherited from external stylesheets */
            }
            
            .licensetypetitle {
            text-transform: none;  /* Override inherited uppercase setting */
            }
            
            .blueRegular {
            color: blue;
            }
            
            .redRegular {
            color: red;
            }
            
            .redBold {
            color: red;
            font-weight: bold;
            }
            
            .blackBoldSmall{
            color: black; 
            font-weight: bold; 
            font-size: small; 
            }
            
            .blackBoldSmaller{
            color: black; 
            font-weight: bold; 
            font-size: small; 
            }
            .subjecttitle {
            text-transform: none;  /* Override the text-transform setting inherited from external stylesheets */
            }
            
            .tealRegular{
            color: teal;
            }
            
            .tealSmall{
            color: teal;
            font-size:small;
            }
            
            .tealBold {
            color: teal;
            font-weight: bold;
            }
            
            .tableName {
            padding-right: 20px;
            white-space: nowrap;
            }
            
            .paddingZero{
            padding:0;
            margin:0;
            }
            .tableValue {
            padding-right: 20px;
            text-transform: capitalize;
            }
            
            .width70{
            width:70%; 
            }
            .width60{
            width:60%; 
            }
            .width15{
            width:15%; 
            }
            .width80{
            width:80%; 
            }
            .width20{
            width:20%; 
            }
            .width25{
            width:25%; 
            }
            .width10{
            width:10%; 
            }
            
            .paddingLeft2{
            padding:0;
            margin: 0 0 0 2em;
            }
            .paddingLeft4{
            padding:0;
            margin:0 0 0 4em;
            }
            .paddingLeft6{
            padding:0;
            margin:0 0 0 6em;
            }
            .floatRight{
            float:right;
            }
        </style>
    <div>
        <h3>COURT CASE DISPOSITION DETAILS</h3>
    </div>
    <div>
        <fieldset class="paddingOne">
            <legend>Case Information</legend>
            <div><table style="height:100%; width:80%;" >
                <tr>
                    <td><b>Case #: </b> <xsl:value-of select="normalize-space(@caseNumber)"/></td>
                    <td></td>
                    <td><b>Subject Name: </b> <xsl:value-of select="normalize-space(ccapDefendantInfo/name)"/></td>
                </tr>
            </table></div>
            <xsl:apply-templates select="charge"/>
        </fieldset>        
    </div>
    
    </xsl:template>
    
    
    <xsl:template match="charge">
        <h2 class="tealRegular"><xsl:text>Charge #</xsl:text><xsl:value-of select="chargeCount"/></h2>
        <div><table CELLSPACING="20">
            <tr>
                <td><b>Statute Cite:</b></td>
                <td><xsl:value-of select="normalize-space(statuteCite)"/></td>
                <td><b>Description:</b></td>
                <td colspan="2"><xsl:value-of select="normalize-space(description)"/></td>
                <td colspan="2"><b>Severity Class Code:</b></td>
                <td><xsl:apply-templates select="severityClsCode"/></td>
            </tr>
            <tr>
                <td><b>Charge Count:</b></td>
                <td><xsl:value-of select="chargeCount"/></td>
                <td><b>Offense Date:</b></td>
                <td><xsl:apply-templates select="offenseDate"/></td>
                <td><b>ATN:</b></td>
                <td><xsl:apply-templates select="arrestTrackingNo"/></td>
            </tr>
            <tr>
                <td><b>Arrest ORI:</b></td>
                <td><xsl:apply-templates select="arrestingOri"/></td>
                <td><b>Arrest OCA:</b></td>
                <td><xsl:apply-templates select="arrestCaseNumber"/></td>    
                <td><b>Booking ORI:</b></td>
                <td><xsl:apply-templates select="bookingOri"/></td>
                <td><b>Booking OCA:</b></td>
                <td><xsl:apply-templates select="bookCaseNumber"/></td>
            </tr>
        </table></div>
        <xsl:apply-templates select="modifier"/>
        <xsl:apply-templates select="judgement"/>    
        <hr/>
    </xsl:template>
    
    <xsl:template match="modifier">
        <style type="text/css">         
            .indnt50{
            text-indent: 50px;
            }
        </style>
        <xsl:variable name="modifierCd" select="normalize-space(statuteCite)"/>
        <xsl:variable name="chargeSeqNo" select="normalize-space(parent::charge/chargeCount)"/>
        <xsl:if test="contains($modifierList, concat($modifierCd,$chargeSeqNo))">    
            <div class="indnt50">
            <xsl:attribute name="id">Mod</xsl:attribute>             
            <h3 class="tealRegular indnt50"><xsl:text>Modifier</xsl:text></h3>       
            <table class="indnt50">
            <tr>
                <td><b>Modifier Code:</b></td>
                <td><xsl:value-of select="normalize-space(statuteCite)"/></td>
                <td><b>Modifier Description:</b></td>
                <td><xsl:value-of select="normalize-space(description)"/></td>
                <td>
                    <button>
                        <xsl:attribute name="modifierCd"><xsl:value-of select="$modifierCd"/></xsl:attribute>
                        <xsl:attribute name="chargeSeqNo"><xsl:value-of select="$chargeSeqNo"/></xsl:attribute>
                        <xsl:attribute name="transID"><xsl:value-of select="$transID"/></xsl:attribute>
                        Delete Modifier
                    </button>
                </td>
             </tr>
            </table>        
        </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="judgement">
        <style type="text/css">         
            .indnt50{
            text-indent: 50px;
            }
        </style>
        <h4 class="tealRegular indnt50"><xsl:text>Judgement</xsl:text></h4>
        <div><table  class="indnt50">
            <tr>
                <td><b>Disposition Code:</b></td>
                <td><xsl:value-of select="normalize-space(dispositionCode)"/></td>
                <td><b>Disposition Text:</b></td>
                <td><xsl:value-of select="normalize-space(dispoText)"/></td>
            </tr>
            <tr>
                <td><b>Court Official No.:</b></td>
                <td><xsl:value-of select="normalize-space(dispCtofcNum)"/></td>
                <td><b>Disposition Date:</b></td>
                <td><xsl:value-of select="normalize-space(jdgmtDispoDate)"/></td>          
            </tr>
        </table></div>
        <xsl:apply-templates select="sentence"/>
        <xsl:apply-templates select="probation"/>
        <xsl:apply-templates select="timeCondition"/>
        <xsl:apply-templates select="miscCondition"/>
    </xsl:template>
 
    
    <xsl:template match="sentence">
        <style type="text/css">         
            .indnt100{
            text-indent: 100px;
            }
        </style>
        <h4 class="tealRegular indnt100"><xsl:text>Sentence</xsl:text></h4>
        <div><table class="indnt100">
            <tr>
                <td colspan="3"><b>Begin Date:</b></td>
                <td><xsl:value-of select="normalize-space(beginDate)"/></td>
            </tr>
            <tr>
                <td colspan="3" align="left"><b>Supervising Agency:</b></td>
                <td><xsl:value-of select="normalize-space(supvAgency)"/></td>  
            </tr>
            <tr>
                <td colspan="3"><b>Sentence Code:</b></td>
                <td><xsl:value-of select="normalize-space(sentenceCode)"/></td>
            </tr>
            <tr>
                <td colspan="3"><b>Sentence Text:</b></td>
                <td colspan="3" align="center"><xsl:value-of select="normalize-space(sentenceText)"/></td>
            </tr>
        </table></div>
        
    </xsl:template>
    
    <xsl:template match="probation">
        <style type="text/css">
            .indnt100{
            text-indent: 100px;
            }
        </style>
        <h4 class="tealRegular indnt100"><xsl:text>Probation</xsl:text></h4>
        <table class="indnt100">
            <tr>
                <td><b>Order Date: </b><xsl:value-of select="normalize-space(orderDate)"/></td>
                <td><b>Length: </b><xsl:value-of select="normalize-space(duration)"/></td>
                <td><b>Comments: </b><xsl:value-of select="normalize-space(comments)"/></td>
            </tr>
        </table>
    </xsl:template>
    
    <xsl:template match="timeCondition">
        <style type="text/css">
            .indnt100{
            text-indent: 100px;
            }
        </style>
        <h4 class="tealRegular indnt100"><xsl:text>Time Condition</xsl:text></h4>
        <table class="indnt100">
            <tr>
                <td><b>Begin Date: </b><xsl:value-of select="normalize-space(beginDate)"/></td>
                <td><b>Condition code: </b><xsl:value-of select="normalize-space(conditionCode)"/></td>
                <td><b>Length: </b><xsl:value-of select="normalize-space(duration)"/></td>
                <td><b>Supervising Agency: </b><xsl:value-of select="normalize-space(supvAgency)"/></td>
            </tr>
        </table>
    </xsl:template>
    
    <xsl:template match="miscCondition">
        <style type="text/css">         
            .indnt100{
            text-indent: 100px;
            }
        </style>
        <h4 class="tealRegular indnt100"><xsl:text>Misc Condition</xsl:text></h4>
        <table class="indnt100">
            <tr>
                <td><b>Condition Code: </b><xsl:value-of select="normalize-space(conditionCode)"/></td>
                <td><b>Condition Text: </b><xsl:value-of select="normalize-space(conditionText)"/></td> 
                <td><b>Supervising Agency: </b><xsl:value-of select="normalize-space(supvAgency)"/></td>
            </tr>
        </table>
    </xsl:template>  
    
</xsl:stylesheet>