<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:java="http://xml.apache.org/xalan/java" 
	xmlns:rap="http://nlets.org/niem2/rapsheet/1.0" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cch/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:jj="http://www.it.ojp.gov/jxdm/3.0.2" 
	xmlns:j="http://niem.gov/niem/domains/jxdm/4.1" 
	xmlns:nc="http://niem.gov/niem/niem-core/2.0" 
	xmlns:ansi-nist="http://niem.gov/niem/ansi-nist/2.0" 
	xmlns:s="http://niem.gov/niem/structures/2.0" 
	xmlns:n="http://www.nlets.org" 
	xmlns:nh2="http://www.nlets.org/niem/nlets-hdr/1.0" 
	xmlns:n2="http://www.nlets.org/niem/1.0" 
	exclude-result-prefixes="xsl rap jj j java doj doj-ext nc ansi-nist s n nh2 n2">
	
	<xsl:import href="raputility.xsl"/>
	<xsl:import href="../common.xsl"/>
	<xsl:import href="../css.xsl"/>
	
	<xsl:output method="html"/>
	<xsl:param name="currentDate"/>
	<xsl:param name="readOnly"/>
	<xsl:param name="executionUrl">/</xsl:param>
	<xsl:param name="imageBase">
		<xsl:text>../../images/</xsl:text>
	</xsl:param>
	<xsl:param name="from"/>
	<xsl:param name="responseId">
		<xsl:value-of select="doj:CCHResponseDocument/@doj-ext:responseID"/>
	</xsl:param>
	<xsl:param name="imageServlet"></xsl:param>
	
	
	<!-- START HERE - root match-->
	<xsl:template match="/">
		<!-- <xsl:call-template name="html_body"/> -->
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension"/>
				<xsl:call-template name="html_body"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">RapSheet</xsl:template>
	
	
	<xsl:template name="html_head_extension">
		<xsl:call-template name="rapsheet_css"/>
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:choose>
			<xsl:when test="doj:CCHResponseDocument/doj:Result/doj:ResultText">
				<xsl:value-of select="doj:CCHResponseDocument/doj:Result/doj:ResultText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:CCHResponseDocument"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
 	<!-- Main controlling template -->
	<xsl:template match="doj:CCHResponseDocument">
		<div><xsl:call-template name="subheader"/></div>
		<div><xsl:call-template name="title"/></div>
		<!-- <div></div> -->
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="header_flag_section"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:Introduction | doj:Result/doj:NonAutomated/rap:RapSheet/rap:Introduction"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="caution_other"/>
			<!-- <br/> -->
		</div>
		<div><xsl:call-template name="header_buttons"/></div>
		<div><hr/></div>
		<a name="identification{$responseId}"></a>
		<div class="identification"><xsl:text>Identification</xsl:text></div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="caution_death"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="subject_details"/>
		</div>
		<div><hr/></div>
		<xsl:if test="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetCycle">
			<a name="history{$responseId}"></a>
			<!-- <div class="criminal_history"><xsl:text>Criminal History</xsl:text></div> --><!-- <p/> -->
			<span class="criminal_history">Criminal History</span><p/>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetCycle"/>
			<div><hr/></div>
		</xsl:if>
		<xsl:call-template name="contributing_agency"/>
	</xsl:template>
	
	
	<!-- images under navigation bar -->
	<xsl:template name="subheader">
		<div align="right">
			<xsl:element name="img">
				<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'cib3_small.png')"/></xsl:attribute>
				<xsl:attribute name="alt">ciblogo</xsl:attribute>
				<xsl:attribute name="width">50</xsl:attribute>
				<xsl:attribute name="height">50</xsl:attribute>
			</xsl:element>
			<xsl:element name="img">
				<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'spacer.gif')"/></xsl:attribute>
				<xsl:attribute name="alt"></xsl:attribute>
				<xsl:attribute name="width">100</xsl:attribute>
				<xsl:attribute name="height">1</xsl:attribute>
			</xsl:element>
		</div>
	</xsl:template>
	
	
	<!-- Page title and current date -->
	<xsl:template name="title">
		<p/>
		<table width="100%">
		<tr>
			<!-- <td class="wisconsin_criminal_history" width="70%">Wisconsin Criminal History</td> -->
			<td class="wisconsin_criminal_history width75percent">Wisconsin Criminal History</td>
			<td class="reported_date">
				<xsl:text>Date: </xsl:text>
				<xsl:if test="$from='armsweb'">
					<xsl:value-of select="$currentDate"/>
				</xsl:if>
				<xsl:if test="$from != 'armsweb'">
					<xsl:call-template name="currentDate"/>
				</xsl:if>
			</td>
		</tr>
		</table>
		<!-- <br/> -->
		<p/>
	</xsl:template>
	
	
	<!-- flags -->
	<xsl:template match="rap:RapSheetPerson" mode="header_flag_section">
		<table class="flag">
		<xsl:if test="j:PersonAugmentation/j:PersonFirearmSalesDisqualifiedCode = 'D'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'firearmDisqualifier.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">gun</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Firearm&#32;Sale&#32;Disqualified&#32;</xsl:text>
					<xsl:apply-templates select="j:PersonAugmentation/j:PersonFirearmSalesDisqualifiedCode[.='D']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<xsl:if test="j:SubjectOffenderNoticeText = 'Convicted Felon'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'convictedfelon.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">felon</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Convicted Felon </xsl:text>
					<xsl:apply-templates select="j:SubjectOffenderNoticeText[.='Convicted Felon']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<xsl:if test="j:PersonAugmentation/j:PersonRegisteredOffenderIndicator = 'true'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'sexOffender.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">sex_offender</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Registered&#32;Sex&#32;Offender&#32;</xsl:text>
					<xsl:apply-templates select="j:PersonAugmentation/j:PersonRegisteredOffenderIndicator[.='true']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<!-- Arrest DNA is on File -->
		<!-- Conviction DNA is on File -->
		<!-- DNA Collection Needed – (One of SAFE team, Crime Lab, Missed Collection) -->
		<!-- No DNA Sample on File -->
		<xsl:for-each select="j:SubjectOffenderNoticeText">
			<xsl:if test="contains(.,'DNA')='true'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'dna2.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">dna</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:apply-templates select="."/>
					<xsl:apply-templates select="." mode="all_attributes"/>
				</td>
			</tr>
			</xsl:if>
			<xsl:if test="contains(.,'Conviction DNA is on File')='true'">
				<input type="hidden" id="convictionDNAIsOnFile" />
			</xsl:if>
		</xsl:for-each>
				
		<!-- DNA Form Link -->
		<xsl:if test="$from='ebc'">
		<tr>
			<td>
				<xsl:text>&#160;&#160;</xsl:text>
				<xsl:element name="img">
					<xsl:attribute name="class">flag_img</xsl:attribute>
					<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'dna2.gif')"/></xsl:attribute>
					<xsl:attribute name="alt">dna</xsl:attribute>
					<xsl:attribute name="width">40</xsl:attribute>
					<xsl:attribute name="height">32</xsl:attribute>
				</xsl:element>
				<xsl:variable name="lastName" select="nc:PersonName/nc:PersonSurName" />
				<xsl:variable name="firstName" select="nc:PersonName/nc:PersonGivenName" />
				<xsl:variable name="middleName" select="nc:PersonName/nc:PersonMiddleName" />
				<xsl:variable name="gender" select="rap:PersonSexText" />
				<xsl:variable name="race" select="rap:PersonRaceText" />
				<xsl:variable name="dob" select="nc:PersonBirthDate/nc:Date" />
				<xsl:variable name="dobMM" select="substring($dob,6,2)" />
				<xsl:variable name="dobDD" select="substring($dob,9,2)" />
				<xsl:variable name="dobYYYY" select="substring($dob,1,4)" />
				<xsl:variable name="sid">
					<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/j:IdentificationJurisdictionNCICLSTACode"/>
					<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/nc:IdentificationID"/>
				</xsl:variable>
				<form id="DNASubmissionForm" action="/secure/personsearch/dna_submission_form.jsp" method="post" style="display:inline" target="_blank">
					<input name="whatToDO" type="hidden" value="showForm" />
					<input name="firstArrest" type="hidden" value="false" />
					<input name="lastName" type="hidden" value="{$lastName}" />
					<input name="firstName" type="hidden" value="{$firstName}" />
					<input name="middleName" type="hidden" value="{$middleName}" />
					<input name="gender" type="hidden" value="{$gender}" />
					<input name="race" type="hidden" value="{$race}" />
					<input name="dob" type="hidden" value="{$dob}" />
					<xsl:if test="$dob">
						<input name="dobMM" type="hidden" value="{$dobMM}" />
						<input name="dobDD" type="hidden" value="{$dobDD}" />
						<input name="dobYYYY" type="hidden" value="{$dobYYYY}" />
					</xsl:if>
					<input name="sid" type="hidden" value="{$sid}" />
				</form>
				<!--'Conviction DNA on file'-->
				<script type="text/javascript">
					function submitDNAForm() {
						if (document.getElementById('convictionDNAIsOnFile')) {
							alert("Additional DNA Sample Not Required");
						} else {
							document.getElementById('DNASubmissionForm').submit();
						}
					}
				</script>
				<a href="javascript:submitDNAForm();">Click here to create the DNA Submission Form</a>
			</td>
		</tr>
		</xsl:if>
		
		</table>
	</xsl:template>
	
	
	<!-- Introduction -->
	<xsl:template match="rap:Introduction">
		<p/>
		<table border="0">
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Purpose Code:</xsl:text>
			</td>
			<td class="purpose_code width75percent">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:PurposeCode"/>
			</td>
		</tr>
		<xsl:if test="$from!='armsweb'">
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Attention:</xsl:text>
			</td>
 			<td class="purpose_code width75percent mixedcase">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:Attention"/>
			</td>
			<!-- <td class="purpose_code width75percent">
				<xsl:value-of select="rap:RapSheetRequest"/>
			</td> -->
		</tr>
		</xsl:if>
		</table>
		<p/>
		<xsl:apply-templates select="rap:Caveat"/>
	</xsl:template>
	
	
	<!-- Caveat -->
	<xsl:template match="rap:Caveat">
		<table border="0">
		<tr>
			<td class="caveat"><xsl:value-of select="nc:CaveatText"/></td>
		</tr>
		</table>
		<p/>
	</xsl:template>
	
	
	<xsl:template match="rap:RapSheetPerson" mode="caution_other">
		<table>
 		<xsl:if test="rap:SubjectCautionInformationText != 'Convicted Felon'">
			<tr>
				<td class="caution width10percent" valign="top">
					<xsl:text>CAUTION:</xsl:text>
				</td>
				<td class="caution width75percent" valign="top" colspan="2">
					<xsl:for-each select="rap:SubjectCautionInformationText">
						<xsl:value-of select="."/>
						<br/>
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
		</table>
	</xsl:template>
	
	
	<!-- buttons under caveat-->
	<xsl:template name="header_buttons">
		<div align="center">
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#identification{$responseId}">Identification</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
			<xsl:if test="//doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetCycle">
				<span style="background-color: blue;">
					&#160;<a style="color: white; font-size: medium" href="#history{$responseId}">Criminal History</a>&#160;
				</span>
				<xsl:text>&#160;&#160;</xsl:text>
			</xsl:if>
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#contributing{$responseId}">Contributing Agencies</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
			<span style="background-color: blue;">
				&#160;<a style="color: white; font-size: medium" href="#request{$responseId}">Your Request</a>&#160;
			</span>
			<xsl:text>&#160;&#160;</xsl:text>
		</div>
	</xsl:template>
	
	
	<!-- Subject Caution Information and Death Information -->
	<xsl:template match="rap:RapSheetPerson" mode="caution_death">
		<table width="100%">
		<tr>
			<td class="death_living" colspan="2">
				<xsl:for-each select="nc:PersonLivingIndicator">
					<xsl:text>Living status:&#160;</xsl:text>
					<xsl:choose>
						<xsl:when test=".='true'">
							<xsl:text>LIVING</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>DECEASED</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="." mode="reportedDate"/>
					<xsl:apply-templates select="." mode="reportingOrganizationText"/>
					<xsl:apply-templates select="." mode="commentText"/>
					<br/>
				</xsl:for-each>
				<xsl:for-each select="nc:PersonDeathDate">
					<xsl:text>Death date:&#160;</xsl:text>
					<xsl:apply-templates select="nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
					<br/>
				</xsl:for-each>
			</td>
		</tr>
		</table>
	</xsl:template>
	
	
	<!-- Controlling template for subject details -->
	<xsl:template match="rap:RapSheetPerson" mode="subject_details">
		<table width="100%">
		<tr>
			<td class="width80percent">
				<table width="100%">
				<xsl:apply-templates select="nc:PersonName" mode="subject_name"/>
				<tr>
					<td colspan="2">
						<div class="detailvalue">
							<xsl:apply-templates select="." mode="gender_race"/>
							<xsl:apply-templates select="." mode="birth_location_and_social"/>
							<xsl:apply-templates select="nc:PersonBirthDate"/>
							<xsl:apply-templates select="." mode="height_to_blood"/>
							<xsl:apply-templates select="../nc:Location" mode="subject_residence"/>
						</div>
					</td>
				</tr>
				</table>
			</td>
			<td class="width20percent centered_top" align="right">
				<br/>
				<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage" mode="image"/>
			</td>
		</tr>
		<tr>
			<td><br/></td>
			<td></td>
		</tr>
		</table>
		<!-- <xsl:call-template name="SMT_Photo_Links"/> -->
		<xsl:apply-templates select="." mode="ssn_to_notice"/>
		<xsl:apply-templates select="nc:PersonPhysicalFeature" mode="subject_physical"/>
		<xsl:apply-templates select="." mode="alias_name"/>
		<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage" mode="photo_info"/>
	</xsl:template>
	
	
	<!-- Matches any element - if element has reportedDate attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportedDate">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="nc:ReportedDate/nc:Date">
			<xsl:text>as of&#160;</xsl:text>
			<xsl:apply-templates select="nc:ReportedDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Matches any element - if element has reportingOrganizationText attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportingOrganizationText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:reportingOrganizationText">
			<xsl:text>reported by&#160;</xsl:text>
			<xsl:value-of select="@j:reportingOrganizationText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Matches any element - if element has commentText attribute it attaches a phrase -->
	<xsl:template match="*" mode="commentText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:commentText">
			<xsl:text>--</xsl:text>
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="@j:commentText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- an alternate way to display attributes -->
	<xsl:template match="*" mode="all_attributes">
		<xsl:apply-templates select="." mode="reportedDate"/>
		<xsl:apply-templates select="." mode="reportingOrganizationText"/>
		<xsl:apply-templates select="." mode="commentText"/>
	</xsl:template>
	
	
	<!-- If calling template has match containing person name information, name will print out -->
	<xsl:template name="person_type">
		<xsl:if test="nc:PersonNamePrefixText">
			<xsl:for-each select="nc:PersonNamePrefixText">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonGivenName">
			<xsl:value-of select="nc:PersonGivenName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonMiddleName">
			<xsl:for-each select="nc:PersonMiddleName">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonSurName">
			<xsl:value-of select="nc:PersonSurName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonNameSuffixText">
			<xsl:for-each select="nc:PersonNameSuffixText">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<!-- *********** In Java do not create full name if other names are present *************
		<xsl:if test="nc:PersonFullName">
			<xsl:value-of select="nc:PersonFullName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if> -->
	</xsl:template>
	
	
	<!-- Elements of type "LocationType" can have their info printed here-->
	<xsl:template match="j:EmploymentLocation | nc:Location | j:PersonBirthLocation | nc:OrganizationLocation">
		<xsl:variable name="metadataid">
			<xsl:value-of select="@s:metadata"/>
		</xsl:variable>
		
		<!-- ************* What to replace with? -->
		<xsl:if test="j:LocationName">
			<xsl:apply-templates select="j:LocationName" mode="TitleCase"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:AddressFullText">
			<xsl:apply-templates select="nc:LocationAddress/nc:AddressFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationStreet/nc:StreetFullText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationStreet/nc:StreetFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:AddressSecondaryUnitText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:AddressSecondaryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:AddressMailDeliveryUnitText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:AddressMailDeliveryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCityName">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCityName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountyName">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountyName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationStateName">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationStateName"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationPostalCode">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationPostalCode"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountryName">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountryName"/>			
		</xsl:if>
		
		<xsl:if test="nc:LocationContactInformation">
			<xsl:text>Contact information:&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationContactInformation/nc:ContactInformationDescriptionText">
			<xsl:value-of select="nc:LocationContactInformation/nc:ContactInformationDescriptionText"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactTelephoneNumber">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactFaxNumber">
			<xsl:if test="position() = 1">
				<xsl:text>Fax:</xsl:text>
			</xsl:if>
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactEmailID">
		<a href="mailto:{.}"><xsl:value-of select="."/></a>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:apply-templates select="//rap:RapSheet/rap:Metadata[@s:id=$metadataid]" mode="reportedDate"/>
	</xsl:template>
	
	
	<!-- name of subject -->
	<xsl:template match="nc:PersonName" mode="subject_name">
		<xsl:if test="position()=1">
			<tr>
				<td class="subject_name">
					<xsl:call-template name="person_type"/>
				</td>
				<td align="center">
					<xsl:if test="../nc:PersonAlternateName">
						<a href="#alias{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="border">0</xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/></xsl:attribute>
								<xsl:attribute name="alt">aliases</xsl:attribute>
							</xsl:element>
						</a>
					</xsl:if>
				</td>
			<br/>
			</tr>
		</xsl:if>
	</xsl:template>
	
	
	<!-- gender and race of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="gender_race">
		<xsl:for-each select="rap:PersonSexText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_separator"/>
			<xsl:text>/</xsl:text>
			<xsl:call-template name="if_last_then_separator"/>
		</xsl:for-each>	
		
		<xsl:for-each select="rap:PersonRaceText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		<br/>
	</xsl:template>
	
	
	<!-- birth location and social details of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="birth_location_and_social">
		<xsl:for-each select="nc:PersonBirthLocation">
			<xsl:call-template name="if_first_then_label">
				<xsl:with-param name="label" select="'Born in&#160;'"/>
			</xsl:call-template>
			<xsl:apply-templates select="nc:LocationName" mode="TitleCase"/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:PersonCitizenshipText">
			<xsl:call-template name="if_first_then_label">
				<xsl:with-param name="label" select="'Citizen of&#160;'"/>
			</xsl:call-template>
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonEthnicityText">
			<xsl:apply-templates select="." mode="TitleCase"/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:PersonMaritalStatusText">
			<xsl:apply-templates select="." mode="TitleCase"/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:PersonReligionText">
			<xsl:apply-templates select="." mode="TitleCase"/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		<xsl:call-template name="if_last_then_break"/>
	</xsl:template>
	
	
	<!-- birthdate of subject -->
	<xsl:template match="nc:PersonBirthDate">
		<xsl:apply-templates select="nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
		<xsl:call-template name="if_not_last_then_separator"/>
		<xsl:call-template name="if_last_then_break"/>
	</xsl:template>
	
	
	<!-- height, weight, eye color, hair color, skin tone, and blood type of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="height_to_blood">
		<xsl:for-each select="nc:PersonHeightMeasure/nc:MeasureText">
			<xsl:value-of select="substring(.,1,1)"/>
			<xsl:text>'</xsl:text>
			<xsl:value-of select="substring(.,2,2)"/>
			<xsl:text>"</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:PersonWeightMeasure/nc:MeasureText">
			<xsl:value-of select="."/>
			<xsl:text>lbs</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonEyeColorText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Eyes</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonHairColorText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Hair</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonSkinToneText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Skin Tone</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonBloodTypeText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		<xsl:call-template name="if_last_then_break"/>
	</xsl:template>
	
	
	<!-- residence of subject -->
	<xsl:template match="nc:Location" mode="subject_residence">
	 	<xsl:apply-templates select="."/>
		<xsl:apply-templates select="." mode="reportedDate"/>
		<!-- xsl:call-template name="if_not_last_then_separator"/ -->
	</xsl:template>
	
	
	<!-- links under state ID and FBI number -->
	<xsl:template name="SMT_Photo_Links">
		<table width="100%">
		<tr>
			<td class="width50percent centered no_decoration">
				<a href="#smt{$responseId}">
					<xsl:element name="img">
						<xsl:attribute name="border">0</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'scarsMarksTattoos.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">SMT</xsl:attribute>
					</xsl:element>
				</a>
			</td>
			<td class="width50percent centered no_decoration">
				<a href="#photo{$responseId}">
					<xsl:element name="img">
						<xsl:attribute name="border">0</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'photoInformation.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">photo</xsl:attribute>
					</xsl:element>
				</a>
			</td>
		</tr>
		</table>
	</xsl:template>
	
	
	<!-- SSN, Misc #, Driver License, fingerprint, palm print, AFIS, DNA, Employer, Occupation, Employment, Offender Notice -->
	<xsl:template match="rap:RapSheetPerson" mode="ssn_to_notice">
		<table>
 		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FBI:'"/>
				<xsl:with-param name="value">
					<xsl:value-of select="j:PersonAugmentation/j:PersonFBIIdentification/nc:IdentificationID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'SOCIAL SECURITY #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="nc:PersonSSNIdentification">
						<xsl:value-of select="substring(nc:IdentificationID,1,3)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(nc:IdentificationID,4,2)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(nc:IdentificationID,6,4)"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</tr>
		
 		<tr>
			<xsl:if test="j:PersonAugmentation/j:PersonStateFingerprintIdentification/nc:IdentificationID">
				<td class="black_header width20percent">
					<xsl:text>STATE ID:</xsl:text>
				</td>
				<td class="detailvalue width25percent" style="white-space: nowrap;">
					<xsl:variable name="sid">
						<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/nc:IdentificationID"/>
					</xsl:variable>
					<xsl:value-of select="$sid"/>
					<xsl:text>&#32;</xsl:text>
					<!-- Only display the Full Record hyperlink if this is an EBC Ident response -->
					<xsl:if test="$from='ebc' and ancestor::doj:Result/doj:MessageKeyCode='IR'">
						<xsl:variable name="rapSheetRequest" select="ancestor::rap:RapSheet/rap:Introduction/rap:RapSheetRequest"/>
						<xsl:variable name="purposeCd" select="$rapSheetRequest/rap:PurposeCode"/>
						<xsl:variable name="attention" select="$rapSheetRequest/rap:Attention"/>
						<xsl:variable name="oboORI" select="/doj:CCHResponseDocument/doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID"/>
						<form id="fullRecordRequest_{$sid}" action="/secure/personsearch/buildcchfq.jsp" method="post" style="display:inline">
							<input name="sid" type="hidden" value="{$sid}"/>
							<xsl:if test="$purposeCd">
								<input name="pur" type="hidden" value="{$purposeCd}"/>
							</xsl:if>
							<xsl:if test="$attention">
								<input name="attn" type="hidden" value="{$attention}"/>
							</xsl:if>
							<xsl:if test="$oboORI">
								<input name="ori" type="hidden" value="{$oboORI}"/>
							</xsl:if>
							<xsl:if test="/doj:CCHResponseDocument/doj:Result/doj:Automated/rap:RapSheet/rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage/nc:BinaryBase64Object">
								<input name="includeImages" type="hidden" value="yes"/>
							</xsl:if>
						</form>
						<a href="javascript:document.getElementById('fullRecordRequest_{$sid}').submit();">Click here to submit Full Record</a>
					</xsl:if>
					<xsl:if test="$sid !='Unknown' and $from='firearm' and $readOnly!='true'">
						<xsl:variable name="leftCurlyBrace">{</xsl:variable>
						<xsl:variable name="rightCurlyBrace">}</xsl:variable>
						<xsl:element name="a">
							<xsl:attribute name="url"><xsl:value-of select="$executionUrl"/><xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:attribute name="id"><xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:attribute name="class">fullRapSheet</xsl:attribute>
							<xsl:attribute name="href">#<xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:text>Click here to Submit Full Record </xsl:text>
						</xsl:element>
					</xsl:if>
				</td>
			</xsl:if>

			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'MISCELLANEOUS #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="nc:PersonOtherIdentification">
						<xsl:value-of select="nc:IdentificationCategoryText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationJurisdictionText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
					<xsl:for-each select="rap:PersonCorrectionsIdentification">
						<xsl:text>CORRECTIONS-</xsl:text>
						<xsl:value-of select="j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width30percent'"/>
			</xsl:call-template>
		</tr>
		</table>
		
		<table>
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'DRIVERS LICENSE #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:PersonAugmentation/nc:DriverLicense/nc:DriverLicenseIdentification">
						<xsl:value-of select="j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FINGERPRINT CLASS:'"/>
				<xsl:with-param name="value">
					<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/rap:PersonFingerprintSet"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		
		<xsl:for-each select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/j:PersonPalmPrint">
			<tr>
				<td valign="top" class="black_header width25percent">PALM PRINT, ORI and LITERAL:</td>
				<td class="detailvalue" valign="top">
					<xsl:value-of select="nc:BiometricImage/nc:BinaryCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="nc:BiometricImage/nc:BinaryCapturer/rap:EntityOrganization/nc:OrganizationName"/>
				</td>
				<td valign="top">
					<!-- img src="images/palm" alt=""/ -->
				</td>
			</tr>
		</xsl:for-each>
		
		<xsl:for-each select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:Fingerprint/j:FingerprintFingerText">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'AFIS CLASSIFICATION:'"/>
					<xsl:with-param name="value" select="."/>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<xsl:for-each select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/rap:PersonDNA">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'DNA:'"/>
					<xsl:with-param name="value">
						<xsl:if test="nc:BiometricEncodingMethodText != 'UNKNOWN'">
							<xsl:text>Method:&#32;</xsl:text>
							<xsl:value-of select="nc:BiometricEncodingMethodText"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<xsl:for-each select="nc:BiometricDescriptionText">
							<xsl:if test="position()=1">
								<xsl:text>Description:&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="."/>
							<xsl:call-template name="if_not_last_then_separator"/>
							<xsl:if test="position() = last()">
								<xsl:text>,</xsl:text>
							</xsl:if>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
						<xsl:if test="nc:BiometricCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID">
							<xsl:text>Agency:&#32;</xsl:text>
							<xsl:value-of select="nc:BiometricCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<!-- xsl:text>Name:&#32;</xsl:text -->
						<xsl:value-of select="nc:BiometricCapturer/rap:EntityOrganization/nc:OrganizationName"/>
						<xsl:text>,&#32;</xsl:text>
						<xsl:if test="nc:BiometricCaptureDate">
							<xsl:text>Date:&#32;</xsl:text>
							<xsl:apply-templates select="nc:BiometricCaptureDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
							<xsl:text>&#32;</xsl:text>
						</xsl:if>
						<xsl:for-each select="nc:BiometricValueText">
							<xsl:if test="position() = 1">
								<xsl:text>Locus(Type/Value(s)):&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="."/>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<!-- Employment Info -->
		<xsl:for-each select="../nc:PersonEmploymentAssociation/nc:Employer">
			<xsl:variable name="position">
				<xsl:value-of select="position()"/>
			</xsl:variable>
			<xsl:variable name="locationId">
				<xsl:value-of select="../nc:EmploymentLocationReference[$position]/@s:ref"></xsl:value-of>
			</xsl:variable>
			<xsl:variable name="location">
			</xsl:variable>
			<xsl:variable name="label">
				<xsl:choose>
					<xsl:when test="$position=1">
						<xsl:text>EMPLOYER:</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<!-- <tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/>
						<xsl:text> - </xsl:text>
						<xsl:apply-templates select="//nc:Location[@s:id=$locationId]"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr> -->
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="''"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="//nc:Location[@s:id=$locationId]"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			
		</xsl:for-each>
		
		<!-- Occupation Info -->
		<xsl:for-each select="../nc:PersonEmploymentAssociation/nc:EmployeeOccupationText">
			<xsl:variable name="label">
				<xsl:choose>
					<xsl:when test="position()=1">
						<xsl:text>OCCUPATION:</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="." mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'OFFENDER NOTICE:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:SubjectOffenderNoticeText">
						<xsl:value-of select="."/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:call-template name="if_last_then_break"/>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		</table>
	</xsl:template>
	
	
	<!-- SMT of subject -->
	<xsl:template match="nc:PersonPhysicalFeature" mode="subject_physical">
		<a name="smt{$responseId}"></a>
		<xsl:if test="position()=1">
			<table width="100%">
			<tr>
				<td class="black_header width100percent">
					<xsl:text>SCARS MARKS TATTOOS DATA:&#32;</xsl:text>
					<br/>
				</td>
			</tr>
			</table>
		</xsl:if>
		
		<table width="100%">
		<tr>
			<td class="width75percent detailvalue">
				<xsl:if test="nc:PhysicalFeatureCategoryText">
					<xsl:apply-templates select="nc:PhysicalFeatureCategoryText" mode="TitleCase"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				
				<!-- ******** Not in NIEM ************
				<xsl:if test="j:PhysicalFeatureTypeCode">
					<xsl:apply-templates select="j:PhysicalFeatureTypeCode" mode="TitleCase"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if> -->
				<xsl:if test="nc:PhysicalFeatureDescriptionText">
					<xsl:text>---</xsl:text>
					<xsl:apply-templates select="nc:PhysicalFeatureDescriptionText" mode="TitleCase"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				
				<!-- *************** Not showing up in GJXDM responses *************
				<xsl:if test="nc:PhysicalFeatureImage/nc:BinaryCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID">
					<xsl:value-of select="nc:PhysicalFeatureImage/nc:BinaryCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
					<xsl:text>&#32;</xsl:text>
				</xsl:if>
				<xsl:apply-templates select="nc:PhysicalFeatureImage/nc:BinaryCapturer/rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/> -->
			</td>
			<td class="width25percent">
				<!-- img src="images/smtimage" alt=""/ -->
			</td>
		</tr>
		</table>
		<!-- <xsl:call-template name="if_last_then_break"/>
		<xsl:call-template name="if_last_then_break"/> -->
	</xsl:template>
	
	
	<!-- alias names of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="alias_name">
		<xsl:if test="nc:PersonAlternateName">
			<a name="alias{$responseId}"></a>
			<table width="100%">
			<tr>
				<td class="black_header width100percent">
					<xsl:text>ALIAS NAMES/FRAUDULENT DATA:&#32;</xsl:text>
					<br/>
				</td>
			</tr>
			<tr>
				<td><xsl:call-template name="listAlias"/></td>
			</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="nc:PersonAlternateName[position() mod 2 != 0]">
				<xsl:sort select="nc:PersonSurName" data-type="text" order="ascending"/>
				<xsl:sort select="nc:PersonGivenName" data-type="text" order="ascending"/>
				<xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
				<tr>
					<td class="detailvalue width20percent">
						<xsl:if test="$startposition = 1">
							<xsl:text>Alias Names:</xsl:text>
						</xsl:if>
					</td>
					<xsl:apply-templates select="../nc:PersonAlternateName" mode="aliasNames">
						<xsl:sort select="nc:PersonSurName" data-type="text" order="ascending"/>
						<xsl:sort select="nc:PersonGivenName" data-type="text" order="ascending"/>
						<xsl:with-param name="startposition" select="$startposition"/>
					</xsl:apply-templates>
					<td class="detailvalue width20percent"/>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
	
	
	<xsl:template match="nc:PersonAlternateName" mode="aliasNames">
		<xsl:param name="startposition"/>
		<xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
			<td class="detailvalue width30percent">
				<xsl:call-template name="person_type"/>
			</td>
		</xsl:if>
	</xsl:template>
	
	
	<!-- photo information -->
	<xsl:template match="nc:PersonDigitalImage" mode="photo_info">
		<a name="photo{$responseId}"></a>
		<xsl:if test="position()=1">
			<table width="100%">
			<tr>
				<td class="black_header width100percent">
					<xsl:text>PHOTO INFORMATION:</xsl:text>
					<br/>
				</td>
			</tr>
			</table>
		</xsl:if>
		
		<xsl:if test="not(nc:BinaryBase64Object)">
			<table width="100%" class="detailvalue">
			<tr>
				<td class="width15percent">
					<xsl:apply-templates select="nc:BinaryCaptureDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
				</td>
				<td class="width65percent">
					<xsl:value-of select="nc:BinaryCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
					<xsl:text>&#160;&#160;&#160;</xsl:text>
					<xsl:apply-templates select="nc:BinaryCapturer/rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/>
				</td>
				<td class="width20percent">
					<!-- img src="images/mugshot" alt=""/> -->
				</td>
			</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Controlling template for cycle info -->
	<xsl:template match="rap:RapSheetCycle">
		<span class="cycle">
			<p/>Cycle<xsl:text>&#32;</xsl:text><xsl:number value="position()"/>
			<br/>
		</span>
		
		<xsl:if test="rap:CycleEarliestDate">
			<span class="history_black_header">EARLIEST EVENT DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CycleEarliestDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:CycleTrackingIdentificationID">
			<!-- Only for Arrest so no problem stating ARREST here... -->
			<span class="history_black_header">ARREST TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:CycleTrackingIdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:Incident/nc:ActivityDate/nc:Date">
			<span class="history_black_header">DATE OF OFFENSE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:Incident/nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:apply-templates select="rap:Arrest"/>
		<xsl:apply-templates select="rap:JuvenileActivity"/>
		<xsl:apply-templates select="rap:Booking"/>
		<xsl:apply-templates select="rap:JuvenileActivity/rap:JuvenileActivityCharge"/>
		<xsl:apply-templates select="rap:Arrest/rap:ArrestCharge"/>
		<xsl:if test="rap:Arrest/nc:ActivityReasonText">
			<xsl:call-template name="DNAAtArrest"/>
		</xsl:if>
		<xsl:apply-templates select="rap:Prosecution"/>
		<xsl:apply-templates select="rap:Prosecution/rap:ProsecutionCharge"/>
		<xsl:for-each select="rap:CourtAction">
			<xsl:if test="position()=1">
				<xsl:apply-templates select="."/>
			</xsl:if>
		</xsl:for-each>
		<xsl:for-each select="rap:CourtAction/rap:CourtCharge">
			<xsl:sort select="j:ChargeSequenceID" data-type="text" order="ascending"/>
			<xsl:if test="j:ChargeSequenceID">
				<xsl:apply-templates select="."/>
			</xsl:if>
		</xsl:for-each>
		<xsl:apply-templates select="rap:Sentencing"/>
		<xsl:apply-templates select="rap:Supervision"/>
	</xsl:template>
	
	
	<!-- Arrest/JuvenileActivity -->
	<xsl:template match="rap:Arrest | rap:JuvenileActivity">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="juv_agency_association" 
					  select="//rap:JuvenileActivityAgencyAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		<xsl:variable name="arrest_agency_association" 
					  select="//rap:ArrestAgencyAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		
		<br/>
		<span class="major_history_header">ARREST DATA</span>
		<br/>
		
		<xsl:call-template name="indent"/>
		<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
		<span class="arrest_name">
			<xsl:choose>
				<xsl:when test="*/rap:SubjectFullName">
					<xsl:apply-templates select="*/rap:SubjectFullName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="//rap:RapSheet/rap:RapSheetPerson/nc:PersonName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:otherwise>
			</xsl:choose>
			<br/>
		</span>
		
		<xsl:if test="nc:ActivityCategoryText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TYPE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityCategoryText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ArrestAgencyRecordIdentification/nc:IdentificationID or 
					  rap:JuvenileActivityAgencyRecordIdentification/nc:IdentificationID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ArrestAgencyRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<xsl:apply-templates select="rap:JuvenileActivityAgencyRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
 		<xsl:if test="$arrest_agency_association or $juv_agency_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">ARREST AGENCY:&#160;&#160;</span>
			<xsl:if test="$arrest_agency_association">
				<xsl:apply-templates select="//rap:Agency[@s:id=$arrest_agency_association/nc:OrganizationReference/@s:ref]"/>
			</xsl:if>
			<xsl:if test="$juv_agency_association">
				<xsl:apply-templates select="//rap:Agency[@s:id=$juv_agency_association/nc:OrganizationReference/@s:ref]"/>
			</xsl:if>
		</xsl:if>
		
		<xsl:if test="rap:ArrestSubject/j:SubjectIdentification/nc:IdentificationID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ArrestSubject/j:SubjectIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Booking -->
	<xsl:template match="rap:Booking">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="booking_agency_association" 
					  select="//rap:BookingAgencyAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		
		<span class="minor_history_header">BOOKING</span>
		<br/>
		
		<xsl:if test="j:BookingAgencyRecordIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:BookingAgencyRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
 		<xsl:if test="$booking_agency_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Agency[@s:id=$booking_agency_association/nc:OrganizationReference/@s:ref]"/>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Arrest/Booking Agency ORI and Name -->
	<xsl:template match="rap:Agency | rap:Court | j:ArrestAgency | j:BookingAgency | j:Court | j:SupervisionAgency">
		<span class="history_data">
			<xsl:choose>
				<xsl:when test="j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID='UNKNOWN'">
					<xsl:apply-templates select="j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID" mode="history_unbounded"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID" mode="history_unbounded"/>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:apply-templates select="nc:OrganizationName" mode="history_unbounded"/>
				</xsl:otherwise>
			</xsl:choose>
			<br/>
		</span>
	</xsl:template>
	
	
	<!-- ArrestCharge/ProsecutionCharge/CourtCharge/SupervisionCharge -->
	<xsl:template match="rap:ArrestCharge | rap:JuvenileActivityCharge | rap:ProsecutionCharge | rap:CourtCharge | rap:SupervisionCharge">
		<span class="minor_history_header">CHARGE</span>
		<br/>
		
		<xsl:if test="j:ChargeSequenceID">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SEQUENCE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSequenceID/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeTrackingIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeTrackingIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:apply-templates select="rap:ChargeStatute"/>
		<xsl:apply-templates select="." mode="literal_to_comments"/>
	</xsl:template>
	
	<!-- DNA at ARREST -->
	<xsl:template name="DNAAtArrest">
		<xsl:variable name="ref_id">
			<xsl:value-of select="rap:Arrest/nc:ActivityReasonText"/>
		</xsl:variable>
		<xsl:variable name="person_dna" select="//rap:PersonBiometricsAssociation/rap:PersonBiometrics/rap:PersonDNA[@s:id=$ref_id]"/>
		
		<span class="minor_history_header">DNA at ARREST</span>
		<br/>
		
		<xsl:if test="$person_dna/nc:BiometricCapturer">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">Collection Agency:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates 
					select="$person_dna/nc:BiometricCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<xsl:text>&#160;&#160;</xsl:text>
				<xsl:apply-templates select="$person_dna/nc:BiometricCapturer/rap:EntityOrganization/nc:OrganizationName" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="$person_dna/nc:BiometricCaptureDate/nc:Date">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">Collection Date:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="$person_dna/nc:BiometricCaptureDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="$person_dna/nc:BiometricDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">Remarks:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="$person_dna/nc:BiometricDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>		
	</xsl:template>
		
	<!-- Prosecution -->
	<xsl:template match="rap:Prosecution">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="prosecution_agency_association" 
					  select="//rap:ProsecutionAgencyAssociation[rap:ProsecutionReference/@s:ref=$ref_id]"/>
		
		<br/>
		<span class="major_history_header">PROSECUTION</span>
		<br/>
		
		<xsl:if test="rap:ProsecutionSubject/rap:SubjectFullName">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
			<span class="other_criminal_name">
				<xsl:apply-templates select="rap:ProsecutionSubject/rap:SubjectFullName" mode="Arrest_Prosecution_Court_Supervision"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:ProsecutionAgencyRecordIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ProsecutionAgencyRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
 		
 		<xsl:if test="$prosecution_agency_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">PROSECUTOR:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Agency[@s:id=$prosecution_agency_association/nc:OrganizationReference/@s:ref]"/>
		</xsl:if>
		
		<xsl:if test="rap:ProsecutionSubject/j:SubjectIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:ProsecutionSubject/j:SubjectIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<!-- CourtAction -->
	<xsl:template match="rap:CourtAction">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="courtaction_court_association" 
					  select="//rap:CourtActionCourtAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		
		<br/><span class="major_history_header">COURT</span>
		<br/>
		
		<xsl:if test="rap:CourtActionSubject">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
			<span class="other_criminal_name">
				<xsl:apply-templates select="rap:CourtActionSubject/rap:SubjectFullName" mode="Arrest_Prosecution_Court_Supervision"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
			<xsl:apply-templates select="nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
			<br/>
			</span>
		</xsl:if>
		
		<xsl:for-each select="rap:CourtRecordIdentification">
			<xsl:if test="position()=1">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
				<span class="history_data">
					<xsl:apply-templates select="./nc:IdentificationID" mode="history_unbounded"/>
					<br/>
				</span>
			</xsl:if>
			<xsl:if test="position()=2">
				<xsl:call-template name="indent"/>
				<span class="history_black_header">DA CASE NUMBER:&#160;&#160;</span>
				<span class="history_data">
					<xsl:apply-templates select="./nc:IdentificationID" mode="history_unbounded"/>
					<br/>
				</span>
			</xsl:if>
		</xsl:for-each>
		
 		<xsl:if test="$courtaction_court_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COURT:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Court[@s:id=$courtaction_court_association/j:CourtReference/@s:ref]"/>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Sentencing -->
	<xsl:template match="rap:Sentencing">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="sentencing_court_association" 
					  select="//rap:SentencingCourtAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		
		<span class="minor_history_header">SENTENCING</span>
		<br/>
		
		<xsl:if test="nc:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:SentencingCourtRecordIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:SentencingCourtRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
 		<xsl:if test="$sentencing_court_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COURT:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Court[@s:id=$sentencing_court_association/j:CourtReference/@s:ref]"/>
		</xsl:if>
		
		<xsl:apply-templates select="rap:Sentence/rap:SentenceCharge"/>
		
		<xsl:apply-templates select="rap:Sentence/j:SentenceDescriptionText"/>
		
		<xsl:apply-templates select="rap:Sentence/j:SupervisionDisciplinaryAction/nc:DisciplinaryActionRestitution"/>
		
		<xsl:apply-templates select="rap:Sentence/rap:SupervisionFineAmount"/>
		
		<xsl:if test="nc:ActivityDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Supervision -->
	<xsl:template match="rap:Supervision">
		<xsl:variable name="ref_id">
			<xsl:value-of select="@s:id"/>
		</xsl:variable>
		<xsl:variable name="supervision_agency_association" 
					  select="//rap:SupervisionAgencyAssociation[rap:SupervisionReference/@s:ref=$ref_id]"/>
		<xsl:variable name="arrest_agency_association" 
					  select="//rap:ArrestAgencyAssociation[nc:ActivityReference/@s:ref=$ref_id]"/>
		
		<br/>
		<span class="major_history_header">SUPERVISION</span>
		<br/>
		
		<xsl:call-template name="indent"/>
		<span class="history_black_header">SUBJECT NAME:&#160;&#160;</span>
		<span class="other_criminal_name">
			<xsl:choose>
				<xsl:when test="rap:SupervisionSubject/rap:SubjectFullName">
					<xsl:apply-templates select="rap:SupervisionSubject/rap:SubjectFullName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="//rap:RapSheet/rap:RapSheetPerson/nc:PersonName" mode="Arrest_Prosecution_Court_Supervision"/>
				</xsl:otherwise>
			</xsl:choose>
		</span>
		<br/>
		
		<!-- First <j:ActivityCommentText> will always have either 'Juvenile Submission' or 
		     'Adult Submission' -->
		<xsl:if test="nc:ActivityDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">TYPE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:for-each select="nc:ActivityDescriptionText">
					<xsl:if test="position() = 1">
						<xsl:apply-templates select="." mode="history_unbounded"/>
						<br/>
					</xsl:if>
				</xsl:for-each>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:ActivityDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:ActivityDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:SupervisionAgencyRecordIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CORRECTIONS OR JAIL CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:SupervisionAgencyRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="rap:SupervisionCourtRecordIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COURT CASE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:SupervisionCourtRecordIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
 		<xsl:if test="$arrest_agency_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">ARRESTING AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Agency[@s:id=$arrest_agency_association/nc:OrganizationReference/@s:ref]"/>
		</xsl:if>
		
 		<xsl:if test="$supervision_agency_association">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SUPERVISION AGENCY:&#160;&#160;</span>
			<xsl:apply-templates select="//rap:Agency[@s:id=$supervision_agency_association/nc:OrganizationReference/@s:ref]"/>
		</xsl:if>
		
		<xsl:if test="rap:SupervisionSubject/j:SubjectIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LOCAL IDENTIFICATION NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="rap:SupervisionSubject/j:SubjectIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="count(nc:ActivityDescriptionText) > 1">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:for-each select="nc:ActivityDescriptionText">
					<xsl:if test="position() > 1">
						<xsl:apply-templates select="." mode="history_unbounded"/>
						<br/>
					</xsl:if>
				</xsl:for-each>
			</span>
		</xsl:if>
		
		<xsl:apply-templates select="rap:SupervisionCharge"/>
		<br/>
		
		<span class="minor_history_header">SUPERVISION ACTION</span>
		<br/>
		<xsl:if test="nc:SupervisionCustodyStatus">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">ACTION LITERAL:&#160;&#160;</span>
 			<span class="history_data">
				<xsl:apply-templates select="nc:SupervisionCustodyStatus/nc:StatusDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:SupervisionRelease">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">RELEASE DATE:&#160;&#160;</span>
 			<span class="history_data">
 				<xsl:choose>
 					<xsl:when test="nc:SupervisionRelease/nc:ActivityDate">
 						<xsl:apply-templates select="nc:SupervisionRelease/nc:ActivityDate/nc:Date" mode="history_unbounded"/>
	 				</xsl:when>
 					<xsl:otherwise>
 						<xsl:apply-templates select="nc:SupervisionRelease/nc:ActivityDescriptionText" mode="history_unbounded"/>
 					</xsl:otherwise>
 				</xsl:choose>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="j:StatusText">
		<xsl:call-template name="supervisiontokenizer">
			<xsl:with-param name="string" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	
	<xsl:template name="supervisiontokenizer">
		<xsl:param name="string"/>
		<xsl:param name="delimiter" select="'=='"/>
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="sentenseLineTexttokenizer">
					<xsl:with-param name="string" select="substring-before($string,$delimiter)"/>
				</xsl:call-template>
				<xsl:call-template name="supervisiontokenizer">
					<xsl:with-param name="string" select="substring-after($string,$delimiter)"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$delimiter and contains($string, ':')">
						<xsl:call-template name="sentenseLineTexttokenizer">
							<xsl:with-param name="string" select="$string"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
						<span class="history_black_header">LITERAL:&#160;&#160;</span>
						<xsl:value-of select="$string"/>
						<br/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="sentenseLineTexttokenizer">
		<xsl:param name="string"/>
		<xsl:param name="delimiter" select="':'"/>
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
				<span class="history_black_header">
					<!-- <xsl:if test="position()=1"><xsl:text> 123 </xsl:text></xsl:if>-->
					<xsl:value-of select="position()"/>
					<xsl:value-of select="substring-before($string,$delimiter)"/>:&#160;&#160;
				</span>
				<span class="history_data">
					<xsl:value-of select="substring-after($string,$delimiter)"/>
					<br/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<span class="history_data">
					<xsl:value-of select="$string"/>
					<br/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<!-- Charges -->
	<xsl:template match="*" mode="literal_to_comments">
		<xsl:if test="j:ChargeText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeNCICCode">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">NCIC CODE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeNCICCode" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeCountQuantity">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COUNTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeCountQuantity" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:apply-templates select="." mode="ChargeClassification"/>
		<xsl:if test="j:ChargeDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">COMMENTS:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:apply-templates select="j:ChargeDisposition"/>
	</xsl:template>
	
	
	<!-- Template to apply Charge Classification -->
	<xsl:template match="*" mode="ChargeClassification">
		<xsl:call-template name="indent"/>
		<span class="history_black_header">CLASSIFICATION:&#160;&#160;</span>
		<br/>
		
		<xsl:if test="j:ChargeApplicabilityText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">INCHOATE CHARGE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeApplicabilityText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeReducingFactorText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">MODIFER OR ENHANCER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeReducingFactorText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeSpecialAllegationText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE ENHANCING FACTOR:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSpecialAllegationText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeSeverityText">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE SEVERITY:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSeverityText" mode="history_unbounded"/>
			</span>
			<br/>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="rap:SentenceCharge">
		<xsl:call-template name="indent"/>
		<span class="history_black_header">CONVICTED OFFENSE:</span>
		<br/>
		
		<xsl:if test="j:ChargeIdentification">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="string-length(j:ChargeText) > 0">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeSequenceID">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE SEQUENCE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeSequenceID/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:ChargeTrackingIdentification">
			<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE TRACKING NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeTrackingIdentification/nc:IdentificationID" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="j:SentenceDescriptionText">
		<xsl:if test="position()=1">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">SENTENCE:&#160;&#160;</span>
			<br/>
		</xsl:if>
		<xsl:call-template name="sentensetokenizer">
			<xsl:with-param name="string" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	
	<xsl:template match="rap:SupervisionFineAmount">
		<xsl:variable name="token">
			<xsl:text>Fine: </xsl:text>
			<xsl:value-of select="."/>
		</xsl:variable>
		<xsl:call-template name="sentensetokenizer">
			<xsl:with-param name="string" select="$token"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<xsl:template match="nc:DisciplinaryActionRestitution">
		<xsl:variable name="token">
			<xsl:text>Restitution: </xsl:text>
			<xsl:value-of select="nc:ObligationTotalAmount"/>
		</xsl:variable>
		<xsl:call-template name="sentensetokenizer">
			<xsl:with-param name="string" select="$token"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<xsl:template name="sentensetokenizer">
		<xsl:param name="string"/>
		<xsl:param name="delimiter" select="':'"/>
		<xsl:choose>
			<xsl:when test="$delimiter and contains($string, $delimiter)">
				<xsl:call-template name="indent"/><xsl:call-template name="indent"/>
				<span class="history_black_header">
					<xsl:value-of select="substring-before($string,$delimiter)"/>:&#160;&#160;
				</span>
				<span class="history_data">
					<xsl:value-of select="substring-after($string,$delimiter)"/>
					<br/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<span class="history_data">
					<xsl:value-of select="$string"/>
					<br/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template match="rap:ChargeStatute">
		<xsl:if test="j:StatuteJurisdiction">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">CHARGE STATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:StatuteJurisdiction/nc:LocationStateName" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="j:StatuteCodeIdentification">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">STATUTE NUMBER:&#160;&#160;</span>
			<span class="history_data">
				<xsl:value-of select="j:StatuteCodeIdentification/nc:IdentificationID"/>
				<xsl:if test="j:StatuteText">
					<xsl:text> - </xsl:text>
					<xsl:value-of select="j:StatuteText"/>
				</xsl:if>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="j:ChargeDisposition">
		<xsl:if test="name(..)='j:ArrestCharge'">
			<span class="minor_history_header">ARREST ACTION:&#160;&#160;</span>
		</xsl:if>
		<xsl:if test="name(..)='rap:ProsecutionCharge'">
			<span class="minor_history_header">PROSECUTION ACTION:&#160;&#160;</span>
		</xsl:if>
		<xsl:if test="name(..)='rap:CourtCharge'">
			<span class="minor_history_header">COURT ACTION:&#160;&#160;</span>
		</xsl:if>
		<xsl:if test="name(..)='rap:SupervisionCharge'">
			<span class="minor_history_header">DISPOSITION&#160;&#160;</span>
		</xsl:if>
		<br/>
		
		<xsl:if test="j:ChargeDispositionOtherText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">LITERAL:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="j:ChargeDispositionOtherText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:DispositionDate">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DISPOSITION DATE:&#160;&#160;</span>
			<span class="history_data">
				<xsl:apply-templates select="nc:DispositionDate/nc:Date" mode="FormatLongDate"/>
				<br/>
			</span>
		</xsl:if>
		
		<xsl:if test="nc:DispositionDescriptionText">
			<xsl:call-template name="indent"/>
			<span class="history_black_header">DISPOSITION:&#160;&#160;</span>
			<span class="history_black_header">
				<xsl:apply-templates select="nc:DispositionDescriptionText" mode="history_unbounded"/>
				<br/>
			</span>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="*" mode="Arrest_Prosecution_Court_Supervision">
		<xsl:choose>
			<xsl:when test="local-name()='PersonName'">
				<xsl:call-template name="person_type"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="if_not_last_then_separator"/>
	</xsl:template>
	
	
	<xsl:template match="*" mode="history_unbounded">
		<xsl:value-of select="."/>
		<xsl:call-template name="if_not_last_then_separator"/>
	</xsl:template>
	
	
	<xsl:template name="contributing_agency">
		<xsl:if test="doj:Result/doj:Automated/rap:RapSheet/rap:Agency or doj:Result/doj:Automated/rap:RapSheet/rap:Court">
		<a name="contributing{$responseId}"></a>
		<br/>
		<div class="contributing_agencies"><xsl:text>Contributing Agencies</xsl:text></div>
		<br/>
		
		<xsl:for-each select="doj:Result/doj:Automated/rap:RapSheet/rap:Agency">
			<xsl:apply-templates select="." mode="print_contributing_agency"/>
		</xsl:for-each>
		
		<xsl:for-each select="doj:Result/doj:Automated/rap:RapSheet/rap:Court">
			<xsl:apply-templates select="." mode="print_contributing_agency"/>
		</xsl:for-each>
		
		<br/><br/>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="*" mode="print_contributing_agency">
		<xsl:if test="j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID != 'UNKNOWN'">
			<span class="detailvalue">
				<xsl:value-of select="j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
				<xsl:text>&#160;&#160;&#160;</xsl:text>
				<xsl:apply-templates select="nc:OrganizationName" mode="TitleCase"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:apply-templates select="nc:OrganizationLocation"/>
			</span>
			<br/>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="nc:PersonDigitalImage" mode="image">
		<xsl:if test="position()=1">
			<xsl:choose>
				<xsl:when test="nc:BinaryBase64Object">
					<xsl:choose>
						<xsl:when test="$from='armsweb'">
							<xsl:variable name="initiatorID" select="/doj:CCHResponseDocument/@doj-ext:initiatorID"/>
							<img ignoreNightMode="true" src="{$imageServlet}?rapsheetid={$initiatorID}&amp;imageindex=0&amp;resize=true"/>
							<br/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="responseID" select="/doj:CCHResponseDocument/@doj-ext:responseID"/>
							<img ignoreNightMode="true" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=true"/>
							<br/>
							<a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;DataServiceCode=CCH&amp;WhatToDo=showImages&amp;ShowOneImage=true', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
								<xsl:element name="img">
									<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'detail.jpg')"/></xsl:attribute>
								</xsl:element>
							</a>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="nc:BinaryAvailableIndicator='true'">
						<span class="textTealSmall">Image Available</span>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>