<?xml version="1.0"?>
<xsl:transform
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
	xmlns:date="http://exslt.org/dates-and-times" 
	extension-element-prefixes="date">
	
	
	<xsl:variable name="AlphaUpperCase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
	<xsl:variable name="AlphaLowerCase" select="'abcdefghijklmnopqrstuvwxyz'"/>
	
	
	<!-- Converts YYYY-MM-DD to MM/DD/YYYY -->
	<xsl:template match="* | @*" mode="FormatFullDateAsMMDDYYYY">
		<xsl:call-template name="formatFullDateAsMMDDYYYY">
			<xsl:with-param name="dateString" select="."></xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- Converts dateString from YYYY-MM-DD to MM/DD/YYYY -->
	<xsl:template name="formatFullDateAsMMDDYYYY">
		<xsl:param name="dateString"/>
		<xsl:if test="$dateString">
			<!-- Converts valid xsd:Date element (YYYY-MM-DD) to MM/DD/YYYY -->
			<xsl:value-of select="substring($dateString,6,2)"/>
			<!-- MM -->
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring($dateString,9,2)"/>
			<!-- DD -->
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring($dateString,1,4)"/>
			<!-- YYYY -->
		</xsl:if>
	</xsl:template>
	
	
	<!-- Converts YYYY-MM-DD to MM/DD/YYYY -->
	<xsl:template match="*" mode="FormatLongDate">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<!-- Converts valid xsd:Date element (YYYY-MM-DD) to Month DD, YYYY -->
			<xsl:call-template name="convertToLongMonth">
				<xsl:with-param name="month" select="substring($theValue,6,2)"/>
			</xsl:call-template>
			<!-- MM -->
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="substring($theValue,9,2)"/>
			<!-- DD -->
			<xsl:text>,&#160;</xsl:text>
			<xsl:value-of select="substring($theValue,1,4)"/>
			<!-- YYYY -->
		</xsl:if>
	</xsl:template>
	
	
	<!-- Converts YYYY-MM to MM/YYYY -->
	<xsl:template match="*" mode="FormatYearMonthAsMMYYYY">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<!-- Convert from YYYY-MM to MMYYYY -->
			<xsl:value-of select="substring($theValue,6,2)"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring($theValue,1,4)"/>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="*" mode="FormatTimeAsHHMM">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<!-- Convert from hh:mm:ss to hhmm -->
			<xsl:value-of select="substring($theValue,1,2)"/>
			<xsl:value-of select="substring($theValue,4,2)"/>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Date of Birth followed by a semi-colon -->
	<xsl:template match="PersonBirthDate | PersonBirthYearMonth | PersonBirthYear">
		<xsl:choose>
			<xsl:when test="self::PersonBirthDate">
				<!--  Date of Birth: Full Date -->
				<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/>
			</xsl:when>
			<xsl:when test="self::PersonBirthYearMonth">
				<!--  Date of Birth: Year and Month Only -->
				<xsl:apply-templates select="." mode="FormatYearMonthAsMMYYYY"/>
			</xsl:when>
			<xsl:when test="self::PersonBirthYear">
				<!--  Date of Birth: Year Only -->
				<xsl:value-of select="."/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
	
	
	<!-- Label does not appear if value is empty -->
	<xsl:template name="ConditionalLabelWithValue">
		<xsl:param name="label"/>
		<xsl:param name="value"/>
		<xsl:param name="label_class_name"/>
		<xsl:param name="value_class_name"/>
		<td class="{$label_class_name}" valign="top">
			<xsl:if test="string($value) != ''">
				<xsl:copy-of select="$label"/>
			</xsl:if>
		</td>
		<td class="{$value_class_name}" valign="top">
			<xsl:if test="string($value) != ''">
				<xsl:copy-of select="$value"/>
			</xsl:if>
		</td>
	</xsl:template>
	
	
	<!-- row of two ConditionalLabelWithValue, row is suppressed if both values not present -->
	<xsl:template name="ConditionalRow">
		<xsl:param name="label1"/>
		<xsl:param name="value1"/>
		<xsl:param name="label_class_name1"/>
		<xsl:param name="value_class_name1"/>
		<xsl:param name="label2"/>
		<xsl:param name="value2"/>
		<xsl:param name="label_class_name2"/>
		<xsl:param name="value_class_name2"/>
		<xsl:if test="string($value1) != '' or string($value2) != ''">
			<tr>
				<xsl:if test="string($label1) != ''">
					<xsl:call-template name="ConditionalLabelWithValue">
						<xsl:with-param name="label" select="$label1"/>
						<xsl:with-param name="value" select="$value1"/>
						<xsl:with-param name="label_class_name" select="$label_class_name1"/>
						<xsl:with-param name="value_class_name" select="$value_class_name1"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string($label2) != ''">
					<xsl:call-template name="ConditionalLabelWithValue">
						<xsl:with-param name="label" select="$label2"/>
						<xsl:with-param name="value" select="$value2"/>
						<xsl:with-param name="label_class_name" select="$label_class_name2"/>
						<xsl:with-param name="value_class_name" select="$value_class_name2"/>
					</xsl:call-template>
				</xsl:if>
			</tr>
		</xsl:if>
	</xsl:template>
	
	
	<!-- converts MM to spelled-out month -->
	<xsl:template name="convertToLongMonth">
		<xsl:param name="month"/>
		<xsl:if test="$month = '01'"> <xsl:text>January</xsl:text> </xsl:if>
		<xsl:if test="$month = '02'"> <xsl:text>February</xsl:text> </xsl:if>
		<xsl:if test="$month = '03'"> <xsl:text>March</xsl:text> </xsl:if>
		<xsl:if test="$month = '04'"> <xsl:text>April</xsl:text> </xsl:if>
		<xsl:if test="$month = '05'"> <xsl:text>May</xsl:text> </xsl:if>
		<xsl:if test="$month = '06'"> <xsl:text>June</xsl:text> </xsl:if>
		<xsl:if test="$month = '07'"> <xsl:text>July</xsl:text> </xsl:if>
		<xsl:if test="$month = '08'"> <xsl:text>August</xsl:text> </xsl:if>
		<xsl:if test="$month = '09'"> <xsl:text>September</xsl:text> </xsl:if>
		<xsl:if test="$month = '10'"> <xsl:text>October</xsl:text> </xsl:if>
		<xsl:if test="$month = '11'"> <xsl:text>November</xsl:text> </xsl:if>
		<xsl:if test="$month = '12'"> <xsl:text>December</xsl:text> </xsl:if>
	</xsl:template>
	
	
	<xsl:template name="currentDate">
		<xsl:variable name="today" select="date:date-time()"/>
		<xsl:call-template name="formatFullDateAsMMDDYYYY">
			<xsl:with-param name="dateString" select="substring-before($today,'T')"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!-- inserts the given character if the position is not last -->
	<xsl:template name="if_not_last_then_separator">
		<xsl:if test="position() != last()">
			<xsl:call-template name="same_field_separator"/>
		</xsl:if>
	</xsl:template>
	
	
	<!-- inserts the given character if the position is last -->
	<xsl:template name="if_last_then_separator">
		<xsl:if test="position() = last()">
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="if_last_then_semicolon">
		<xsl:if test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- breaks the line if the position is last -->
	<xsl:template name="if_last_then_break">
		<xsl:if test="position() = last()">
			<br/>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="if_first_then_label">
		<xsl:param name="label"/>
		<xsl:if test="position() = 1">
			<xsl:value-of select="$label"/>
		</xsl:if>
	</xsl:template>
	
	
	<!-- character to be used to separate values of the same field -->
	<xsl:template name="same_field_separator">
		<xsl:text>, </xsl:text>
		<xsl:text>&#32;</xsl:text>
	</xsl:template>
	
	
	<!-- converts first letter of each word to upper-case -->
	<xsl:template match="*|@*|text()" mode="TitleCase">
		<xsl:call-template name="TitleCase">
			<xsl:with-param name="text" select="translate(., $AlphaUpperCase, $AlphaLowerCase)"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<xsl:template name="TitleCase">
		<xsl:param name="text"/>
		<xsl:variable name="charsBeforeSpace">
			<xsl:choose>
				<xsl:when test="contains($text, ' ')">
					<xsl:value-of select="substring-before($text, ' ')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$text"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="charsAfterSpace">
			<xsl:if test="contains($text, ' ')">
				<xsl:value-of select="substring-after($text, ' ')"/>
			</xsl:if>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="$charsBeforeSpace = 'cib' or $charsBeforeSpace = 'wi'">
				<xsl:value-of select="translate($charsBeforeSpace, $AlphaLowerCase, $AlphaUpperCase)"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- translate first char to upper-case -->
				<xsl:value-of select="translate(substring($charsBeforeSpace, 1, 1), $AlphaLowerCase, $AlphaUpperCase)"/>
				
				<!-- translate the rest to lower-case -->
				<xsl:value-of select="translate(substring($charsBeforeSpace, 2), $AlphaUpperCase, $AlphaLowerCase)"/>
			</xsl:otherwise>
		</xsl:choose>
		
		<!-- if there was any text following a space in the original string, process it -->
		<xsl:if test="string-length($charsAfterSpace) &gt; 0">
			<xsl:text>&#32;</xsl:text>
			<xsl:call-template name="TitleCase">
				<xsl:with-param name="text" select="$charsAfterSpace"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	
	<!-- indent size for criminal history -->
	<xsl:template name="indent">
		<xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
	</xsl:template>
</xsl:transform>