<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:java="http://xml.apache.org/xalan/java" 
	xmlns:rap="http://nlets.org/niem2/rapsheet/1.0" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cch/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:jj="http://www.it.ojp.gov/jxdm/3.0.2" 
	xmlns:j="http://niem.gov/niem/domains/jxdm/4.1" 
	xmlns:nc="http://niem.gov/niem/niem-core/2.0" 
	xmlns:ansi-nist="http://niem.gov/niem/ansi-nist/2.0" 
	xmlns:s="http://niem.gov/niem/structures/2.0" 
	xmlns:n="http://www.nlets.org" 
	xmlns:nh2="http://www.nlets.org/niem/nlets-hdr/1.0" 
	xmlns:n2="http://www.nlets.org/niem/1.0" 
	exclude-result-prefixes="xsl rap jj j java doj doj-ext nc ansi-nist s n nh2 n2">
	
	<xsl:import href="/2017V01/cch/raputility.xsl"/>
	<xsl:import href="/2017V01/common.xsl" />
	<xsl:import href="/2017V01/util.xsl" />
	
	<xsl:output method="html"/>
	
	<xsl:param name="readOnly"/>
	<xsl:param name="executionUrl">/</xsl:param>
	<xsl:param name="imageBase">
		<xsl:text>../../images/</xsl:text>
	</xsl:param>
	<xsl:param name="from"/>
	<xsl:param name="responseId">
		<xsl:value-of select="doj:CCHResponseDocument/@doj-ext:responseID"/>
	</xsl:param>
	<xsl:param name="imageServlet"></xsl:param>
	<xsl:param name="bcresponseid"/>
	<xsl:param name="applicationid"/>
	<xsl:param name="isRapsheetExisted">
		<xsl:text>false</xsl:text>
	</xsl:param>
	
	
	<!-- START HERE - root match-->
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension"/>
				<xsl:call-template name="html_body"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">RapSheet</xsl:template>
	
	
	<xsl:template name="html_head_extension">
		<xsl:call-template name="rapsheet_css"/>
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:choose>
			<xsl:when test="doj:CCHResponseDocument/doj:Result/doj:ResultText">
				<xsl:value-of select="doj:CCHResponseDocument/doj:Result/doj:ResultText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:CCHResponseDocument"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
 	<!-- Main controlling template -->
	<xsl:template match="doj:CCHResponseDocument">
		<div><xsl:call-template name="subheader"/></div>
		<div><xsl:call-template name="title"/></div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="header_flag_section"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:Introduction | doj:Result/doj:NonAutomated/rap:RapSheet/rap:Introduction"/>
		</div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="caution_other"/>
		</div>
		<div><hr/></div>
		<a name="identification{$responseId}"></a>
		<div class="identification"><xsl:text>Identification</xsl:text></div>
		<div>
			<xsl:apply-templates select="doj:Result/doj:Automated/rap:RapSheet/rap:RapSheetPerson | doj:Result/doj:NonAutomated/rap:RapSheet/rap:RapSheetPerson" mode="subject_details"/>
		</div>
		<div><hr/></div>
		<xsl:if test="doj:Result/doj:Automated/rap:RapSheet/rap:SummaryRapSheetCycle">
			<a name="history{$responseId}"></a>
			<span class="criminal_history">Arrest &#38; Disposition Data</span><p/>
			<table style="border-collapse:collapse;">
				<tr>
					<th class="black_header" style="text-align: left;  font-size: 85%; width: 10%">Date</th>
					<th class="black_header" style="text-align: left;  font-size: 85%; width: 45%">Charge Literal</th>
					<th class="black_header" style="text-align: left;  font-size: 85%; width: 35%">Arresting Agency</th>
					<th class="black_header" style="text-align: left;  font-size: 85%; width: 10%">Disposition</th>
				</tr>
				<xsl:for-each select="doj:Result/doj:Automated/rap:RapSheet/rap:SummaryRapSheetCycle" >
					<xsl:sort select="@s:id" data-type="text" order="descending"/>
					<tr>
						<td class="detailvalue"> 
						<!-- Date -->
							<xsl:if test="rap:EventDate">
								<xsl:apply-templates select="rap:EventDate" />
							</xsl:if>
						</td>
						<td class="detailvalue">
						 <!-- CHARGE LITERAL -->
						 <xsl:for-each select="rap:LiteralCharge">
								<xsl:apply-templates select="."/>
								<br />
						 </xsl:for-each>
						</td>
						<td class="detailvalue">
						<!-- Arresting Agency -->
						<xsl:for-each select="rap:ArrestAgency">
							<xsl:apply-templates select="."/>
							<br />
						</xsl:for-each>
						</td>
						<td class="detailvalue">
						<!-- Disposition -->
						<xsl:for-each select="rap:ChargeDispositionOtherText">
							<xsl:sort select="ChargeDispositionOtherText" data-type="text" order="ascending"/>
								<xsl:apply-templates select="."/>	
								<br />
						</xsl:for-each>
						</td>
					</tr>
				</xsl:for-each>				
			</table>
			<div><hr/></div>
		</xsl:if>
	</xsl:template>
	
	<!-- images under navigation bar -->
	<xsl:template name="subheader">
		<div align="right">
			<xsl:element name="img">
				<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'cib3_small.png')"/></xsl:attribute>
				<xsl:attribute name="alt">ciblogo</xsl:attribute>
				<xsl:attribute name="width">50</xsl:attribute>
				<xsl:attribute name="height">50</xsl:attribute>
			</xsl:element>
			<xsl:element name="img">
				<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'spacer.gif')"/></xsl:attribute>
				<xsl:attribute name="alt"></xsl:attribute>
				<xsl:attribute name="width">100</xsl:attribute>
				<xsl:attribute name="height">1</xsl:attribute>
			</xsl:element>
		</div>
	</xsl:template>
	
	
	<!-- Page title and current date -->
	<xsl:template name="title">
		<p/>
		<table width="100%">
		<tr>
			<td class="wisconsin_criminal_history width75percent">Wisconsin Criminal History</td>
			<td class="reported_date">
				<xsl:text>Date:&#32;</xsl:text>
				<xsl:call-template name="currentDate"/>
			</td>
		</tr>
		</table>
		<p/>
	</xsl:template>
	
	
	<!-- flags -->
	<xsl:template match="rap:RapSheetPerson" mode="header_flag_section">
		<table class="flag">
		<xsl:if test="j:PersonAugmentation/j:PersonFirearmSalesDisqualifiedCode = 'D'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'firearmDisqualifier.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">gun</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Firearm&#32;Sale&#32;Disqualified&#32;</xsl:text>
					<xsl:apply-templates select="j:PersonAugmentation/j:PersonFirearmSalesDisqualifiedCode[.='D']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<xsl:if test="j:SubjectOffenderNoticeText = 'CONVICTED FELON'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'convictedfelon.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">felon</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Convicted Felon </xsl:text>
					<xsl:apply-templates select="j:SubjectOffenderNoticeText[.='Convicted Felon']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<xsl:if test="j:SubjectOffenderNoticeText = 'REGISTERED SEX OFFENDER'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'sexOffender.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">sex_offender</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:text>Registered&#32;Sex&#32;Offender&#32;</xsl:text>
					<xsl:apply-templates select="j:SubjectOffenderNoticeText[.='true']" mode="all_attributes"/>
				</td>
			</tr>
		</xsl:if>
		
		<!-- Arrest DNA is on File -->
		<!-- Conviction DNA is on File -->
		<!-- DNA Collection Needed – (One of SAFE team, Crime Lab, Missed Collection) -->
		<!-- No DNA Sample on File -->
		<xsl:for-each select="j:SubjectOffenderNoticeText">
			<xsl:if test="contains(.,'DNA')='true'">
			<tr>
				<td>
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:element name="img">
						<xsl:attribute name="class">flag_img</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'dna2.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">dna</xsl:attribute>
						<xsl:attribute name="width">40</xsl:attribute>
						<xsl:attribute name="height">32</xsl:attribute>
					</xsl:element>
					<xsl:apply-templates select="."/>
					<xsl:apply-templates select="." mode="all_attributes"/>
				</td>
			</tr>
			</xsl:if>
		</xsl:for-each>
		
		</table>
	</xsl:template>
	
	
	<!-- Introduction -->
	<xsl:template match="rap:Introduction">
		<p/>
		<table border="0">
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Purpose Code:</xsl:text>
			</td>
			<td class="purpose_code width75percent">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:PurposeCode"/>
			</td>
		</tr>
		<xsl:if test="$from!='armsweb'">
		<tr>
			<td class="purpose_code width25percent">
				<xsl:text>Attention:</xsl:text>
			</td>
 			<td class="purpose_code width75percent mixedcase">
				<xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
				<xsl:value-of select="rap:RapSheetRequest/rap:Attention"/>
			</td>
			<!-- <td class="purpose_code width75percent">
				<xsl:value-of select="rap:RapSheetRequest"/>
			</td> -->
		</tr>
		</xsl:if>
		</table>
		<p/>
		<xsl:apply-templates select="rap:Caveat"/>
	</xsl:template>
	
	
	<!-- Caveat -->
	<xsl:template match="rap:Caveat">
		<table border="0">
		<tr>
			<td class="caveat"><xsl:value-of select="nc:CaveatText"/></td>
		</tr>
		</table>
		<p/>
	</xsl:template>
	
	
	<xsl:template match="rap:RapSheetPerson" mode="caution_other">
		<table>
 		<xsl:if test="rap:SubjectCautionInformationText != 'Convicted Felon'">
			<tr>
				<td class="caution width10percent" valign="top">
					<xsl:text>CAUTION:</xsl:text>
				</td>
				<td class="caution width75percent" valign="top" colspan="2">
					<xsl:for-each select="rap:SubjectCautionInformationText">
						<xsl:value-of select="."/>
						<br/>
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
		</table>
	</xsl:template>
		
	<!-- Controlling template for subject details -->
	<xsl:template match="rap:RapSheetPerson" mode="subject_details">
		<table width="100%">
		<tr>
			<td class="width80percent">
				<table width="100%">
				<xsl:apply-templates select="nc:PersonName" mode="subject_name"/>
				<tr>
					<td colspan="2">
						<div class="detailvalue">
							<xsl:apply-templates select="." mode="gender_race"/>
							<xsl:apply-templates select="nc:PersonBirthDate"/>
							<xsl:apply-templates select="." mode="height_to_blood"/>
							<xsl:apply-templates select="../nc:Location" mode="subject_residence"/>
						</div>
					</td>
				</tr>
				</table>
			</td>
			<td class="width20percent centered_top" align="right">
				<br/>
				<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage" mode="image"/>
			</td>
		</tr>
		<tr>
			<td><br/></td>
			<td></td>
		</tr>
		</table>
		<!-- <xsl:call-template name="SMT_Photo_Links"/> -->
		<xsl:apply-templates select="." mode="ssn_to_notice"/>
		<xsl:apply-templates select="." mode="subject_physical"/>
		<xsl:apply-templates select="." mode="alias_name"/>
		<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage" mode="photo_info"/>
	</xsl:template>
	
	
	<!-- Matches any element - if element has reportedDate attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportedDate">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="nc:ReportedDate/nc:Date">
			<xsl:text>as of&#160;</xsl:text>
			<xsl:apply-templates select="nc:ReportedDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Matches any element - if element has reportingOrganizationText attribute it attaches a phrase -->
	<xsl:template match="*" mode="reportingOrganizationText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:reportingOrganizationText">
			<xsl:text>reported by&#160;</xsl:text>
			<xsl:value-of select="@j:reportingOrganizationText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- Matches any element - if element has commentText attribute it attaches a phrase -->
	<xsl:template match="*" mode="commentText">
		<xsl:text>&#32;</xsl:text>
		<xsl:if test="@j:commentText">
			<xsl:text>--</xsl:text>
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="@j:commentText"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<!-- an alternate way to display attributes -->
	<xsl:template match="*" mode="all_attributes">
		<xsl:apply-templates select="." mode="reportedDate"/>
		<xsl:apply-templates select="." mode="reportingOrganizationText"/>
		<xsl:apply-templates select="." mode="commentText"/>
	</xsl:template>
	
	
	<!-- If calling template has match containing person name information, name will print out -->
	<xsl:template name="person_type">
		<xsl:if test="nc:PersonNamePrefixText">
			<xsl:for-each select="nc:PersonNamePrefixText">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonGivenName">
			<xsl:value-of select="nc:PersonGivenName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonMiddleName">
			<xsl:for-each select="nc:PersonMiddleName">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonSurName">
			<xsl:value-of select="nc:PersonSurName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:PersonNameSuffixText">
			<xsl:for-each select="nc:PersonNameSuffixText">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">
					<xsl:text>;</xsl:text>
				</xsl:if>
			</xsl:for-each>
			<xsl:text>&#32;</xsl:text>
		</xsl:if>
		
		<!-- *********** In Java do not create full name if other names are present *************
		<xsl:if test="nc:PersonFullName">
			<xsl:value-of select="nc:PersonFullName"/>
			<xsl:text>&#32;</xsl:text>
		</xsl:if> -->
	</xsl:template>
	
	
	<!-- Elements of type "LocationType" can have their info printed here-->
	<xsl:template match="j:EmploymentLocation | nc:Location | j:PersonBirthLocation | nc:OrganizationLocation">
		<xsl:variable name="metadataid">
			<xsl:value-of select="@s:metadata"/>
		</xsl:variable>
		
		<!-- ************* What to replace with? -->
		<xsl:if test="j:LocationName">
			<xsl:apply-templates select="j:LocationName" mode="TitleCase"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:AddressFullText">
			<xsl:apply-templates select="nc:LocationAddress/nc:AddressFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationStreet/nc:StreetFullText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationStreet/nc:StreetFullText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:AddressSecondaryUnitText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:AddressSecondaryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:AddressMailDeliveryUnitText">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:AddressMailDeliveryUnitText" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCityName">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCityName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountyName">
			<xsl:apply-templates select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountyName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationStateName">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationStateName"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationPostalCode">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationPostalCode"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountryName">
			<xsl:value-of select="nc:LocationAddress/nc:StructuredAddress/nc:LocationCountryName"/>			
		</xsl:if>
		
		<xsl:if test="nc:LocationContactInformation">
			<xsl:text>Contact information:&#160;</xsl:text>
		</xsl:if>
		
		<xsl:if test="nc:LocationContactInformation/nc:ContactInformationDescriptionText">
			<xsl:value-of select="nc:LocationContactInformation/nc:ContactInformationDescriptionText"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactTelephoneNumber">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactFaxNumber">
			<xsl:if test="position() = 1">
				<xsl:text>Fax:</xsl:text>
			</xsl:if>
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:LocationContactInformation/nc:ContactEmailID">
		<a href="mailto:{.}"><xsl:value-of select="."/></a>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		
		<xsl:apply-templates select="//rap:RapSheet/rap:Metadata[@s:id='location']" mode="reportedDate"/>
	</xsl:template>
	
	
	<!-- name of subject -->
	<xsl:template match="nc:PersonName" mode="subject_name">
		<xsl:if test="position()=1">
			<tr>
				<td class="subject_name">
					<xsl:call-template name="person_type"/>
				</td>
				<!--<td align="center">
					<xsl:if test="../nc:PersonAlternateName">
						<a href="#alias{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="border">0</xsl:attribute>
								<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/></xsl:attribute>
								<xsl:attribute name="alt">aliases</xsl:attribute>
							</xsl:element>
						</a>
					</xsl:if>
				</td> -->
			<br/>
			</tr>
		</xsl:if>
	</xsl:template>
	
	
	<!-- gender and race of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="gender_race">
		<xsl:for-each select="rap:PersonSexText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_separator"/>
			<xsl:text>/</xsl:text>
			<xsl:call-template name="if_last_then_separator"/>
		</xsl:for-each>	
		
		<xsl:for-each select="rap:PersonRaceText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
		</xsl:for-each>
		<br/>
	</xsl:template>
	
	
	<!-- birthdate of subject -->
	<xsl:template match="nc:PersonBirthDate">
		<xsl:apply-templates select="nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
		<xsl:call-template name="if_not_last_then_separator"/>
		<xsl:call-template name="if_last_then_break"/>
	</xsl:template>
	
	
	<!-- height, weight, eye color, hair color, skin tone, and blood type of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="height_to_blood">
		<xsl:for-each select="nc:PersonHeightMeasure/nc:MeasureText">
			<xsl:value-of select="substring(.,1,1)"/>
			<xsl:text>'</xsl:text>
			<xsl:value-of select="substring(.,2,2)"/>
			<xsl:text>"</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="nc:PersonWeightMeasure/nc:MeasureText">
			<xsl:value-of select="."/>
			<xsl:text>lbs</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonEyeColorText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Eyes</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonHairColorText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Hair</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonSkinToneText">
			<xsl:value-of select="."/>
			<xsl:text>&#32;Skin Tone</xsl:text>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		
		<xsl:for-each select="rap:PersonBloodTypeText">
			<xsl:value-of select="."/>
			<xsl:call-template name="if_not_last_then_separator"/>
			<xsl:call-template name="if_last_then_semicolon"/>
		</xsl:for-each>
		<xsl:call-template name="if_last_then_break"/>
	</xsl:template>
	
	
	<!-- residence of subject -->
	<xsl:template match="nc:Location" mode="subject_residence">
	 	<xsl:apply-templates select="."/>
		<xsl:apply-templates select="." mode="reportedDate"/>
		<!-- xsl:call-template name="if_not_last_then_separator"/ -->
	</xsl:template>
	
	
	<!-- links under state ID and FBI number -->
	<xsl:template name="SMT_Photo_Links">
		<table width="100%">
		<tr>
			<td class="width50percent centered no_decoration">
				<a href="#smt{$responseId}">
					<xsl:element name="img">
						<xsl:attribute name="border">0</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'scarsMarksTattoos.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">SMT</xsl:attribute>
					</xsl:element>
				</a>
			</td>
			<td class="width50percent centered no_decoration">
				<a href="#photo{$responseId}">
					<xsl:element name="img">
						<xsl:attribute name="border">0</xsl:attribute>
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'photoInformation.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">photo</xsl:attribute>
					</xsl:element>
				</a>
			</td>
		</tr>
		</table>
	</xsl:template>
	
	
	<!-- SSN, Misc #, Driver License, fingerprint, palm print, AFIS, DNA, Employer, Occupation, Employment, Offender Notice -->
	<xsl:template match="rap:RapSheetPerson" mode="ssn_to_notice">
		<table>
 		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FBI:'"/>
				<xsl:with-param name="value">
					<xsl:value-of select="j:PersonAugmentation/j:PersonFBIIdentification/nc:IdentificationID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'SOCIAL SECURITY #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="nc:PersonSSNIdentification">
						<xsl:value-of select="substring(nc:IdentificationID,1,3)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(nc:IdentificationID,4,2)"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="substring(nc:IdentificationID,6,4)"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</tr>
		
 		<tr>
			<xsl:if test="j:PersonAugmentation/j:PersonStateFingerprintIdentification/nc:IdentificationID">
				<td class="black_header width20percent">
					<xsl:text>STATE ID:</xsl:text>
				</td>
				<td class="detailvalue width25percent" style="white-space: nowrap;">
					<xsl:variable name="sid">
						<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:value-of select="j:PersonAugmentation/j:PersonStateFingerprintIdentification/nc:IdentificationID"/>
					</xsl:variable>
					<xsl:value-of select="$sid"/>
					<xsl:text>&#32;</xsl:text>
					<!-- Only display the Full Record hyperlink if this is an EBC Summary response -->
					<xsl:if test="ancestor::doj:Result/doj:MessageKeyCode='SR'">
						<xsl:variable name="rapSheetRequest" select="ancestor::rap:RapSheet/rap:Introduction/rap:RapSheetRequest"/>
						<xsl:variable name="purposeCd" select="$rapSheetRequest/rap:PurposeCode"/>
						<xsl:variable name="attention" select="$rapSheetRequest/rap:Attention"/>
						<xsl:variable name="oboORI" select="/doj:CCHResponseDocument/doj:Header/doj-ext:SubmissionRequestorDetails/doj-ext:SubmissionRequestor.OnBehalfOfOrganization/doj-ext:OrganizationORIID/doj-ext:ID"/>
						<form id="fullRecordRequest_{$sid}" action="/secure/personsearch/buildcchfq.jsp" method="post" style="display:inline">
							<input name="sid" type="hidden" value="{$sid}"/>
							<xsl:if test="$purposeCd">
								<input name="pur" type="hidden" value="{$purposeCd}"/>
							</xsl:if>
							<xsl:if test="$attention">
								<input name="attn" type="hidden" value="{$attention}"/>
							</xsl:if>
							<xsl:if test="$oboORI">
								<input name="ori" type="hidden" value="{$oboORI}"/>
							</xsl:if>
							<xsl:if test="/doj:CCHResponseDocument/doj:Result/doj:Automated/rap:RapSheet/rap:PersonBiometricsAssociation/rap:PersonBiometrics/nc:PersonDigitalImage/nc:BinaryBase64Object">
								<input name="includeImages" type="hidden" value="yes"/>
							</xsl:if>
						</form>
						<a href="javascript:document.getElementById('fullRecordRequest_{$sid}').submit();">Click here to submit Full Record</a>
					</xsl:if>
					<xsl:if test="$sid !='Unknown' and $from='firearm' and $readOnly!='true'">
						<xsl:variable name="leftCurlyBrace">{</xsl:variable>
						<xsl:variable name="rightCurlyBrace">}</xsl:variable>
						<xsl:element name="a">
							<xsl:attribute name="url"><xsl:value-of select="$executionUrl"/><xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:attribute name="id"><xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:attribute name="class">fullRapSheet</xsl:attribute>
							<xsl:attribute name="href">#<xsl:value-of select="$sid"/></xsl:attribute>
							<xsl:text>Click here to Submit Full Record </xsl:text>
						</xsl:element>
					</xsl:if>
				</td>
			</xsl:if>

			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'MISCELLANEOUS #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="nc:PersonOtherIdentification">
						<xsl:value-of select="nc:IdentificationCategoryText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationJurisdictionText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
					<xsl:for-each select="rap:PersonCorrectionsIdentification">
						<xsl:text>CORRECTIONS-</xsl:text>
						<xsl:value-of select="j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width20percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width30percent'"/>
			</xsl:call-template>
		</tr>
		</table>
		
		<table>
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'DRIVERS LICENSE #:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:PersonAugmentation/nc:DriverLicense/nc:DriverLicenseIdentification">
						<xsl:value-of select="j:IdentificationJurisdictionNCICLSTACode"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="nc:IdentificationID"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'FINGERPRINT CLASS:'"/>
				<xsl:with-param name="value">
					<xsl:apply-templates select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/rap:PersonFingerprintSet"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		
		<xsl:for-each select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/j:PersonPalmPrint">
			<tr>
				<td valign="top" class="black_header width25percent">PALM PRINT, ORI and LITERAL:</td>
				<td class="detailvalue" valign="top">
					<xsl:value-of select="nc:BiometricImage/nc:BinaryCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="nc:BiometricImage/nc:BinaryCapturer/rap:EntityOrganization/nc:OrganizationName"/>
				</td>
				<td valign="top">
					<!-- img src="images/palm" alt=""/ -->
				</td>
			</tr>
		</xsl:for-each>
		
		<xsl:for-each select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:Fingerprint/j:FingerprintFingerText">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'AFIS CLASSIFICATION:'"/>
					<xsl:with-param name="value" select="."/>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<xsl:for-each select="../rap:PersonBiometricsAssociation/rap:PersonBiometrics/rap:PersonDNA">
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="'DNA:'"/>
					<xsl:with-param name="value">
						<xsl:if test="nc:BiometricEncodingMethodText != 'UNKNOWN'">
							<xsl:text>Method:&#32;</xsl:text>
							<xsl:value-of select="nc:BiometricEncodingMethodText"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<xsl:for-each select="nc:BiometricDescriptionText">
							<xsl:if test="position()=1">
								<xsl:text>Description:&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="."/>
							<xsl:call-template name="if_not_last_then_separator"/>
							<xsl:if test="position() = last()">
								<xsl:text>,</xsl:text>
							</xsl:if>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
						<xsl:if test="nc:BiometricCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID">
							<xsl:text>Agency:&#32;</xsl:text>
							<xsl:value-of select="nc:BiometricCapturer/rap:EntityOrganization/j:OrganizationAugmentation/j:OrganizationORIIdentification/nc:IdentificationID"/>
							<xsl:text>,&#32;</xsl:text>
						</xsl:if>
						<!-- xsl:text>Name:&#32;</xsl:text -->
						<xsl:value-of select="nc:BiometricCapturer/rap:EntityOrganization/nc:OrganizationName"/>
						<xsl:text>,&#32;</xsl:text>
						<xsl:if test="nc:BiometricCaptureDate">
							<xsl:text>Date:&#32;</xsl:text>
							<xsl:apply-templates select="nc:BiometricCaptureDate/nc:Date" mode="FormatFullDateAsMMDDYYYY"/>
							<xsl:text>&#32;</xsl:text>
						</xsl:if>
						<xsl:for-each select="nc:BiometricValueText">
							<xsl:if test="position() = 1">
								<xsl:text>Locus(Type/Value(s)):&#32;</xsl:text>
							</xsl:if>
							<xsl:value-of select="."/>
							<xsl:text>&#32;</xsl:text>
						</xsl:for-each>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<!-- Employment Info -->
		<xsl:for-each select="../nc:PersonEmploymentAssociation/nc:Employer">
			<xsl:variable name="position">
				<xsl:value-of select="position()"/>
			</xsl:variable>
			<xsl:variable name="locationId">
				<xsl:value-of select="../nc:EmploymentLocationReference[$position]/@s:ref"></xsl:value-of>
			</xsl:variable>
			<xsl:variable name="location">
			</xsl:variable>
			<xsl:variable name="label">
				<xsl:choose>
					<xsl:when test="$position=1">
						<xsl:text>EMPLOYER:</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<!-- <tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/>
						<xsl:text> - </xsl:text>
						<xsl:apply-templates select="//nc:Location[@s:id=$locationId]"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr> -->
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="rap:EntityOrganization/nc:OrganizationName" mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="''"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="//nc:Location[@s:id=$locationId]"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
			
		</xsl:for-each>
		
		<!-- Occupation Info -->
		<xsl:for-each select="../nc:PersonEmploymentAssociation/nc:EmployeeOccupationText">
			<xsl:variable name="label">
				<xsl:choose>
					<xsl:when test="position()=1">
						<xsl:text>OCCUPATION:</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> </xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<tr>
				<xsl:call-template name="ConditionalLabelWithValue">
					<xsl:with-param name="label" select="$label"/>
					<xsl:with-param name="value">
						<xsl:apply-templates select="." mode="TitleCase"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
					<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
				</xsl:call-template>
				<td></td>
			</tr>
		</xsl:for-each>
		
		<tr>
			<xsl:call-template name="ConditionalLabelWithValue">
				<xsl:with-param name="label" select="'OFFENDER NOTICE:'"/>
				<xsl:with-param name="value">
					<xsl:for-each select="j:SubjectOffenderNoticeText">
						<xsl:value-of select="."/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:call-template name="if_last_then_break"/>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name" select="'black_header width25percent'"/>
				<xsl:with-param name="value_class_name" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<td></td>
		</tr>
		</table>
	</xsl:template>
	
	
	<!-- SMT of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="subject_physical">		
		<xsl:if test="nc:PersonPhysicalFeature"> <!-- test="position()=1"-->
			<a name="smt{$responseId}"></a>
			<table width="100%">
				<tr>
					<td class="black_header width100percent">
						<xsl:text>SCARS MARKS TATTOOS DATA:&#32;</xsl:text>
						<br/>
					</td>
				</tr>
				<tr>
					<td class="width25percent detailvalue">
						<xsl:for-each select="nc:PersonPhysicalFeature">
							<xsl:if test="nc:PhysicalFeatureCategoryText">
								<xsl:value-of select="nc:PhysicalFeatureCategoryText"/>
								<xsl:text>&#32;</xsl:text>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="nc:PhysicalFeatureDescriptionText">
									<xsl:text>---</xsl:text>
									<xsl:apply-templates select="nc:PhysicalFeatureDescriptionText" mode="TitleCase"/>
									<xsl:if test="position() != last()">
										<xsl:text>; </xsl:text>
										<xsl:text>&#32;</xsl:text>
									</xsl:if>
									<xsl:text>&#32;</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if test="position() != last()">
										<xsl:text>; </xsl:text>
										<xsl:text>&#32;</xsl:text>
									</xsl:if>
									<xsl:text>&#32;</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	
	<!-- alias names of subject -->
	<xsl:template match="rap:RapSheetPerson" mode="alias_name">
		<xsl:if test="nc:PersonAlternateName">
			<a name="alias{$responseId}"></a>
			<table width="100%">
			<tr>
				<td class="black_header width100percent">
					<xsl:text>ALIAS NAMES/FRAUDULENT DATA:&#32;</xsl:text>
					<br/>
				</td>
			</tr>
			<tr>
				<td class="detailvalue width25percent">
					<xsl:for-each select="nc:PersonAlternateName">
						<xsl:value-of select="nc:PersonFullName"/>
						<xsl:call-template name="if_not_last_then_separator"/>
						<xsl:text>&#32;</xsl:text>
					</xsl:for-each>
				</td>
			</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!--<xsl:template name="listAlias">
		<xsl:with-param name="value">
			<xsl:for-each select="nc:PersonAlternateName">
				<xsl:value-of select="nc:PersonFullName"/>
				<xsl:call-template name="if_not_last_then_separator"/>
				<xsl:text>&#32;</xsl:text>
			</xsl:for-each>
		</xsl:with-param>
	</xsl:template> -->
	
	<!--<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="nc:PersonAlternateName[position() mod 2 != 0]">
				<xsl:sort select="nc:PersonSurName" data-type="text" order="ascending"/>
				<xsl:sort select="nc:PersonGivenName" data-type="text" order="ascending"/>
				<xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
				<tr>
					<xsl:apply-templates select="../nc:PersonAlternateName" mode="aliasNames">
						<xsl:sort select="nc:PersonSurName" data-type="text" order="ascending"/>
						<xsl:sort select="nc:PersonGivenName" data-type="text" order="ascending"/>
						<xsl:with-param name="startposition" select="$startposition"/>
					</xsl:apply-templates>
					<td class="detailvalue width20percent"/>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template> -->
	
	
	<xsl:template match="nc:PersonAlternateName" mode="aliasNames">
		<xsl:param name="startposition"/>
		<xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
			<td class="detailvalue width30percent">
				<xsl:call-template name="person_type"/>
			</td>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template match="j:ChargeDisposition">
		<xsl:apply-templates select="j:ChargeDispositionOtherText" mode="history_unbounded"/>
	</xsl:template>
	
	
	<xsl:template match="*" mode="history_unbounded">
		<xsl:value-of select="."/>
		<xsl:call-template name="if_not_last_then_separator"/>
	</xsl:template>	
</xsl:stylesheet>