<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:doj="http://www.doj.state.wi.us/dles/cib/internal/dnrv/response" 
    xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:dnrv-ext="http://www.doj.state.wi.us/dles/cib/internal/dnrv/response/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"  
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    exclude-result-prefixes="xsl"
    version="2.0">
    <xsl:output omit-xml-declaration="yes"/> 
    
    <xsl:template match="transferRequests">
        <doj:FirearmsDenialReversal>
            <xsl:attribute name="xsi:schemaLocation">
                <xsl:value-of select='"http://www.doj.state.wi.us/dles/cib/dnrv/response ../../../../internal/dnrv/response/WIInternalDNRVResponseDoc.xsd"' />
            </xsl:attribute>
           	<xsl:choose>
            	<xsl:when test="count(*) &gt; 0">
            		<xsl:apply-templates select="transferRequest" />
            	</xsl:when>
            	<xsl:otherwise>
                	<doj:ResultText>NO HIT</doj:ResultText>
            	</xsl:otherwise>
            </xsl:choose>
        </doj:FirearmsDenialReversal>   		
    </xsl:template>
    
    <xsl:template match="transferRequest">

                <doj:DenialReversalResponse>
                    <xsl:call-template name="RecordIdentifiers" />
                    <xsl:call-template name="BuyerInformation" />
                    <xsl:call-template name="AdditionalInformation" />
                </doj:DenialReversalResponse>	
    </xsl:template>
    
    <xsl:template name="RecordIdentifiers">
        <doj:RecordIdentifiers>
        <xsl:apply-templates select="id" />
        <xsl:apply-templates select="formNo" />
        <xsl:apply-templates select="confirmationNo" />
        </doj:RecordIdentifiers>
    </xsl:template>
    
    <xsl:template name="BuyerInformation">
        <doj:BuyerInformation>
            <xsl:apply-templates select="buyer" />
        </doj:BuyerInformation>
    </xsl:template>
    
    <xsl:template name="AdditionalInformation">
        <doj:AdditionalInformation>
        <xsl:call-template name="finalDecisionCode" >
            <xsl:with-param name="finalDecisionCode" select="finalDecisionCode"/>
        </xsl:call-template>
        <xsl:apply-templates select="denialReasonCodeDesc" />  
        <xsl:apply-templates select="requestDate" />
        <xsl:apply-templates select="dealerUid" />         
        </doj:AdditionalInformation>
    </xsl:template>
 
    <xsl:template match="buyer">
        <xsl:call-template name="PersonName" >
            <xsl:with-param name="FirstName" select="primaryName/firstName"/>
            <xsl:with-param name="MiddleName" select="primaryName/middleName"/>
            <xsl:with-param name="LastName" select="primaryName/lastName"/>
        </xsl:call-template>
        <j:PersonBirthDate>
            <xsl:call-template name="DateValue">
                <xsl:with-param name="date" select="formPersonDOB/birthDate" />
            </xsl:call-template>
        </j:PersonBirthDate>
        <xsl:call-template name="PersonPhysicalDetails" />
        <xsl:apply-templates select="photoIds" />
    </xsl:template>
  
    <xsl:template match="photoIds">
        <j:PersonAssignedIDDetails>
            <j:PersonOtherID>
            <xsl:apply-templates select="photoId" />
            <xsl:apply-templates select="photoIdTypeCode" />
            </j:PersonOtherID>
        </j:PersonAssignedIDDetails>
    </xsl:template>
    
    <xsl:template match="denialReasonCodeDesc">
        <dnrv-ext:ResultCodeDesc>
            <xsl:value-of select="../denialReasonCodeDesc"/>
        </dnrv-ext:ResultCodeDesc>
    </xsl:template>
    
    <xsl:template match="photoId">
           <j:ID><xsl:value-of select="../photoId"/></j:ID>
    </xsl:template>
    
    <xsl:template match="photoIdTypeCode">
        <j:IDTypeText><xsl:value-of select="../photoIdTypeCode"/></j:IDTypeText>     
    </xsl:template>
 
    <xsl:template match="id">
        <dnrv-ext:RequestID>
            <j:ID><xsl:value-of select="../id"/></j:ID>
        </dnrv-ext:RequestID>
    </xsl:template>
    
    <xsl:template match="formNo">
        <dnrv-ext:FormID>
            <j:ID><xsl:value-of select="../formNo"/></j:ID>
        </dnrv-ext:FormID>
    </xsl:template>
    
    <xsl:template match="confirmationNo">
        <dnrv-ext:ConfirmationID>
            <j:ID><xsl:value-of select="../confirmationNo"/></j:ID>
        </dnrv-ext:ConfirmationID>
    </xsl:template>
    
    <xsl:template name="finalDecisionCode">
        <xsl:param name="finalDecisionCode"/>
        <dnrv-ext:ResultTypeCode>        
            <xsl:choose>
            <xsl:when test="$finalDecisionCode = 'DN'">DENIAL</xsl:when>
            <xsl:otherwise>REVERSAL</xsl:otherwise>
            </xsl:choose>
        </dnrv-ext:ResultTypeCode>
    </xsl:template>
    
    <xsl:template match="requestDate">
        <dnrv-ext:RequestDate>
            <xsl:call-template name="DateValue">
                <xsl:with-param name="date" select="../requestDate" />
            </xsl:call-template>
        </dnrv-ext:RequestDate>
    </xsl:template>
    
    <xsl:template match="dealerUid">
        <dnrv-ext:DealerID>
            <j:ID><xsl:value-of select="../dealerUid"/></j:ID>
        </dnrv-ext:DealerID>
    </xsl:template>
 
    <xsl:template name="DateValue">
        <xsl:param name="date"/>
        <xsl:value-of select='substring($date,1,10)'/>
    </xsl:template>
    
    <xsl:template name="PersonName">
        <xsl:param name="FirstName"/>
        <xsl:param name="MiddleName"/>
        <xsl:param name="LastName"/>
        <xsl:param name="Suffix"/>
        <xsl:if test="$FirstName or $MiddleName" >
            <j:PersonName>
                <xsl:if test="$FirstName">
                    <j:PersonGivenName>
                        <xsl:value-of select="$FirstName"/>
                    </j:PersonGivenName>
                </xsl:if>
                <xsl:if test="$MiddleName">
                    <j:PersonMiddleName>
                        <xsl:value-of select="$MiddleName"/>
                    </j:PersonMiddleName>
                </xsl:if>
                <xsl:if test="$LastName">
                    <j:PersonSurName>
                        <xsl:value-of select="$LastName"/>
                    </j:PersonSurName>
                </xsl:if>
                <xsl:if test="$Suffix">
                    <j:PersonSuffixName>
                        <xsl:value-of select="$Suffix"/>
                    </j:PersonSuffixName>
                </xsl:if>
            </j:PersonName>
        </xsl:if>
     </xsl:template>
    
    <xsl:template name="PersonPhysicalDetails">	
        <j:PersonPhysicalDetails>
            <xsl:if test="genderCode">  	
                <j:PersonSexCode>
                    <xsl:value-of select="genderCode"/>
                </j:PersonSexCode>
            </xsl:if>
            <xsl:if test="raceCode">
                <j:PersonRaceCode>
                    <xsl:value-of select="raceCode"/>
                </j:PersonRaceCode>
            </xsl:if>
        </j:PersonPhysicalDetails>
    </xsl:template>
    
</xsl:stylesheet>