<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doc-ext="http://www.doj.state.wi.us/dles/cib/doc/response/extension"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/doc/response" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
    xmlns:xalan="http://xml.apache.org/xslt"
    exclude-result-prefixes="xsl xsi doc-ext doj j xalan"
>
	
	<xsl:import href="../common.xsl" />
	<xsl:import href="../util.xsl" />

	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:DOCResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:apply-templates select="doj:Result/@doj-ext:resultStatusText"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="doj:Result">
		<xsl:param name="fileName" select="."/>
	    <xsl:choose>
	      <xsl:when test="$from='ebc'">
	        <xsl:call-template name="html_main">
				<xsl:with-param name="fileName" select="$fileName"/>
			</xsl:call-template>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:call-template name="html_head_extension" />
	        <!-- This prevents the solid black lines from displaying in online validations (FB 189) -->
	        <div id="container">
	        	<xsl:call-template name="html_body" />
	        </div>
	      </xsl:otherwise>
	    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:param name="fileName"/>
		<xsl:choose>
			<xsl:when test="FormattedResultText">
				<xsl:apply-templates select="FormattedResultText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="doj:ResultText"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="child::node()/doj:InquiryResult"/>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:apply-templates select="@doj-ext:resultStatusText"/>
	</xsl:template>
	
	<xsl:template match="doj:ResultText">
		<xsl:if test="position() = 1">
			<xsl:apply-templates select="." mode="header"/>
		</xsl:if>
		<xsl:choose>
			<!-- failed schema validation so returning raw DOJ XML -->
			<xsl:when test="contains(.,'OffenderResponse')">
				<pre class="legacytext">
					<xsl:value-of select="."/>
				</pre>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="position() != last()">
			<br/>	
		</xsl:if>
	</xsl:template> 
	
	<xsl:template match="FormattedResultText">
		<xsl:apply-templates select="." mode="header"/>
		<pre class="legacytext">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</pre>
	</xsl:template>
	
	<!-- File Type Header -->
	<xsl:template match="*" mode="header">
		<!-- Data Service Logo -->	
		<xsl:call-template name="docLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width90percent">
					<table>
						<tr><td>
							<span class="filetype">
								<xsl:text>DOC</xsl:text>
									<xsl:apply-templates select="../@doj-ext:resultStatusText"/>
								<xsl:text>Response</xsl:text>
							</span>
						</td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>
	
	<xsl:template match="@doj-ext:resultStatusText"> 
		<xsl:choose>
			<xsl:when test=".='Normal'">
				<!--  normal response with no hits -->
				<xsl:text>&#32;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- For advisory, queued, reject or error (with no legacy) responses -->
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="."/>
				<xsl:text>&#32;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="docLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<xsl:element name="img">
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'doc.jpg')"/></xsl:attribute>
						<xsl:attribute name="alt">DOC Logo</xsl:attribute>
						<xsl:attribute name="width">50</xsl:attribute>
						<xsl:attribute name="height">50</xsl:attribute>
					</xsl:element>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	
</xsl:transform>