<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/internal/nciciii/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
	xmlns:nciciii-ext="http://www.doj.state.wi.us/dles/cib/internal/nciciii/modify/extension" 
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2" 
	xmlns:xalan="http://xml.apache.org/xslt" 
	exclude-result-prefixes="xsl xsi dnr-ext doj j xalan">
	
	<xsl:import href="../common.xsl" />
	<xsl:import href="../util.xsl" />
	
	<xsl:param name="from" />
    <xsl:param name="imageBase">
	  <xsl:text>../../images/</xsl:text>
	</xsl:param>
	<xsl:param name="responseId">
		<xsl:value-of select="doj:NCICIIIInternalResponseDocument/@doj-ext:responseID" />
	</xsl:param>
	
	<xsl:output method="html" 
				version="4.01" 
				encoding="UTF-8" 
				omit-xml-declaration="yes" 
				doctype-public="-//W3C//DTD HTML 4.01//EN" 
				doctype-system="http://www.w3.org/TR/html4/strict.dtd" 
				indent="yes" 
				media-type="text/html" 
				xalan:indent-amount="2" />
	
	
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$from='ebc'">
				<xsl:call-template name="html_main" />
			</xsl:when>
			<xsl:when test="$from='firearms'">
				<div>
					<xsl:call-template name="html_body" />
				</div>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="html_head_extension" />
				<xsl:call-template name="html_body" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="html_title">
		III - Firearms Response
	</xsl:template>
	
	
	<xsl:template name="html_body">
		<xsl:call-template name="iiiLogo" />
		<hr />
		<!-- Not all of the following will be applicable on a single response -->
		<xsl:apply-templates select="doj:NCICIIIInternalResponseDocument/doj:Result/doj:ResultText" />
		<!-- Hit response -->
		<xsl:apply-templates select="doj:NCICIIIInternalResponseDocument/doj:Result/doj:IIIFirearmsResponse" />
	</xsl:template>
	
	
	<xsl:template name="iiiLogo">
		<table width="100%">
			<tr>
				<td align="right">
				  <xsl:element name="img">
				    <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'III.gif')"/></xsl:attribute>
				    <xsl:attribute name="alt">III Logo</xsl:attribute>
				    <xsl:attribute name="width">60</xsl:attribute>
				    <xsl:attribute name="height">30</xsl:attribute>
				  </xsl:element>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	
	<xsl:template match="doj:ResultText">
		<div class="resulttext">
			<h1 class="filetype">
				<xsl:value-of select="." />
			</h1>
		</div>
	</xsl:template>
	
	
	<xsl:template match="doj:IIIFirearmsResponse">
		<table class="detailvalue" cellspacing="0">
			<tr>
				<td colspan="2">
						<xsl:text>NICS Transaction Number:&#160;</xsl:text>
						<xsl:value-of select="doj:NICSTransactionNumber/j:ID" />
				</td>
			</tr>
			<tr>
				<td colspan="2">
						<xsl:text>III Response:&#160;</xsl:text>
						<pre>
							<xsl:value-of select="doj:IIIQueryResponse/text()" />
						</pre>
				</td>
			</tr>
			<tr>
				<td><br /></td>
			</tr>
		</table>
	</xsl:template>
	
</xsl:transform>