<?xml version="1.0"?>
<xsl:transform version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
  xmlns:doj="http://www.doj.state.wi.us/dles/cib/nlets/response" 
  xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
  xmlns:j="http://www.it.ojp.gov/jxdm/3.0" 
  xmlns:j2="http://www.it.ojp.gov/jxdm/3.0.2" 
  xmlns:n="http://www.nlets.org" 
  xmlns:xalan="http://xml.apache.org/xslt" 
  xmlns:ebcutil="us.wi.state.doj.etime.ebc.util.EBCUtil" 
  xmlns:java="java" 
  exclude-result-prefixes="xsl xsi doj doj-ext j j2 n xalan java ebcutil">
  
  <xsl:import href="../common.xsl" />
  <xsl:import href="../util.xsl" />
  <xsl:param name="from" />
  <xsl:param name="nightMode" />
  <xsl:param name="responseId">
    <xsl:value-of select="doj:NLETSResponseDocument/@doj-ext:responseID" />
  </xsl:param>
  
  <xsl:output method="html" version="4.01" encoding="UTF-8" 
    omit-xml-declaration="yes" doctype-public="-//W3C//DTD HTML 4.01//EN" 
    doctype-system="http://www.w3.org/TR/html4/strict.dtd" indent="yes" 
    media-type="text/html" xalan:indent-amount="2" />
  
  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$from='ebc'">
        <xsl:call-template name="html_main" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="html_head_extension" />
        <xsl:call-template name="html_body" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="html_title">TIME - NLETS</xsl:template>
  
  <xsl:template name="html_body">
    <!-- Format header information -->
    <xsl:variable name="HEADER_INFORMATION">
      <xsl:choose>
        <xsl:when test="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID">
          <xsl:value-of select="substring(doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentSource.Organization/j:OrganizationORIID/j:ID,1,2)" />
          <xsl:text> </xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>NLETS </xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <!-- Not all of the following will be applicable on a single response -->
    <xsl:apply-templates select="doj:NLETSResponseDocument/doj:Result/doj:ResultText">
      <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
    <xsl:apply-templates select="doj:NLETSResponseDocument/doj:Result/n:NLETS/n:NLETSResponseMessage/n:NLETSResponseData/n:ResponseText">
      <xsl:with-param name="headerInformation" select="$HEADER_INFORMATION" />
    </xsl:apply-templates>
  </xsl:template>
  
  <xsl:template match="j:DocumentFiledDate">
    <p>
      <label>Search Date: </label>
      <span>
        <xsl:value-of select="."/>
      </span>
    </p>  
  </xsl:template>
  <xsl:template match="j:Subject">
    <p>
      <label>Search Criteria:</label> 
      <div style="margin-left:2em; width:80%" class="tableDiv">
        <p>
          <label>Name: </label>
          <span><xsl:apply-templates select="j:PersonName"></xsl:apply-templates></span>
        </p>
        <p>
          <label>DOB: </label>
          <span>
            <xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>
          </span>
        </p>
        <p>
          <label>Place of Birth: </label>
          <span>
            <xsl:value-of select="j:PersonBirthPlaceCode"/>
          </span>
        </p>
        <p>
          <label>Sex:</label>
          <span><xsl:value-of select="j:PersonPhysicalDetails/j:PersonSexCode"/></span>
        </p>
        <p>
          <label>FBI ID:</label>
          <span><xsl:value-of select="j:PersonAssignedIDDetails/j:PersonFBIID/j:ID"/></span>
        </p>
        <xsl:if test="j:PersonAssignedIDDetails/j:PersonOtherID">
          <p><label>Other Id:</label>
            <xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID">
              <span><xsl:value-of select="j:ID"/>
                <xsl:if test="j:PersonIDTypeCode">/<xsl:value-of select="j:PersonIDTypeCode"/></xsl:if>
                <xsl:if test="j:IDTypeText">/<xsl:value-of select="j:IDTypeText"/></xsl:if>
              <xsl:if test="position()!= last()"><xsl:text>, </xsl:text></xsl:if>
              </span>
            </xsl:for-each>
          </p>
        </xsl:if>
        
      </div>
    </p>
  </xsl:template>
  
  <xsl:template match="doj:ResultText | n:ResponseText">
    <xsl:param name="headerInformation" />
    <!-- Data Service Logo -->
    <xsl:call-template name="nletsLogo" />
    <h4>LESC(Law Enforcement Suport Center) Result</h4>    
    <xsl:apply-templates select="ancestor::n:NLETSResponseMessage/n:NLETSResponseHeader/j:DocumentFiledDate"/>
    <xsl:apply-templates select="ancestor::n:NLETSResponseMessage/n:NLETSInquiryData/j:Subject"/>
    <!-- File Type Header Section -->
    <table>
      <tr>
        <td class="width90percent">
          <table>
            <tr>
              <td>
                <span class="filetype">
                  <xsl:value-of select="$headerInformation" />
                  <xsl:variable name="key" select="parent::n:NLETSResponseData/@Key"></xsl:variable>
                  <xsl:choose>
                    <xsl:when test="$key='IAR'">
                      <xsl:text>IAR response</xsl:text>
                    </xsl:when>
                    <xsl:when test="$key='SWR'">
                      <xsl:text>State Warrant Response</xsl:text>
                    </xsl:when>
                    <xsl:when test="$key='DR'">
                      <xsl:text>DR Response</xsl:text>
                    </xsl:when>
                  </xsl:choose>
                </span>
              </td>
            </tr>
          </table>
        </td>
      </tr>
    </table>
        
    <pre class="legacytext">
      <xsl:choose>
        <xsl:when test="$from='ebc'">
          <xsl:value-of select="ebcutil:formartLegacyText(.)" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </pre>
    <!-- Horizontal Line -->
    <hr />
  </xsl:template>
  
  <xsl:template name="nletsLogo">
    <table width="100%">
      <tr>
        <td align="right">
          <xsl:element name="img">
            <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'spacer.gif')"/></xsl:attribute>
            <xsl:attribute name="width">100</xsl:attribute>
            <xsl:attribute name="height">1</xsl:attribute>
          </xsl:element>
          <xsl:element name="img">
            <xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'nlets.gif')"/></xsl:attribute>
            <xsl:attribute name="alt">NLETS Logo</xsl:attribute>
          </xsl:element>
        </td>
      </tr>
    </table>
  </xsl:template>
  
</xsl:transform>