<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>
	
	<!--  CIB - MENTAL HEALTH PERSON RECORD -->
	<!-- ############  -->
	<!-- main template -->
	<!-- ############  -->
	<xsl:template match="/doj:CIBResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - CIB Mental Health Person</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:CourtOrder/j:CourtOrderDesignatedSubject" mode="subject_details_all"/>
		<div>
		<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgencyDetails">
				<xsl:with-param name="enteringAgencyDetails" select="cib-ext:EnteringAgencyDetails"></xsl:with-param>
			</xsl:call-template>
		</div>
		<xsl:apply-templates select="." mode="record_details"/>	 
	</xsl:template>
	
	<!-- ###########################  -->
	<!-- File Type Header	 		  -->
	<!-- ###########################  -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic"><xsl:value-of select="concat($imageBase,'mentalhealth.jpg')"/><xsl:text>-</xsl:text><xsl:text>Mental Health</xsl:text></xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Court Order Details-->	
		<table style="width:70%">
			<!-- Court order status and case No-->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Status:'"/>
				<xsl:with-param name="value1" select="cib-ext:CourtOrder/j:ActivityStatus/j:StatusText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Court Case No:'"/>
				<xsl:with-param name="value2">
					<xsl:value-of select="cib-ext:CourtOrder/j:CaseDocketID/j:ID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'basiclabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'basicvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court Name -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'CourtName :'"/>
				<xsl:with-param name="value1">
					<xsl:value-of select="cib-ext:CourtOrder/j:CourtOrderIssuingCourt/j:OrganizationName"/>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
			</xsl:call-template>
			<!-- Restriction Begin and End Dates -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Restriction Begin Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="cib-ext:CourtOrder/j:CourtOrderIssuingDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Restriction End Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:CourtOrder/j:CourtOrderIssuingDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Offense Date and Form Date -->   
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Offense Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="cib-ext:CourtOrder/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Form Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:CourtOrder/j:ActivityDocket/j:DocumentDescriptiveMetadata/j:DocumentFiledDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Submitted By Name -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Form Submitted By Name:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="cib-ext:CourtOrder/j:ActivityDocket/j:DocumentDescriptiveMetadata/j:DocumentSubmitter.Person/j:PersonName"></xsl:apply-templates>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Warrant Number and Warrant Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Number:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/> 
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Warrant Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:ArrestWarrant/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court ORI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Court ORI:'"/>
				<xsl:with-param name="value1" select="j:ArrestWarrant/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template> 
	
</xsl:stylesheet>