<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  CIB - NO FILE TYPE RECORD -->
	<xsl:import href="cib_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:CIBResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName"> 
				<xsl:apply-templates select="doj:Result/@doj-ext:resultStatusText"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:apply-templates select="@doj-ext:resultStatusText"/>
	</xsl:template>
	
	<xsl:template match="doj:ResultText">
		<xsl:apply-templates select="." mode="header"/>
		<pre class="legacytext">
			<xsl:value-of select="."/>
		</pre>
	</xsl:template> 
	
	<xsl:template match="FormattedResultText">
		<xsl:apply-templates select="." mode="header"/>
		<pre class="legacytext">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</pre>
	</xsl:template>
	
	<!-- File Type Header -->
	<xsl:template match="*" mode="header">
		<!-- Data Service Logo -->	
		<xsl:call-template name="cibLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width90percent">
					<table>
						<tr><td>
							<span class="filetype">
								<xsl:text>CIB&#32;</xsl:text>
									<xsl:value-of select="../@doj-ext:resultStatusText"/>
								<xsl:text>&#32;Response</xsl:text>
							</span>
						</td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>
	
	<xsl:template match="@doj-ext:resultStatusText"> 
		<xsl:choose>
			<xsl:when test=".='Normal'">
				<!--  normal response with no hits -->
				<xsl:text>&#32;</xsl:text>
			</xsl:when>
			<xsl:when test="../doj:NCICLegacyText">
				<xsl:text>&#32;Legacy&#32;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- For advisory, queued, reject or error (with no legacy) responses -->
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="."/>
				<xsl:text>&#32;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
</xsl:transform>