<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/cib/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">

	<xsl:import href="cib_common.xsl"/>

	<!-- Date of Birth followed by a semi-colon -->
	<xsl:template match="cib-ext:PersonBirthDateText | j:PersonBirthDate">
		<!--  Date of Birth: Full Date -->
		<xsl:apply-templates select="." mode="FormatFullDateAsMMDDYYYY"/>
		<xsl:if test="position() != last()">
			<xsl:text>;&#160;</xsl:text>
		</xsl:if>
	</xsl:template> 
	
	<!-- Name in format First, Middle, Last, Suffix -->
	<xsl:template match="j:PersonName">
		<span class="subjecttitle">
			<xsl:value-of select="j:PersonSurName"/>
			<xsl:if test="j:PersonGivenName">
				<xsl:text>,&#160;</xsl:text>
				<xsl:value-of select="j:PersonGivenName"/>
			</xsl:if>
			<xsl:if test="j:PersonMiddleName or j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:PersonMiddleName"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:PersonSuffixName"/>
			</xsl:if>
		</span>
	</xsl:template> 

	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:SupervisionSubject | j:RegisteredSexOffender" 
		mode="subject_caution_all">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">Record Details</xsl:attribute>
						</xsl:element>
						<!--<img src="../../images/RecordDetails.jpg" alt="Record Details"/> -->
					</a>
				</td>
				<td class="width80percent" align="center">
					<xsl:apply-templates select="cib-ext:SubjectCautionInformationText"/>
				</td>
				<td class="width10percent"></td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:SupervisionSubject | j:RegisteredSexOffender | j:Person" 
		mode="subject_details_all">
		<br/>	
		<table>
			<tr>
				<td class="width80percent"> 
					<!-- Name -->
					<xsl:apply-templates select="j:PersonName"/>
					<br/>
					<!-- Gender/Race -->
					<div class="subjectvalue">
					<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonSexText" mode="TitleCase"/>	
					<xsl:text>&#160;&#160;</xsl:text>
					<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonRaceText" mode="TitleCase"/>	
					<br/>		
					<!-- more person details --> 
					<xsl:if test="cib-ext:PersonBirthPlaceName">
						<xsl:text>Born in&#160;</xsl:text>
						<xsl:value-of select="cib-ext:PersonBirthPlaceName"/>
						<br/>
					</xsl:if>
					<!-- Person primary birthdate -->
					<xsl:apply-templates select="j:PersonBirthDate"/>
					<xsl:apply-templates select="cib-ext:PersonBirthDateText"/>
					<xsl:apply-templates select="cib-ext:PersonBirthYear.Range"/>
					<!--  Person other birth dates -->
					<xsl:if test="j:PersonAlias/cib-ext:PersonBirthDateText">
						<xsl:text>;&#32;</xsl:text>
						<xsl:for-each select="j:PersonAlias/cib-ext:PersonBirthDateText">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#32;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if> 
					<br/>
					<!-- Emancipation Date - only wanted person -->
					<xsl:if test="cib-ext:SubjectEmancipationDate">
						<xsl:text>Emancipation&#160;Date:&#160;</xsl:text>
						<xsl:apply-templates select="cib-ext:SubjectEmancipationDate" mode="FormatFullDateAsMMDDYYYY"/>
						<br/>
					</xsl:if>			
					<!-- Height and weight -->
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure">
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,1,1)" />
						<xsl:text>'</xsl:text>
						<xsl:value-of select="substring(j:PersonPhysicalDetails/j:PersonHeightMeasure,2,2)" />
						<xsl:text>"</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure='UNK'">
						              <xsl:text>Unknown Height</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,1,1)" />
									<xsl:text>'</xsl:text>
									<xsl:value-of select="substring(j:PersonPhysicalDetails/cib-ext:PersonHeightMeasure,2,2)" />
									<xsl:text>"</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if> 			
					<xsl:if test="j:PersonPhysicalDetails/j:PersonWeightMeasure">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonWeightMeasure"/>
						<xsl:text>&#160;lbs</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure">
						<xsl:choose>
						       <xsl:when test="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure='UNK'">
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:text>Unknown Weight</xsl:text> 
						       </xsl:when>
						       <xsl:otherwise>
						              <xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						              <xsl:value-of select="j:PersonPhysicalDetails/cib-ext:PersonWeightMeasure"/>
						              <xsl:text>&#160;lbs</xsl:text>
						       </xsl:otherwise>
						</xsl:choose>
					</xsl:if>
					<!-- Eyes and hair --> 
					<xsl:if test="j:PersonPhysicalDetails/j:PersonEyeColorText">
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonEyeColorText"/>
						<xsl:text>&#160;Eyes</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHairColorText"> 
						<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						<xsl:value-of select="j:PersonPhysicalDetails/j:PersonHairColorText"/>
						<xsl:text>&#160;Hair</xsl:text>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/j:PersonHeightMeasure 
						or j:PersonPhysicalDetails/j:PersonWeightMeasure
						or j:PersonPhysicalDetails/j:PersonEyeColorText
						or j:PersonPhysicalDetails/j:PersonHairColorText">
						<br/>
					</xsl:if>
					<!-- bald, mustache, beard, ethnic (Sex Offender only) -->
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBaldIndicator">
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBaldIndicator = 'true'">Bald</xsl:if>
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBaldIndicator = 'false'">Not Bald</xsl:if>
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonMustacheIndicator 
							or j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator 
							or j:PersonSocialDetails/j:PersonEthnicityText"> 
							<xsl:text>/</xsl:text>
						</xsl:if>
					</xsl:if>
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonMustacheIndicator">
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonMustacheIndicator= 'true'">Mustache</xsl:if>
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonMustacheIndicator = 'false'">No Mustache</xsl:if>
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator or j:PersonSocialDetails/j:PersonEthnicityText">
							<xsl:text>/</xsl:text>
						</xsl:if>
					</xsl:if>				
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator">
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator= 'true'">Beard</xsl:if>
						<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator= 'false'">No Beard</xsl:if>
						<xsl:if test="j:PersonSocialDetails/j:PersonEthnicityText">
							<xsl:text>/</xsl:text>
						</xsl:if>
					</xsl:if>			
					<xsl:value-of select="j:PersonSocialDetails/j:PersonEthnicityText"/>		
					<xsl:if test="j:PersonPhysicalDetails/cib-ext:PersonBaldIndicator 
							or j:PersonPhysicalDetails/cib-ext:PersonMustacheIndicator 
							or j:PersonPhysicalDetails/cib-ext:PersonBeardIndicator or 
							j:PersonSocialDetails/j:PersonEthnicityText">	
						<br/>
					</xsl:if>
					<!-- Address -->
					<xsl:for-each select="j:Residence">
						<xsl:if test="j:LocationAddress/j:LocationStreet/j:StreetFullText">
							<xsl:value-of select="j:LocationAddress/j:LocationStreet/j:StreetFullText"/>
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:if test="j:LocationAddress/j:LocationCityName">
							<xsl:apply-templates select="j:LocationAddress/j:LocationCityName" mode="TitleCase"/>
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>			
						<xsl:if test="j:LocationAddress/j:LocationStateName">
							<xsl:value-of select="j:LocationAddress/j:LocationStateName"/>
						</xsl:if>	
						<xsl:if test="j:LocationAddress/j:LocationPostalCodeID">
							<xsl:text>,&#160;</xsl:text>
							<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeID"/>
							<xsl:if test="j:LocationAddress/j:LocationPostalCodeExtensionID">
								<xsl:text>-</xsl:text>
								<xsl:value-of select="j:LocationAddress/j:LocationPostalCodeExtensionID"/>
							</xsl:if>
						</xsl:if>	
						<!--  telephone number -->
						<xsl:if test="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID">
							<xsl:text>&#160;&#160;&#160;&#160;&#160;Telephone Number:&#160;</xsl:text>
							<xsl:value-of select="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
						</xsl:if>
						<br/> 
					</xsl:for-each>
					<!--  telephone number -->
					<xsl:if test="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID">
						<xsl:text>Telephone Number:&#160;</xsl:text>
						<xsl:value-of select="j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
						<br/>
					</xsl:if> 
					</div>
				</td>
				<td class="width20percent" valign="left">
					<!--  picture of file goes here - it is not implemented at this point SConrad 8/30/2006 -->
					<!-- <img src="../../images/Ozzy.bmp"  alt="Person Picture"  width="60px;"  height="60px;" /> -->
					<!-- 09/2010 per CIB display the Alias/Fraud link when the following is in the XML -->
					<xsl:if test="j:PersonAlias/j:PersonName or cib-ext:PersonStolenFraudulent">
						<br/>
						<a href="#alias{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="src">
									<xsl:value-of select="concat($imageBase,'aliasfraudlink.jpg')"/>
								</xsl:attribute>
								<xsl:attribute name="alt">Link to alias info</xsl:attribute>
							</xsl:element>
							<!-- <img src="../../images/aliasfraudlink.jpg" alt="Link to alias info" /> -->
						</a>
					</xsl:if>
					<xsl:if test="../j:ProtectionOrderRestrictedPerson">
						<br/>
						<a href="#petitioner{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="src">
									<xsl:value-of select="concat($imageBase,'Petitioner.jpg')"/>
								</xsl:attribute>
								<xsl:attribute name="alt">Link to petitioner info</xsl:attribute>
							</xsl:element>
							<!-- <img src="../../images/Petitioner.jpg" alt="Link to petitioner info"/> -->
						</a>
					</xsl:if>
					<xsl:if test="../j:IncidentVictim">
						<br/>
						<a href="#victimInfo{$responseId}">
							<xsl:element name="img">
								<xsl:attribute name="src">
									<xsl:value-of select="concat($imageBase,'VictimInformation.jpg')"/>
								</xsl:attribute>
								<xsl:attribute name="alt">Link to victim info</xsl:attribute>
							</xsl:element>
							<!-- <img src="../../images/VictimInformation.jpg" alt="Link to victim info"/> -->
						</a>
					</xsl:if>	
					<xsl:if test="../cib-ext:PersonWithInformation">
						<br/>
            			<a href="#personWithInfo{$responseId}">
            				<xsl:element name="img">
            					<xsl:attribute name="src">
            						<xsl:value-of select="concat($imageBase,'personWithInfo.jpg')"/>
            					</xsl:attribute>
            					<xsl:attribute name="alt">Link to person with information</xsl:attribute>
            				</xsl:element>
            				<!-- <img src="../../images/personWithInfo.jpg" alt="Link to person with information"/> -->
            			</a>
          		</xsl:if>	
				</td>
			</tr>
		</table>
	</xsl:template> 

	<!-- FBI, SSN, stateID, Miscellaneous #, skintone, scarmark -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender" mode="FBItoSMT">
		<xsl:if test="j:PersonAssignedIDDetails or j:PersonPhysicalDetails/j:PersonSkinToneText">
			<br/>
		</xsl:if>
		<!--  FBI and Social Security -->
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'FBI:'"/>
				<xsl:with-param name="value1" select="j:PersonAssignedIDDetails/j:PersonFBIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Social Security #:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:text>; </xsl:text>
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
							<xsl:apply-templates select="." mode="FormatSSN"/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#160;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>			
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>
			</xsl:call-template>		
			<!-- State ID and Miscellaneous # -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'State ID:'"/>
				<xsl:with-param name="value1" select="j:PersonAssignedIDDetails/j:PersonStateID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Miscellaneous #:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="."/>
					</xsl:for-each>
					<xsl:if test="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:for-each select="j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
							<xsl:text>;&#10;</xsl:text>
							<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
							<xsl:text>-</xsl:text>
							<xsl:value-of select="."/>
						</xsl:for-each>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>			
			</xsl:call-template>
			<!-- Skintone: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Skintone:'"/>
				<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonSkinToneText"/>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width15percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width15percent'"/>
				<xsl:with-param name="label2" select="'Scarmark:'"/>
				<xsl:with-param name="value2">
					<xsl:for-each select="j:PersonPhysicalDetails/j:PersonPhysicalFeature">
						<xsl:value-of select="j:PhysicalFeatureTypeText"/>
						<xsl:if test="position() != last()">
							<xsl:text>; </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width20percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width50percent'"/>		
			</xsl:call-template>
		</table>
	</xsl:template>

	<!-- FBI, SSN, stateID, Miscellaneous #, skintone, scarmark --> 
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender" 
		mode="DLtoDNALoc">
		<xsl:if test="j:DriverLicense or j:PersonPhysicalDetails/j:PersonDental or j:PersonBiometricDetails or cib-ext:PersonCircumcisionText">
			<br/>
		</xsl:if>
		<table>
			<xsl:apply-templates select="." mode="DriverLicense"/> 
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonFingerprintSet/j:BiometricValueText" />
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDNA"/>
			<xsl:apply-templates select="j:PersonBiometricDetails/j:PersonDNA/cib-ext:DNALocationInformationText"/> 
			<!--  glasses -->
			<xsl:apply-templates select="j:PersonMedicalDetails/j:PersonVisionPrescriptionText"/> <!-- missing person -->
			<xsl:apply-templates select="j:PersonPhysicalDetails/cib-ext:PersonEyeWearIndicator"/> <!-- sex offender -->
			<!--  circumcised -->
			<xsl:apply-templates select="cib-ext:PersonCircumcisionText"/> <!-- missing and unidentified -->
			<!--  dental -->
			<xsl:apply-templates select="." mode="DentalInfo"/>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonCircumcisionText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Circumcision:'"/>			
			<xsl:with-param name="value1"> 
				<xsl:value-of select="."/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template>

	<xsl:template match="j:PersonVisionPrescriptionText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Glasses:'"/>			
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonEyeWearIndicator">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Glasses:'"/>			
			<xsl:with-param name="value1">
				<xsl:apply-templates select="." mode="FormatBooleanAsYesNo"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>		
	</xsl:template> 
	
	<!-- Dental Information  -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender" 
		mode="DentalInfo">
		<xsl:if test="j:PersonPhysicalDetails/j:PersonDental">
			<table>
				<xsl:call-template name="ConditionalRow">
					<xsl:with-param name="label1" select="'Dental X_RAY:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates 
							select="j:PersonPhysicalDetails/j:PersonDental/cib-ext:PersonDentalXRaysAvailableIndicator" 
							mode="FormatBooleanAsYesNo"/>
					</xsl:with-param> 
					<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
					<xsl:with-param name="label2" select="'Dental Model Available:'"/>
					<xsl:with-param name="value2">
						<xsl:apply-templates 
							select="j:PersonPhysicalDetails/j:PersonDental/cib-ext:PersonDentalModelPhotoAvailableIndicator" 
							mode="FormatBooleanAsYesNo"/>
					</xsl:with-param>
					<xsl:with-param name="label_class_name2" select="'detaillabel uppercase width25percent'"/>
					<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
				</xsl:call-template>
			</table> 
			<!-- DCH or TEETH: -->
			<table>
				<xsl:choose>
					<!-- TEETH -->
					<xsl:when test="j:PersonPhysicalDetails/j:PersonDental/j:PersonTooth"> 
						<tr>
							<td class="detaillabel uppercase width25percent">
								<xsl:text>DCH:</xsl:text>
							</td>
							<td class="detailvalue width75percent">
								<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonTooth"/>
							</td>
						</tr>
					</xsl:when>
					<!--  DCH -->
					<xsl:otherwise>
						<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonDentalCharacteristicGeneralText"/>
					</xsl:otherwise>
				</xsl:choose>
			</table>
			<!--  remarks -->
			<table>
				<xsl:apply-templates select="j:PersonPhysicalDetails/j:PersonDental/j:PersonDentalCharacteristicText"/>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="j:PersonDentalCharacteristicGeneralText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'DCH:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="j:PersonDentalCharacteristicText"> 
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Dental Remarks:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	 
	<xsl:template match="j:PersonTooth">
		<span class="tooth"><xsl:value-of select="j:PersonToothIDCode"/></span>
		<xsl:text>-</xsl:text>
		<!-- The status of dental codes  -->
		<xsl:for-each select="cib-ext:PersonToothStatus/cib-ext:PersonToothStatusText">	
			<xsl:value-of select="."/>
			<xsl:if test="position()!=last()">
				<xsl:text>/</xsl:text>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="position()!=last()">
			<xsl:text>,&#160;</xsl:text>
		</xsl:if>
		<xsl:if test="number ( position() mod 4) = 0">
		   <br/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="aliasHeader">
		<br/>
		<a name="alias{$responseId}">
		<span class="detaillabel">ALIAS NAMES/FRAUDULENT DATA:</span>
		</a>
	</xsl:template>
		
	<!-- Caution Medical Conditions (reusable by all file types) -->
	<xsl:template match="cib-ext:SubjectCautionInformationText">
		<xsl:choose>
			<xsl:when test="position() = 1">
				<span class="medicallabel">
					<xsl:text>Caution&#160;-&#160;Medical&#160;Condition:&#160;&#160;</xsl:text>
					<xsl:apply-templates select="." mode="TitleCase"/>		 
				</span>
			</xsl:when>
			<xsl:otherwise>
				<br/>
				<span class="medicalvalue">
					<xsl:apply-templates select="." mode="TitleCase"/>							
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Drivers License (1 master, n supp.in PersonAlias) -->
	<xsl:template match="j:CourtOrderDesignatedSubject | j:MissingPerson | j:RegisteredSexOffender" mode="DriverLicense">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1">
				<xsl:if test="j:DriverLicense">
					<xsl:text>Drivers License #:</xsl:text>
				</xsl:if>				
			</xsl:with-param>
			<xsl:with-param name="value1"> 
				<xsl:for-each select="j:DriverLicense/j:DriverAuthorizationID.Detailed">
					<xsl:value-of select="j:ID"/>
					<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="j:IDIssuingAuthorityText"/> 
					<xsl:if test="j:IDIssuingAuthorityText">
						<xsl:text>,&#160;</xsl:text>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
						    <xsl:text>Unknown Expiration Year</xsl:text> 
						</xsl:when>
						<xsl:otherwise>
						    <xsl:value-of select="cib-ext:IDExpirationYear"/>
						</xsl:otherwise>
					</xsl:choose>					
				</xsl:for-each>
				<xsl:for-each select="j:PersonAlias/j:DriverLicense/j:DriverAuthorizationID.Detailed">
					<xsl:text>;&#10;</xsl:text>
					<xsl:value-of select="j:ID"/>
					<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="j:IDIssuingAuthorityText"/>
					<xsl:if test="j:IDIssuingAuthorityText">
						<xsl:text>,&#160;</xsl:text>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
						    <xsl:text>Unknown Expiration Year</xsl:text> 
						</xsl:when>
						<xsl:otherwise>
						    <xsl:value-of select="cib-ext:IDExpirationYear"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Fingerprint (on its own line)   -->
	<xsl:template match="j:BiometricValueText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Fingerprint Class:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>
	</xsl:template>
	
	<!-- DNA Available (on its own line)   -->
	<xsl:template match="j:PersonDNA">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'DNA Available:'"/>
			<xsl:with-param name="value1">
				<xsl:if test="@j:commentText = 'available'">
					<xsl:text>Yes</xsl:text>
				</xsl:if>
				<xsl:if test="@j:commentText = 'unavailable'">
					<xsl:text>No</xsl:text>
				</xsl:if>				
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>	
	</xsl:template>
	
	<!-- DNA Location (on its own line)  -->
	<xsl:template match="cib-ext:DNALocationInformationText">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Dna Location:'"/>
			<xsl:with-param name="value1" select="."/>
			<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>	
		</xsl:call-template>	
	</xsl:template>
	
	<xsl:template name="vehicle_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/cib-ext:Vehicle">
			<br/>
			<table>
				<tr>
					<td class="width25percent">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'VehicleIcon.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">Vehicle</xsl:attribute>
						</xsl:element>
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/cib-ext:Vehicle" >
							<xsl:call-template name="Vehicle"/>
							<br/>
						</xsl:for-each>
					</td> 
				</tr>
			</table>
		</xsl:if> 
	</xsl:template>
	
	<!-- Vehicle  -->
	<xsl:template name="Vehicle">
		<span class="detailvalue">
			<xsl:value-of select="j:VehicleModelYearDate"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="cib-ext:VehicleMakeText"/>
			<!-- Vehicle Make Comment Text -->
			<xsl:if test="cib-ext:VehicleMakeCommentsText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="cib-ext:VehicleMakeCommentsText"/>
			</xsl:if>
			<xsl:if test="j:VehicleModelCodeText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="j:VehicleModelCodeText"/>
			</xsl:if>
			<xsl:if test="j:VehicleColorPrimaryText">
				<xsl:text>,&#160;</xsl:text>
				<xsl:value-of select="j:VehicleColorPrimaryText"/>
				<xsl:if test="j:VehicleColorSecondaryText">
					<xsl:text>/</xsl:text>
					<xsl:value-of select="j:VehicleColorSecondaryText"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="cib-ext:VehicleStyleText">
				<xsl:text>,&#160;</xsl:text>
					<xsl:value-of select="cib-ext:VehicleStyleText"/>
				</xsl:if>
				<xsl:if test="j:VehicleID/j:ID">
					<xsl:text>,&#160; VIN&#160;</xsl:text>
				<xsl:value-of select="j:VehicleID/j:ID" /> 
			</xsl:if>
		</span>
		<br/>
	</xsl:template>
	
	<xsl:template name="licensePlate_all">
		<xsl:param name="parent" select="."/>
		<xsl:if test="$parent/cib-ext:LicensePlate">
			<br/>
			<table>
				<tr>
					<td class="width25percent" valing="top">
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'Plate1.jpg')"/></xsl:attribute>
							<xsl:attribute name="alt">License Plate</xsl:attribute>
						</xsl:element>
						<!-- <img src="../../images/Plate1.jpg" alt="License Plate" width="100"/> -->
					</td>
					<td class="width75percent">
						<xsl:for-each select="$parent/cib-ext:LicensePlate" >
							<xsl:call-template name="LicensePlate"/>
						</xsl:for-each> 
					</td> 
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<!-- Plates -->
	<xsl:template name="LicensePlate">
		<span class="detailvalue">
			<xsl:value-of select="j:VehicleRegistrationPlateID/j:ID"/>	
			<xsl:text>,&#160;</xsl:text>		
			<xsl:value-of select="j:RegistrationJurisdictionName"/>
			<xsl:text>&#160;</xsl:text>		
			<xsl:choose>
				<xsl:when test="cib-ext:RegistrationExpirationYear = 'NX'"> 
					<xsl:text>Non-Expiring</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>Exp.&#160;</xsl:text>
					<xsl:value-of select="cib-ext:RegistrationExpirationYear"/> 
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="j:VehicleRegistrationPlateTypeText"/> 
		</span><br/>
	</xsl:template>

	<xsl:template match="j:VehicleRegistrationPlateTypeText">
		<xsl:text>,&#160;</xsl:text>
		<xsl:value-of select="."/>	
	</xsl:template>
	
	<!-- Alias Names -->
	<xsl:template match="j:CourtOrderDesignatedSubject |j:MissingPerson | j:RegisteredSexOffender | cib-ext:SupervisionSubject | j:Person" 
		mode="alias">
		<xsl:if test="j:PersonAlias/j:PersonName">
			<xsl:call-template name="aliasHeader"/>
				<table>
					<tr>
						<td class="detailsublabel width25percent">Alias Names:</td>
						<td class="width75percent">
							<xsl:call-template name="listAlias"/>
						</td>
					</tr>
				</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="listAlias">
		<table>
			<xsl:for-each select="j:PersonAlias/j:PersonName[position() mod 2 != 0]">
                <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                <xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
                    <tr>
                        <xsl:apply-templates select="../j:PersonName" mode="aliasNames">
                             <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                             <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                             <xsl:with-param name="startposition" select="$startposition"/>
                        </xsl:apply-templates>
                    </tr>
            </xsl:for-each>
          </table>
	</xsl:template>
	
	<xsl:template match="j:PersonName" mode="aliasNames">
        <xsl:param name="startposition"/>
        <xsl:if test="position() = number($startposition) or position() = number($startposition)+1">
            <td class="width50percent"><xsl:apply-templates select="." mode="alias"/></td>
        </xsl:if>
    </xsl:template>
	
	<!-- Name in format Last, First, Middle, Suffix -->
	<xsl:template match="*" mode="alias">
		<span class="detailvalue">
			<xsl:apply-templates select="j:PersonSurName" mode="TitleCase"/>
			<xsl:text>,&#160;</xsl:text>
			<xsl:apply-templates select="j:PersonGivenName" mode="TitleCase"/>
			<xsl:if test="j:PersonMiddleName or j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
			</xsl:if>
			<xsl:apply-templates select="j:PersonMiddleName" mode="TitleCase"/>		
			<xsl:if test="j:PersonSuffixName">
				<xsl:text>&#160;</xsl:text>
				<xsl:apply-templates select="j:PersonSuffixName" mode="TitleCase"/>
			</xsl:if>
		</span>
	</xsl:template>
	
	<xsl:template name="fraudulentNames">
		<table>
			<xsl:for-each select="j:PersonName[position() mod 2 != 0]">
                <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                <xsl:variable name="startposition" select="((number(position())-1)*2)+1"/>
                    <tr>
                        <xsl:apply-templates select="../j:PersonName" mode="aliasNames">
                             <xsl:sort select="j:PersonSurName" data-type="text" order="ascending"/>
                             <xsl:sort select="j:PersonGivenName" data-type="text" order="ascending"/>
                             <xsl:with-param name="startposition" select="$startposition"/>
                        </xsl:apply-templates>
                    </tr>
            </xsl:for-each>
          </table>
	</xsl:template>
	
	<!-- ################ -->
	<!-- Fraudulent Data  -->
	<!-- ################ -->
	<xsl:template match="cib-ext:PersonStolenFraudulent">
		<br/>
		<xsl:if test="not(../j:PersonAlias)">
			<xsl:call-template name="aliasHeader"/>
			<a name="alias{$responseId}"/>
		</xsl:if>
		<table>
			<tr>
				<td class="detailsublabel width25percent"><xsl:text>Stolen/Fraudulent:</xsl:text></td>
				<td class="detailvalue width75percent">
					<!--  Fradulent Names -->
					<xsl:call-template name="fraudulentNames"/>
					<!--  Social Security # -->
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<!-- Birth dates -->
				   	<xsl:for-each select="cib-ext:PersonBirthDateText">
						<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:apply-templates select="."/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
				  	</xsl:for-each>
				  	<!-- Miscellaenous # -->
					<xsl:for-each select="j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="."/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<!-- Drivers License -->
					<xsl:for-each select="j:DriverLicense/j:DriverAuthorizationID.Detailed">
						<xsl:if test="position() = 1">
							<br/>
						</xsl:if>
						<xsl:value-of select="j:ID"/>
						<xsl:text>,&#160;</xsl:text>
						<xsl:value-of select="j:IDIssuingAuthorityText"/>
						<xsl:if test="j:IDIssuingAuthorityText">
							<xsl:text>,&#160;</xsl:text>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="cib-ext:IDExpirationYear='UNKN'">
							    <xsl:text>Unknown Expiration Year</xsl:text> 
							</xsl:when>
							<xsl:otherwise>
							    <xsl:value-of select="cib-ext:IDExpirationYear"/>
							</xsl:otherwise>
						</xsl:choose>						
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:PersonFirearmProhibitedText | cib-ext:ProtectionOrderConditionText">
		<span class="caveat"><xsl:value-of select="."/></span>
		<br/> 
	</xsl:template>
	
	<!-- Detainer Templates -->
	<xsl:template match="cib-ext:DetainerDetails">
		<xsl:apply-templates select="j:CaveatText" mode="DetainerCaveats"/>
		<div class="caveat">
			<xsl:text>DATE OF DETAINER/</xsl:text>
			<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:text>INCARCERATING AGENCY/ </xsl:text>
			<xsl:value-of select="j:SupervisionFacility/j:OrganizationName"/>
			<xsl:text>&#160;ORI/</xsl:text>
			<xsl:value-of select="j:SupervisionFacility/j:OrganizationORIID"/>
			<br/>
			<xsl:text>DATE INCARCERATION STARTS/ </xsl:text>
			<xsl:apply-templates select="cib-ext:SupervisionStartDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:text>DATE SENTENCE ENDS/</xsl:text>
			<xsl:apply-templates select="cib-ext:SupervisionEndDate" mode="FormatFullDateAsMMDDYYYY"/>
			<br/>
			<xsl:for-each select="cib-ext:MiscellaneousText">
				<xsl:if test="position()=1">
					<xsl:text>REMARKS/</xsl:text>
				</xsl:if>
				<xsl:value-of select="."/>
			</xsl:for-each>
		</div>
	</xsl:template>
	
	<xsl:template match="cib-ext:WarrantGeographicRestrictionText | j:WarrantExtraditionLimitationText">
		<div class="extradition">
			<xsl:text>**&#160;</xsl:text>
				<xsl:apply-templates select="." mode="TitleCase"/>
			<xsl:text>&#160;**</xsl:text>
		</div>
	</xsl:template>
	
</xsl:transform>