<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - STOLEN BOAT RECORD --> 
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Stolen Boat</xsl:text>
	</xsl:template>
	
	<!-- ################# --> 
	<!-- doj:InquiryResult --> 
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:BoatIncident"/> 
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="." mode="record_details"/>	 
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'	
					or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/stolenBoat.gif</xsl:text>
		<xsl:text>-</xsl:text>
		<xsl:text>Stolen Boat</xsl:text>
	</xsl:template>

	<!-- Details about a stolen gun	-->
	<xsl:template match="cib-ext:BoatIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:Boat"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen boat -->
	<xsl:template match="cib-ext:Boat">
		<span class="propertyinfo">
			<!--  boat year -->
			<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyYearDate"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="cib-ext:BoatMakeText"/>
			<xsl:if test="cib-ext:BoatMakeCommentsText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="cib-ext:BoatMakeCommentsText"/>
			</xsl:if>
			<!--  model name -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyModelName">
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyModelName"/>
			</xsl:if>
			<!--  boat length -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyLengthMeasure">
				<br/>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyLengthMeasure"/>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyLengthMeasure/@j:lengthUnitCode"/>
				<xsl:text>;&#160;</xsl:text>
			</xsl:if>
			<!-- boat color -->
			<xsl:if test="cib-ext:BoatColor">
				<xsl:for-each select="cib-ext:BoatColor">
					<xsl:value-of select="cib-ext:BoatColorText"/>
					<xsl:if test="position() != last()">
						<xsl:text>/</xsl:text> 
					</xsl:if>
				</xsl:for-each>
			</xsl:if>
			<!--  boat name -->
			<xsl:if test="cib-ext:BoatName">
				<xsl:text>;&#160;</xsl:text>
				<xsl:value-of select="cib-ext:BoatName"/>
			</xsl:if>
			<!--  IDs section -->
			<xsl:if test="j:BoatHullID/j:ID or j:PropertyOwnerAppliedID/j:ID or j:BoatRegistrationID/j:ID">
				<xsl:if test="j:BoatHullID">
					<br />
					<xsl:text>Hull&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:BoatHullID/j:ID"/>
				</xsl:if>
				<xsl:if test="j:PropertyOwnerAppliedID">
					<br/> 
					<xsl:text>OAN&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:PropertyOwnerAppliedID/j:ID"/>
				</xsl:if>
				<xsl:if test="j:BoatRegistrationID">
					<br/>
					<xsl:text>Coast Guard&#160;#&#160;</xsl:text>
					<xsl:value-of select="j:BoatRegistrationID/j:ID"/>
				</xsl:if>
			</xsl:if>
			<!--  boat license -->
			<xsl:apply-templates select="cib-ext:BoatRegistration"/>
		</span>
	</xsl:template>
	
	<xsl:template match="cib-ext:BoatRegistration">
		<br/>
		<xsl:if test="j:PropertyVisibleID/j:ID">
			<xsl:value-of select="j:PropertyVisibleID/j:ID"/>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
		<xsl:value-of select="j:RegistrationJurisdictionName"/>
		<xsl:apply-templates select="cib-ext:RegistrationExpirationYear" mode="FormatYYYYorNX"/>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Hull Type and Propulsion -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Hull Type:'"/>
				<xsl:with-param name="value1" select="cib-ext:BoatIncident/cib-ext:Boat/j:BoatHullMaterialText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Propulsion:'"/>
				<xsl:with-param name="value2" select="cib-ext:BoatIncident/cib-ext:Boat/j:BoatPropulsionText"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Boat Type and Hull Shape -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Boat Type:'"/>
				<xsl:with-param name="value1" select="cib-ext:BoatIncident/cib-ext:Boat/cib-ext:BoatTypeText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Hull Shape:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:BoatIncident/cib-ext:Boat/j:BoatHullShapeText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Home Port -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Home Port:'"/>
				<xsl:with-param name="value1" select="cib-ext:BoatIncident/cib-ext:Boat/cib-ext:BoatHomePortName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:transform>