<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - STOLEN GUN RECORD -->
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Stolen Gun</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:FirearmIncident"/> 
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'	
					or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LostIndicator = 'true'">   
				<xsl:text>../../images/lostGun.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Lost Gun</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:StolenIndicator = 'true'">  
				<xsl:text>../../images/stolenGun.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Stolen Gun</xsl:text>
			</xsl:when>	
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:RecoveredIndicator = 'true'">   
				<xsl:text>../../images/recoveredGun.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Recovered Gun</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:FelonyIndicator = 'true'">   
				<xsl:text>../../images/felonyGun.gif</xsl:text> 
				<xsl:text>-</xsl:text>
				<xsl:text>Felony Gun</xsl:text>
			</xsl:when>									
		</xsl:choose>
	</xsl:template>

	<!-- Details about a stolen gun	-->
	<xsl:template match="cib-ext:FirearmIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:Firearm"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen gun	-->
	<xsl:template match="cib-ext:Firearm"> 
		<span class="propertyinfo">
			<!-- MAKE --> 
			<xsl:value-of select="cib-ext:FirearmMakeText"/>
			<xsl:if test="cib-ext:FirearmMakeCommentsText">
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="cib-ext:FirearmMakeCommentsText"/>
			</xsl:if>
			<!-- MODEL -->
			<xsl:if test="j:PropertyPhysicalDetails/j:PropertyModelName">
				<xsl:text>&#32;</xsl:text>
				<xsl:value-of select="j:PropertyPhysicalDetails/j:PropertyModelName"/>
			</xsl:if>
			<!-- TYPE  -->
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="cib-ext:FirearmTypeText"/>
			<xsl:text>&#32;</xsl:text>
			<!-- DESCRIPTION -->
			<xsl:value-of select="j:FirearmTypeDescriptionText"/>
			<xsl:text>&#160;</xsl:text>
			<!-- CALIBER -->
			<xsl:text>&#32;Caliber&#160;</xsl:text>
			<xsl:value-of select="cib-ext:FirearmCaliberCode"/>
			<br/>
			<!-- SERIAL #-->
			<xsl:text>SERIAL&#160;</xsl:text>
			<xsl:value-of select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID"/>
		</span>
	</xsl:template>

</xsl:transform>