<?xml version="1.0"?>
<xsl:transform
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response"
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension"
	xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:include href="../../util.xsl"/>
	<xsl:include href="../cib_ncic_common.xsl"/>
	
	<xsl:template match="doj:Result">
		<xsl:param name="fileName" select="."/>
	    <xsl:choose>
	      <xsl:when test="$from='ebc'">
	        <xsl:call-template name="html_main">
				<xsl:with-param name="fileName" select="$fileName"/>
			</xsl:call-template>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:call-template name="html_head_extension" />
	        <!-- This prevents the solid black lines from displaying in online validations (FB 189) -->
	        <div id="container">
	        	<xsl:call-template name="html_body" />
	        </div>
	      </xsl:otherwise>
	    </xsl:choose>
	</xsl:template>
	
	<xsl:template name="html_body">
		<xsl:param name="fileName"/>
		<xsl:choose>
			<xsl:when test="doj:NCICLegacyText">
				<xsl:apply-templates select="doj:NCICLegacyText"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="FormattedResultText">
						<xsl:apply-templates select="FormattedResultText"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="doj:ResultText"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="child::node()/doj:InquiryResult"/>
	</xsl:template>
	
	<xsl:template name="ncicLogo">
		<table width="100%" >
			<tr>
				<td align="right">
					<xsl:element name="img">
						<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'FBI.gif')"/></xsl:attribute>
						<xsl:attribute name="alt">NCIC Logo</xsl:attribute>
						<xsl:attribute name="width">60</xsl:attribute>
						<xsl:attribute name="height">60</xsl:attribute>
					</xsl:element>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<!-- ##################################################### --> 
	<!-- #  REUSABLE MATCH TEMPLATES FOR ALL FILE TYPES      # -->
	<!-- ##################################################### -->
	<!-- Record Details section  --> 
	<xsl:template match="doj:InquiryResult" mode="record_details_all">
		<br/>
		<xsl:choose>
			<xsl:when test="contains(cib-ext:RecordTypeText,'WANTED')">
				<a name="warrantdetails{$responseId}">
					<span class="detaillabel uppercase">Warrant Details:</span>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a name="recorddetails{$responseId}">
					<span class="detaillabel uppercase">Record Details:</span>
				</a>
			</xsl:otherwise>
		</xsl:choose>
		<table>
			<!-- Agency Case # and NCIC #: -->  
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Agency Case #:'"/> 
				<xsl:with-param name="value1">
					<xsl:apply-templates select="." mode="agency_case_number"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'NCIC #:'"/>
				<xsl:with-param name="value2" select="cib-ext:EnteringAgencyDetails/j:DocumentFileControlID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!--  Date of Entry -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Entry Date:'"/>   
				<xsl:with-param name="value1">
					<xsl:apply-templates  
							select="cib-ext:EnteringAgencyDetails/j:DocumentFiledDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="cib-ext:EnteringAgencyDetails/j:DocumentFiledTime"/>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentFiledTimeZoneCode"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Updated Date: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Update Date:'"/>   
				<xsl:with-param name="value1">
					<xsl:apply-templates  
							select="cib-ext:EnteringAgencyDetails/j:DocumentLastModifiedDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
					<xsl:if test="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTime">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTime"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTimeZoneCode"/>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Protective Interest only -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Threat:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Validator and Date: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Validator:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/cib-ext:ValidationPersonText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Validated Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="cib-ext:EnteringAgencyDetails/cib-ext:ValidationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Linking ORI and Linking Case: -->
			<xsl:call-template name="ConditionalRow"> 
				<xsl:with-param name="label1" select="'Linking ORI:'"/>
				<xsl:with-param name="value1" select="cib-ext:LinkageAgency/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>	
				<xsl:with-param name="label2" select="'Linking Case #:'"/>
				<xsl:with-param name="value2" select="cib-ext:LinkageAgency/j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Public Dissemination and Date -->
			<xsl:if test="../../doj:VehicleResponse|../../doj:ArticleResponse" >
			       <xsl:call-template name="ConditionalRow">
				       <xsl:with-param name="label1" select="'Public Disseminations:'"/>
				       <xsl:with-param name="value1" select="cib-ext:PublicDisseminationStatus/cib-ext:PublicDisseminationStatusText"/>
				       <xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				       <xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				       <xsl:with-param name="label2" select="'Date:'"/>
				       <xsl:with-param name="value2">  
 				       		<xsl:apply-templates select="cib-ext:PublicDisseminationStatus/cib-ext:PublicDisseminationStatusDate" mode="FormatFullDateAsMMDDYYYY"/>
 				       </xsl:with-param>
  				       <xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				       <xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/> 
			       </xsl:call-template>
			</xsl:if>			
			<!-- Date of Purge : -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Purge Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates 
						select="cib-ext:PurgeDateText"
						mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>  
	
	<xsl:template match="doj:InquiryResult" mode="agency_case_number">
		<!-- identity theft  -->
		<!-- violent gang	 -->
		<!-- possible terrorist	 -->
		<!-- identity theft  -->
		<!-- sex offender -->
		<!-- foreign fugitive -->
		<!-- immigration violator -->		
		<!-- supervised release --> 
		<!-- wanted person -->	
		<!-- protection order -->
		<!-- missing person --> 
		<!-- protective interest -->
		<!-- stolen/felony vehicle -->
		<!-- stolen parts -->
		<!-- stolen license plates -->
		<!-- group articles -->
		<!-- single article -->
		<!-- group securities -->
		<!-- single security -->  
		<xsl:if test="child::node()/j:ActivityCrimeCase/j:CaseDocketID">	
			<xsl:value-of select="child::node()/j:ActivityCrimeCase/j:CaseDocketID/j:ID"/>
		</xsl:if>
		<!-- violent gang -->
		<xsl:if test="j:CaseDocketID">	
			<xsl:value-of select="j:CaseDocketID/j:ID"/>
		</xsl:if>
	</xsl:template>

	<!-- File Type Header -->
	<xsl:template name="file_type_header_all">
		<xsl:param name="fileLogoPic" />
		<xsl:param name="flagPic1" />
		<xsl:param name="flagPic2" />
		<xsl:param name="flagPic3" />
		<xsl:param name="flagPic4" />
		<!-- Data Service Logo -->	
		<xsl:call-template name="ncicLogo"/>
		<!-- File Type Header Section -->
		<table>
			<tr>
				<td class="width10percent">
					<!-- Display File Type Logo -->	
					<img src="{substring-before($fileLogoPic,'-')}" alt="{substring-after($fileLogoPic,'-')}"/>
				</td>
				<td class="width90percent">
					<table>
						<tr><td>
							<!-- File Description --> 	
							<span class="filetype">
								<xsl:apply-templates select="cib-ext:RecordTypeText" mode="TitleCase"/>			
							</span>
							<!-- File Flags Images -->
							<xsl:text>&#160;</xsl:text>
							<xsl:if test="$flagPic1 != '' ">
								<img src="{substring-before($flagPic1,'-')}" alt="{substring-after($flagPic1,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
							<xsl:if test="$flagPic2 != '' ">
								<img src="{substring-before($flagPic2,'-')}" alt="{substring-after($flagPic2,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
							<xsl:if test="$flagPic3 != '' ">
								<img src="{substring-before($flagPic3,'-')}" alt="{substring-after($flagPic3,'-')}"/>
								<xsl:text>&#160;</xsl:text>
							</xsl:if>
						</td></tr>
						<tr><td>	
							<!-- Caution Text -->
							<xsl:choose>
								<xsl:when test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator='true' or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator='true'">
									<!--  do not display caution text -->
								</xsl:when>
								<xsl:otherwise>
									<xsl:apply-templates select="cib-ext:FileTypeDetails/cib-ext:CautionIndicator"/>
								</xsl:otherwise>
							</xsl:choose>
							 
							<!-- Caveat Text -->
							<xsl:apply-templates select="j:CaveatText" mode="TopCaveats"/>
							
							<!-- Protection Order only -->	
							<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject/cib-ext:PersonFirearmProhibitedText"/>
							<xsl:apply-templates select="j:ProtectionOrder/cib-ext:ProtectionOrderConditionText"/>
							
							<!-- Missing Person specifics -->	
							<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonCircumstanceText"/>
							<xsl:if test="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeCode='AA' or
							    cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeCode='CA'">
								<xsl:apply-templates select="cib-ext:MissingPersonIncident/j:MissingPerson/j:MissingPersonDisappearanceTypeText"/>
							</xsl:if>
							
							<!-- Caveat Text Common for all Property Files -->
							<div class="caveat">
								<xsl:if test="cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
									**&#160;USE CAUTION - HOLD FOR LATENT FINGERPRINTS&#160;**<br/>
								</xsl:if>
								<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'">
									**&#160;USE CAUTION - ARMED AND DANGEROUS&#160;**<br/>
								</xsl:if>
							</div>
							
							<xsl:if test="(cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true' or
									cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true') and 
									cib-ext:MiscellaneousText">
								<a href="#remarks{$responseId}" class="remarks">See Remarks</a>
							</xsl:if>
							
							<!-- Notify Agency ORI -->
							<xsl:apply-templates select="cib-ext:NotifyOriginatingAgencyIndicator"/>
							
							<!-- All files -->
							<xsl:apply-templates select="j:CaveatText" mode="BottomCaveats"/>
							
							<!-- Wanted Person only -->
							<xsl:apply-templates select="cib-ext:DetainerDetails"/>
						</td></tr>
					</table>
				</td>
			</tr>
		</table>
		<!-- Horizontal Line -->
		<hr/>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="property_details"> 
		<table>
			<!-- Date of Offense, Date of Theft, Date of Lost or Date of Recovery: -->
			<xsl:call-template name="ConditionalRow"> 
				<xsl:with-param name="label1">
					<xsl:choose>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:StolenIndicator = 'true'">
							<xsl:text>Date of Theft:</xsl:text>
						</xsl:when>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LostIndicator = 'true'">
							<xsl:text>Date of Lost:</xsl:text>
						</xsl:when>
						<xsl:when test="cib-ext:FileTypeDetails/cib-ext:RecoveredIndicator = 'true'">
							<xsl:text>Date of Recovery:</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>Date of Offense:</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="child::node()/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width75percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>	
	
	<xsl:template match="doj:InquiryResult" mode="property_details_all">
		<table>
			<tr>
				<td width="90%">
					<xsl:apply-templates select="." mode="property_details"/>
				</td>
				<td class="width10percent" valign="left">
          <xsl:apply-templates select="." mode="cibExtImage"/>
				</td>
			</tr>
		</table>
	</xsl:template>	
		
	<xsl:template name="DateOfOffense">
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Date&#160;of&#160;Offense:'"/>
			<xsl:with-param name="value1">
				<xsl:apply-templates select="child::node()/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width25percent'"/>
			<xsl:with-param name="value_class_name1" select="'basicvalue width75percent'"/>
		</xsl:call-template>
	</xsl:template>		
		
	<xsl:template name="EnteringAgency">  
		<xsl:call-template name="ConditionalRow">
			<xsl:with-param name="label1" select="'Entering Agency:'"/>
			<xsl:with-param name="value1">
				<xsl:value-of select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Organization/j:OrganizationORIID/j:ID"/>
				<xsl:text>&#160;-&#160;</xsl:text>
				<xsl:value-of select="cib-ext:EnteringAgencyDetails/j:DocumentSubmitter.Organization/j:OrganizationName" />
			</xsl:with-param>
			<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
			<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
		</xsl:call-template>		
	</xsl:template>	
	
	<xsl:template match="cib-ext:RecoveryDetails" mode="recovery_all"> 
		<xsl:variable name="miscText">
			<xsl:call-template name="MiscText"/>
		</xsl:variable>
		<table>
			<!-- Date of Recovery: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Recovery:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Recovering Agency ORI: --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Recovering Agency ORI:'"/>
				<xsl:with-param name="value1" select="j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Recovering Agency Case: --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Recovering Agency Case:'"/>
				<xsl:with-param name="value1" select="j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Recovering Remarks: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Recovering Remarks:'"/>
				<xsl:with-param name="value1" select="$miscText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<!-- Serial # : -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Serial #:'"/>
				<xsl:with-param name="value1"> 
					<xsl:apply-templates select="cib-ext:PropertyBeginingSerialID"/>
					<xsl:apply-templates select="cib-ext:PropertyEndingSerialID"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>	
		
	<xsl:template match="cib-ext:PropertyBeginingSerialID">
		<xsl:value-of select="j:ID"/>
	</xsl:template>
	
	<xsl:template match="cib-ext:PropertyEndingSerialID">
		<xsl:text>&#160;-&#160;</xsl:text>
		<xsl:value-of select="j:ID"/>
	</xsl:template>
	
	<xsl:template match="j:CaveatText" mode="TopCaveats">
		<!-- Displays caveats which belong on the top of a response -->
        <xsl:if test="not(starts-with(.,'VERIFY') and contains(.,'IMMEDIATELY WITH ORI'))">
        	<div class="caveat">
			   <xsl:value-of select="."/> 
			</div>
        </xsl:if>
      </xsl:template>
      
	 <xsl:template match="j:CaveatText" mode="BottomCaveats">
     	<!-- Displays caveats which belong on the bottom of a response -->
        <xsl:if test="starts-with(.,'VERIFY') and contains(.,'IMMEDIATELY WITH ORI')">
            <div class="verify">
				<xsl:value-of select="."/>
			</div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="*" mode="cibExtImage">
      <xsl:choose>
        <xsl:when test="//cib-ext:Image/j:BinaryObject.Base64">
          <xsl:variable name="responseID" select="/doj:NCICResponseDocument/@doj-ext:responseID"/>
          <img ignoreNightMode="true" src="image?ETIMEResponseId={$responseID}&amp;ImageIndex=0&amp;Resize=true"/>
          <br/>
          <a href="javascript: void(0)" onclick="window.open('imageDetail.jsp?ETIMEResponseId={$responseID}&amp;WhatToDo=showImages', '', 'directories=no, location=no, menubar=no, resizable=yes, toolbar=no, scrollbars=yes, status=no');return false;">
          	<xsl:element name="img">
          		<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'detail.jpg')"/></xsl:attribute>
          	</xsl:element>
          </a>
          <xsl:if test="count(//cib-ext:Image) > 1">
            <a href="javascript: void(0)" onclick="alert('Additional Images is not available at this time');return false;">
            	<xsl:element name="img">
            		<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'additionalimages.jpg')"/></xsl:attribute>
            	</xsl:element>
            </a>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:for-each select="//cib-ext:Image">
            <xsl:choose>
              <xsl:when test="position() = 1">
                <xsl:text>Image #&#160;</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>, </xsl:text>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="j:DocumentFileControlID/j:ID"/>
            <xsl:choose>
              <xsl:when test="cib-ext:ImageTypeText">
                <xsl:text> (</xsl:text>
                <xsl:value-of select="cib-ext:ImageTypeText"/>
                <xsl:text>)</xsl:text>
              </xsl:when>
              <xsl:when test="j:ImageTypeCode">
                <xsl:text> (</xsl:text>
                <xsl:value-of select="j:ImageTypeCode"/>
                <xsl:text>)</xsl:text>
              </xsl:when>
            </xsl:choose>
          </xsl:for-each>
        </xsl:otherwise> 
      </xsl:choose> 
    </xsl:template>
    
	<xsl:template name="MiscText">
		<xsl:for-each select="cib-ext:MiscellaneousText">
			<xsl:value-of select="."/>
			<xsl:if test="position() != last()">
				<xsl:text>;&#160;</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
    
</xsl:transform>
