<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <xsl:import href="person_common.xsl"/> 
	<xsl:param name="from"></xsl:param>

	<!-- NICS - Denied Person Record -->
	<!-- ############### -->
	<!-- main template   -->
	<!-- ############### -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NICS Denied Person</xsl:text>
	</xsl:template>
	
   	<!-- ################### -->
	<!-- doj:InquiryResult   -->
	<!-- ################### -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:NICSDeniedIncident"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:NICSDeniedIncident/cib-ext:NICSDeniedPerson" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:NICSDeniedIncident" mode="denied_details"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		
		<xsl:apply-templates select="." mode="denied_record_details_all"/>	
		
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file > -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase,'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:value-of select="concat($imageBase,'no_gun.gif')"/>
		<xsl:text>-</xsl:text>
		<xsl:text>Denied Person</xsl:text>
	</xsl:template>
	<xsl:template match="cib-ext:NICSDeniedIncident">
		<table>
			<tr>
				<td class="width10percent"> 
					<xsl:element name="a">
						<xsl:attribute name="href">#recorddetails<xsl:value-of select="$responseId"/></xsl:attribute>
						<xsl:element name="img">
							<xsl:attribute name="src"><xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/></xsl:attribute>
							<xsl:attribute name="border"><xsl:value-of select="0"/></xsl:attribute>
						</xsl:element>
					</xsl:element>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Record Details-->	
		<br/>
		<table>
			<!-- Entering Agency: -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="denied_record_details_all">
		<br/>
			<a name="recorddetails{$responseId}">
				<span class="detaillabel uppercase">Record Details:</span>
			</a>
		<table>
			<!-- NIC #: -->  
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'NIC #:'"/>
				<xsl:with-param name="value1" select="cib-ext:EnteringAgencyDetails/j:DocumentFileControlID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			
			<!--  State Transaction -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'State Transaction #:'"/>
				<xsl:with-param name="value1" select="cib-ext:NICSDeniedIncident/cib-ext:NICSDeniedActivity/j:StateTransactionID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			
			<!--  NICS Transaction -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'NICS Transaction #:'"/>
				<xsl:with-param name="value1" select="cib-ext:NICSDeniedIncident/cib-ext:NICSDeniedActivity/j:NICSTransactionID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			
			<!--  Entry Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Entry Date:'"/>   
				<xsl:with-param name="value1">
					<xsl:apply-templates  
							select="cib-ext:EnteringAgencyDetails/j:DocumentFiledDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="cib-ext:EnteringAgencyDetails/j:DocumentFiledTime"/>
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentFiledTimeZoneCode"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			
			<!-- Updated Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Update Date:'"/>   
				<xsl:with-param name="value1">
					<xsl:apply-templates  
							select="cib-ext:EnteringAgencyDetails/j:DocumentLastModifiedDate" 
							mode="FormatFullDateAsMMDDYYYY">
					</xsl:apply-templates>
					<xsl:if test="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTime">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTime"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="cib-ext:EnteringAgencyDetails/cib-ext:DocumentLastModifiedTimeZoneCode"/>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:NICSDeniedIncident" mode="denied_details">
		<table>
		<br/>
		<!-- Social Security #: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Social Security #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="cib-ext:NICSDeniedPerson/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:apply-templates select="." mode="FormatSSN"/>
						<xsl:if test="position() != last()">
							<xsl:text>;&#160;</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="cib-ext:NICSDeniedPerson/j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
						<xsl:text>; </xsl:text>
						<xsl:for-each select="cib-ext:NICSDeniedPerson/j:PersonAlias/j:PersonAssignedIDDetails/j:PersonSSNID/j:ID">
							<xsl:apply-templates select="." mode="FormatSSN"/>
							<xsl:if test="position() != last()">
								<xsl:text>;&#160;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>			
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>
			</xsl:call-template>
			<tr/>
			<!-- Miscellaneous -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Miscellaneous #:'"/>
				<xsl:with-param name="value1">
					<xsl:for-each select="cib-ext:NICSDeniedPerson/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
						<xsl:text>-</xsl:text>
						<xsl:value-of select="."/>
					</xsl:for-each>
					<xsl:if test="cib-ext:NICSDeniedPerson/j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
						<xsl:for-each select="cib-ext:NICSDeniedPerson/j:PersonAlias/j:PersonAssignedIDDetails/j:PersonOtherID/j:ID">
							<xsl:text>;&#10;</xsl:text>
							<xsl:value-of select="../cib-ext:PersonIDTypeText"/>
							<xsl:text>-</xsl:text>
							<xsl:value-of select="."/>
						</xsl:for-each>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>			
			</xsl:call-template>
			<tr/>
			<!-- state of purchase -->
			<xsl:call-template name="ConditionalRow">
				
				<xsl:with-param name="label1" select="'State of Purchase:'"/>
				<xsl:with-param name="value1">
						<xsl:value-of select="cib-ext:NICSDeniedActivity/j:PurchaseLocation/j:LocationStateName"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>			
			</xsl:call-template>
			<tr/>
			<!-- state of Residence -->
			<xsl:call-template name="ConditionalRow">
				
				<xsl:with-param name="label1" select="'State of Residence:'"/>
				<xsl:with-param name="value1">
					<xsl:value-of select="cib-ext:NICSDeniedPerson/j:Residence/j:LocationStateName"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>			
			</xsl:call-template>
			<tr/>
			<!-- Date of Denial -->
			<xsl:call-template name="ConditionalRow">
				
				<xsl:with-param name="label1" select="'Date of Denial:'"/>
				<xsl:with-param name="value1">
						<xsl:apply-templates select="cib-ext:NICSDeniedActivity/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detaillabel uppercase width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width75percent'"/>			
			</xsl:call-template>
		<tr/>
		</table>
	</xsl:template>
		
</xsl:transform>
