<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <!--  NCIC - STOLEN PART RECORD -->
	<xsl:import href="ncic_common.xsl"/>
	
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title"> 
		<xsl:text>TIME - NCIC Stolen Parts</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="cib-ext:PartIncident"/> 
		<xsl:apply-templates select="." mode="property_details_all"/>
		<xsl:apply-templates select="cib-ext:MiscellaneousText"  mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.-->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:OccupantsArmedIndicator = 'true'	
					or cib-ext:FileTypeDetails/cib-ext:LatentFingerprintHoldIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:StolenIndicator = 'true' ">
				<xsl:text>../../images/stolenPart.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Stolen Part</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:LocatedIndicator = 'true'">
				<xsl:text>../../images/locatedPart.gif</xsl:text>
				<xsl:text>-</xsl:text>
				<xsl:text>Located Part</xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- Details about a stolen plate ...	-->
	<xsl:template match="cib-ext:PartIncident">
		<table>
			<tr>
				<td class="width10percent">
					<a href="#recorddetails{$responseId}"><img src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width90percent">
					<xsl:apply-templates select="cib-ext:PartDetails"/>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
	
	<!-- Details about a stolen part ..	-->
	<xsl:template match="cib-ext:PartDetails">
		<span class="propertyinfo">
			<!-- PART YEAR -->
			<xsl:value-of select="cib-ext:PartYear"/>
			<xsl:text>&#160;</xsl:text>
			<!-- PART BRAND -->
			<xsl:value-of select="j:VehiclePartBrandName"/>
			<xsl:text>&#160;</xsl:text>
			<!--  PART TYPE  -->
			<xsl:value-of select="j:VehiclePartCategoryText"/>
			<xsl:text>&#160;</xsl:text>
			<!-- DISPLACEMENT -->
			<xsl:value-of select="j:EnginePowerDisplacement"/>
			<xsl:value-of select="j:EnginePowerDisplacement/@j:enginePowerDisplacementUnitCode"/>
			<br/>
			<!-- PART SERIAL -->
			<xsl:if test="j:PropertyAssignedIDDetails/j:PropertySerialID">
				<xsl:text>SERIAL&#160;</xsl:text>
				<xsl:value-of select="j:PropertyAssignedIDDetails/j:PropertySerialID/j:ID"/>
				<br/>
			</xsl:if>
			<!-- OAN -->
			<xsl:if test="j:PropertyAssignedIDDetails/j:PropertyOwnerAppliedID">
				<xsl:text>OAN&#160;</xsl:text>
				<xsl:value-of select="j:PropertyAssignedIDDetails/j:PropertyOwnerAppliedID/j:ID"/>
			</xsl:if>
		</span>
	</xsl:template>

</xsl:transform>