<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>

	<!-- NCIC - PROTECTION ORDER -->
	<!-- ############### -->
	<!-- main template   -->
	<!-- ############### -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Protection Order</xsl:text>
	</xsl:template>
	
	<!-- ################## -->
	<!-- doj:InquiryResult  -->
	<!-- ################## -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject" mode="subject_details_all"/>
		<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject" mode="FBItoSMT"/>
		<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="j:ProtectionOrder/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="j:ProtectionOrder/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="j:ProtectionOrder/j:ProtectionOrderRestrictedPerson"/>
		<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject" mode="alias"/>
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>
	</xsl:template>

	<!-- ###################### -->
	<!-- The File Type Header   -->
	<!-- ###################### -->
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogo"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogo">
		<xsl:choose>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TemporaryIndicator='true' 
				and cib-ext:FileTypeDetails/cib-ext:ClearedIndicator='true'">
				<xsl:value-of select="concat($imageBase, 'cancelledTemporaryProtectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Cancelled Temporary Protection Order</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TemporaryIndicator='true' 
				and cib-ext:FileTypeDetails/cib-ext:ExpiredIndicator='true'">
				<xsl:value-of select="concat($imageBase, 'expiredTemporaryProtectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Expired Temporary Protection Order</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:ClearedIndicator='true'">
				<xsl:value-of select="concat($imageBase, 'cancelledProtectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Cancelled Protection Order</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:ExpiredIndicator='true'">
				<xsl:value-of select="concat($imageBase, 'expiredProtectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Expired Protection Order</xsl:text>
			</xsl:when>
			<xsl:when test="cib-ext:FileTypeDetails/cib-ext:TemporaryIndicator='true'">
				<xsl:value-of select="concat($imageBase, 'temporaryProtectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Temporary Protection Order</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat($imageBase, 'protectionOrder.gif')"/>
				<xsl:text>-</xsl:text>
				<xsl:text>Protection Order</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderDesignatedSubject" mode="subject_caution_all"/>
		<!-- Protection Order Details-->
		<br/>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Beginning Date:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:ProtectionOrder/j:CourtOrderIssuingDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Ending Date:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="j:ProtectionOrder/cib-ext:CourtOrderExpirationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Service:'"/>
				<xsl:with-param name="value1" select="j:ProtectionOrder/cib-ext:ProtectionOrderServedText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Service Date:'"/>
					<xsl:with-param name="value1">
						<xsl:apply-templates select="j:ProtectionOrder/cib-ext:ProtectionOrderServedDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Court Case #:'"/>
				<xsl:with-param name="value1" select="j:ProtectionOrder/j:CaseDocketID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Court ORI #:'"/>
				<xsl:with-param name="value1" select="j:ProtectionOrder/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Order or Injuction #:'"/>
				<xsl:with-param name="value1" select="j:ProtectionOrder/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>

	<xsl:template match="j:ProtectionOrderRestrictedPerson">
		<br/>
		<a name="petitioner{$responseId}"/>
		<span class="detaillabel uppercase">Petitioner:</span>
		<table>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Name:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:PersonName" mode="alias"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Social Security #:'"/>
				<xsl:with-param name="value2" select="j:PersonAssignedIDDetails/j:PersonSSNID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Sex:'"/>
				<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonSexText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Address:'"/>
				<xsl:with-param name="value2" select="j:Residence/j:LocationAddress/j:LocationStreet/j:StreetFullText"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Race:'"/>
				<xsl:with-param name="value1" select="j:PersonPhysicalDetails/j:PersonRaceText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'City:'"/>
				<xsl:with-param name="value2" select="j:Residence/j:LocationAddress/j:LocationCityName"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Birth:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:PersonBirthDate" mode="FormatFullDateAsMMDDYYYY"/>			
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'State:'"/>
				<xsl:with-param name="value2" select="j:Residence/j:LocationAddress/j:LocationStateName"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:stylesheet>