<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>

	<!--  NCIC - PROTECTIVE INTEREST RECORD -->
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Protective Interest</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all">
			<xsl:with-param name="parent" select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson" mode="alias"/>
		<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson/cib-ext:PersonStolenFraudulent" />
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />	
		<xsl:apply-templates select="." mode="record_details_all"/>
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->  
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase,'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>		
	</xsl:template>				

	<xsl:template name="fileLogoPicture">
		<xsl:value-of select="concat($imageBase,'secretServiceProtective.gif')"/>
		<xsl:text>-</xsl:text>
		<xsl:text>Protective Interest</xsl:text> 
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<table>
			<tr>
				<td class="width10percent"> 
					<a href="#recorddetails{$responseId}">
						<xsl:element name="img">
							<xsl:attribute name="src">
								<xsl:value-of select="concat($imageBase,'RecordDetails.jpg')"/>
							</xsl:attribute>
							<xsl:attribute name="alt">Record Details</xsl:attribute>
							<xsl:attribute name="border">0</xsl:attribute>
						</xsl:element>
					</a>
				</td>
				<td class="width80percent" align="center">
					<xsl:apply-templates select="cib-ext:ProtectiveInterestIncident/cib-ext:ProtectiveInterestPerson/cib-ext:SubjectCautionInformationText"/>
				</td>
				<td class="width10percent"></td> <!-- on purpose left empty -->
			</tr>
		</table>
		<br/>
		<!-- Entering Agency -->
		<table>
			<xsl:call-template name="EnteringAgency"/>
		</table>
		
	</xsl:template>
	
</xsl:stylesheet>