<?xml version="1.0"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
	<xsl:import href="person_common.xsl"/>

	<!--  NCIC - US SECRET SERVICE PROTECTIVE RECORD -->
	<!-- ############# -->
	<!-- main template -->
	<!-- ############# -->
	<xsl:template match="/doj:NCICResponseDocument"> 
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC US Secret Service Protective</xsl:text>
	</xsl:template>
	
	<!-- ################# -->
	<!-- doj:InquiryResult -->
	<!-- ################# -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject" mode="subject_details_all"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject" mode="FBItoSMT"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="j:CourtOrder/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="j:CourtOrder/j:CourtOrderDesignatedSubject"/>
		</xsl:call-template>
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject" mode="alias"/>
		<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject/cib-ext:PersonStolenFraudulent" />
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />	
		<xsl:apply-templates select="." mode="record_details_all"/>
		<xsl:apply-templates select="." mode="record_details"/>	 	
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file.  -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:text>../../images/flag.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2">
				<xsl:if test="cib-ext:DetainerDetails">
					<xsl:text>../../images/cuffs.gif</xsl:text>
					<xsl:text>-</xsl:text>
					<xsl:text>Detainer Info</xsl:text>
				</xsl:if>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="fileLogoPicture">
		<xsl:text>../../images/secretServiceProtective.gif</xsl:text>
		<xsl:text>-</xsl:text>
		<xsl:text>US Secret Service Protective</xsl:text> 
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<table>
			<tr>
				<td class="width10percent"> 
					<a href="#recorddetails{$responseId}"><img border="0" src="../../images/RecordDetails.jpg" alt="Record Details"/></a>
				</td>
				<td class="width80percent" align="center">
					<xsl:apply-templates select="j:CourtOrder/j:CourtOrderDesignatedSubject/cib-ext:SubjectCautionInformationText"/>
					<xsl:apply-templates select="j:CourtOrder/j:WarrantExtraditionLimitationText"/>
					<xsl:apply-templates select="j:CourtOrder/cib-ext:WarrantGeographicRestrictionText"/>
				</td>
				<td class="width10percent"></td> <!-- on purpose left empty -->
			</tr>
		</table>
		<br/>
		<!-- US Secret Service Details-->	
		<table>
			<!--  Warrant Type -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant&#160;Type:'"/>
				<xsl:with-param name="value1" select="j:CourtOrder/cib-ext:WarrantTypeText"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Offense Code -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Offense:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICText"/>
					<xsl:text>&#160;</xsl:text>
					<xsl:apply-templates select="j:CourtOrder/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICCodeCommentText"/>
				</xsl:with-param> 
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!--  Original Offense Code -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Original Offense:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityCrimeCase/j:CaseCharge/j:ChargeReporting/cib-ext:ChargeNCICOriginalText" mode="TitleCase"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Warrant Number and Warrant Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Number:'"/>
				<xsl:with-param name="value1" select="j:CourtOrder/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Warrant Date:'"/>
				<xsl:with-param name="value2">
					<xsl:apply-templates select="j:CourtOrder/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Court ORI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Court ORI:'"/>
				<xsl:with-param name="value1" select="j:CourtOrder/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
</xsl:stylesheet>