<?xml version="1.0"?>
<xsl:transform 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:cib-ext="http://www.doj.state.wi.us/dles/cib/cib/response/extension"
	xmlns:doj="http://www.doj.state.wi.us/dles/cib/ncic/response" 
	xmlns:doj-ext="http://www.doj.state.wi.us/dles/cib/extension" 
    xmlns:j="http://www.it.ojp.gov/jxdm/3.0.2">
    
    <xsl:import href="person_common.xsl"/>
	
	<!-- NCIC - SUPERVISED RELEASE RECORD -->
	<!-- ############### -->
	<!-- main template   -->
	<!-- ############### -->
	<xsl:template match="/doj:NCICResponseDocument">
		<xsl:apply-templates select="doj:Result">
			<xsl:with-param name="fileName">
				<xsl:call-template name="html_title"/>
			</xsl:with-param>
		</xsl:apply-templates>	
	</xsl:template>
	
	<xsl:template name="html_title">
		<xsl:text>TIME - NCIC Probation or Supervised Release</xsl:text>
	</xsl:template>
	
   	<!-- ################### -->
	<!-- doj:InquiryResult   -->
	<!-- ################### -->
	<xsl:template match="doj:InquiryResult">
		<xsl:apply-templates select="." mode="file_type_header"/>
		<xsl:apply-templates select="." mode="file_type_details"/>
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject" mode="subject_details_all"/>
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject" mode="FBItoSMT"/>
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject" mode="DLtoDNALoc"/>
		<xsl:call-template name="vehicle_all">
			<xsl:with-param name="parent" select="cib-ext:Supervision/cib-ext:SupervisionSubject"/>
		</xsl:call-template>
		<xsl:call-template name="licensePlate_all" >
			<xsl:with-param name="parent" select="cib-ext:Supervision/cib-ext:SupervisionSubject"/>
		</xsl:call-template> 
		<xsl:apply-templates select="cib-ext:MiscellaneousText" mode="remarks_all"/>
		<xsl:apply-templates select="cib-ext:AdditionalInformation"/>
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject" mode="alias"/>
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject/cib-ext:PersonStolenFraudulent" />
		<xsl:apply-templates select="cib-ext:InvestigativeInterestDetails" />
		<xsl:apply-templates select="." mode="record_details_all"/>	
		<xsl:apply-templates select="." mode="record_details"/>	  	
		<xsl:apply-templates select="cib-ext:RecoveryDetails" mode="recovery_all"/>	
	</xsl:template>
	
	<!-- ################# -->
	<!-- File Type Header  -->
	<!-- ################# -->	
	<xsl:template match="doj:InquiryResult" mode="file_type_header">
		<!-- Invoke the file type header template that builds the header of the file > -->
		<xsl:call-template name="file_type_header_all">
			<xsl:with-param name="fileLogoPic">
				<xsl:call-template name="fileLogoPicture"/>
			</xsl:with-param>
			<xsl:with-param name="flagPic1">
				<xsl:if test="cib-ext:FileTypeDetails/cib-ext:CautionIndicator = 'true'">
					<xsl:value-of select="concat($imageBase, 'flag.gif')"/>
					<xsl:text>-</xsl:text>
					<xsl:text>Caution</xsl:text>
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="flagPic2"/> <!-- N/A for this file type-->
			<xsl:with-param name="flagPic3"/> <!-- N/A for this file type-->
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="fileLogoPicture">
		<xsl:value-of select="concat($imageBase, 'supervisedReleaseNCIC.gif')"/>
		<xsl:text>-</xsl:text>
		<xsl:text>Supervised Release</xsl:text>
	</xsl:template>
	
	<xsl:template match="doj:InquiryResult" mode="file_type_details">
		<!-- Subject Caution Text -->
		<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionSubject" mode="subject_caution_all"/>
		<br/>
		<!-- Record Details-->	
		<table>
			<!-- Original Offense: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Original Offense:'"/>
				<xsl:with-param name="value1">
					<xsl:apply-templates select="j:Arrest/cib-ext:ChargeNCICOriginalCode"/>
					<xsl:apply-templates select="j:Arrest/cib-ext:ChargeNCICOriginalText"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Supervising Officer: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Officer Code:'"/>
				<xsl:with-param name="value1" 
					select="cib-ext:Supervision/j:SupervisionOfficial/j:PersonName/j:PersonFullName"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue width70percent'"/>
			</xsl:call-template>
			<!-- Supervising Officer Number: -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervising Officer Number:'"/>
				<xsl:with-param name="value1" 
					select="cib-ext:Supervision/j:SupervisionOfficial/j:PrimaryContactInformation/j:ContactTelephoneNumber/j:TelephoneNumberFullID"/>
				<xsl:with-param name="label_class_name1" select="'basiclabel uppercase width30percent'"/>
				<xsl:with-param name="value_class_name1" select="'basicvalue defaultcase width70percent'"/>
			</xsl:call-template>
			<!-- Entering Agency -->
			<xsl:call-template name="EnteringAgency"/>
		</table>
	</xsl:template>

	<xsl:template match="doj:InquiryResult" mode="record_details">
		<table>
			<!-- Date of Arrest and Arresting Agency ORI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Date of Arrest:'"/>
				<xsl:with-param name="value1" >
					<xsl:apply-templates select="j:Arrest/j:ActivityDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Arresting Agency ORI:'"/>
				<xsl:with-param name="value2"
					 select="j:Arrest/j:ArrestAgency/j:OrganizationORIID/j:ID" />
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Sentencing Court ORI -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Sentencing Court ORI:'"/>
				<xsl:with-param name="value1" 
					select="cib-ext:Supervision/j:ActivityCrimeCase/j:CaseCharge/j:ChargeSentence/j:SentenceIssuer.Organization/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Release Location -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Release Location:'"/>
				<xsl:with-param name="value1" select="cib-ext:Supervision/j:SupervisionAgency/j:OrganizationName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Supervision Start Date and Supervision End Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Supervision Start Date:'"/>
				<xsl:with-param name="value1" >
					<xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionStartDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Supervision End Date:'"/>
				<xsl:with-param name="value2">
					 <xsl:apply-templates select="cib-ext:Supervision/cib-ext:SupervisionEndDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Probation Expiration Date and Probation/Release Revoke Date -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Probation Expiration Date:'"/>
				<xsl:with-param name="value1" >
					<xsl:apply-templates select="cib-ext:Supervision/cib-ext:ProbationExpirationDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Release Revoke Date:'"/>
				<xsl:with-param name="value2">
					 <xsl:apply-templates select="cib-ext:Supervision/j:SupervisionConditionalRelease/j:ConditionalReleaseRevokedDate" mode="FormatFullDateAsMMDDYYYY"/>
				</xsl:with-param>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Reason for Revocation  -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Reason for Revocation:'"/>
				<xsl:with-param name="value1" select="cib-ext:Supervision/j:SupervisionConditionalRelease/j:ConditionalReleaseRevokedReasonText"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Warrant Court ORI and Warrant # -->
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Warrant Court ORI:'"/>
				<xsl:with-param name="value1" select="j:Arrest/j:ArrestWarrant/j:CourtOrderIssuingCourt/j:OrganizationORIID/j:ID"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
				<xsl:with-param name="label2" select="'Warrant Number:'"/>
				<xsl:with-param name="value2" select="j:Arrest/j:ArrestWarrant/j:ActivityID/j:ID"/>
				<xsl:with-param name="label_class_name2" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name2" select="'detailvalue width25percent'"/>
			</xsl:call-template>
			<!-- Place of Incarceration  --> 
			<xsl:call-template name="ConditionalRow">
				<xsl:with-param name="label1" select="'Place of Incarceration:'"/>
				<xsl:with-param name="value1" select="cib-ext:Supervision/cib-ext:SupervisionFacility/j:OrganizationName"/>
				<xsl:with-param name="label_class_name1" select="'detailsublabel width25percent'"/>
				<xsl:with-param name="value_class_name1" select="'detailvalue width25percent'"/>
			</xsl:call-template>
		</table>
	</xsl:template>
	
	<xsl:template match="cib-ext:ChargeNCICOriginalCode">
		<xsl:value-of select="."/>
	</xsl:template>
	
	<xsl:template match="cib-ext:ChargeNCICOriginalText">
		<xsl:text>&#160;</xsl:text>  
		<xsl:value-of select="."/>
	</xsl:template>
	
</xsl:transform>
