<?xml version="1.0"?>
<xsl:transform
	version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	exclude-result-prefixes="xsl xsi"
>


	<xsl:variable name="AlphaUpperCase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'"/>
	<xsl:variable name="AlphaLowerCase" select="'abcdefghijklmnopqrstuvwxyz'"/>

	<!-- Converts YYYY-MM-DD to MM/DD/YYYY -->
	<xsl:template match="* | @*" mode="FormatFullDateAsMMDDYYYY">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<xsl:choose> 
				<xsl:when test="$theValue='NONEXP'">
					<xsl:text>NONEXPIRING</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<!-- Converts valid xsd:Date element (YYYY-MM-DD) to MM/DD/YYYY -->
					<xsl:value-of select="substring($theValue,6,2)"/>
					<!-- MM -->
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring($theValue,9,2)"/>
					<!-- DD -->
					<xsl:text>/</xsl:text>
					<xsl:value-of select="substring($theValue,1,4)"/>
					<!-- YYYY -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	<!-- Converts YYYY-MM to MM/YYYY -->
	<xsl:template match="*" mode="FormatYearMonthAsMMYYYY">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<!-- Convert from YYYY-MM to MMYYYY -->
			<xsl:value-of select="substring($theValue,6,2)"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring($theValue,1,4)"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*" mode="FormatTimeAsHHMM">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<!-- Convert from hh:mm:ss to hhmm -->
			<xsl:value-of select="substring($theValue,1,2)"/>
			<xsl:value-of select="substring($theValue,4,2)"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*" mode="FormatSSN">
		<xsl:param name="theValue" select="."/> 
		<xsl:if test="$theValue">
			<!-- Convert from xxxxxxxxx xxx-xx-xxxx -->
			<xsl:value-of select="substring($theValue,1,3)"/>
			<xsl:text>-</xsl:text>
			<xsl:value-of select="substring($theValue,4,2)"/>
			<xsl:text>-</xsl:text>
			<xsl:value-of select="substring($theValue,6)"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*|@*" mode="FormatBooleanAsYesNo">
		<xsl:param name="theValue" select="."/>
		<xsl:choose>
			<xsl:when test="$theValue = 'true'">
				<xsl:text>Yes</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>No</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
		<!-- Label does not appear if value is empty -->
	<xsl:template name="ConditionalLabelWithValue">
		<xsl:param name="label"/>
		<xsl:param name="value"/>
		<xsl:param name="label_class_name"/>
		<xsl:param name="value_class_name"/>
		<td class="{$label_class_name}" valign="top" nowrap="nowrap">
			<xsl:if test="string($value) != ''">
				<span><xsl:value-of select="$label"/></span>
			</xsl:if>
		</td>
		<td class="{$value_class_name}" valign="top">
			<xsl:if test="string($value) != ''">
				<span><xsl:value-of select="$value"/></span>
			</xsl:if>
		</td>
	</xsl:template>
	
	<xsl:template name="ConditionalRow">
		<xsl:param name="label1"/>
		<xsl:param name="value1"/>
		<xsl:param name="label_class_name1"/>
		<xsl:param name="value_class_name1"/>
		<xsl:param name="label2"/>
		<xsl:param name="value2"/>
		<xsl:param name="label_class_name2"/>
		<xsl:param name="value_class_name2"/>
		<xsl:if test="string($value1) != '' or string($value2) != ''">
			<tr>
				<xsl:if test="string($label1) != ''">
					<xsl:call-template name="ConditionalLabelWithValue">
						<xsl:with-param name="label" select="$label1"/>
						<xsl:with-param name="value" select="$value1"/>
						<xsl:with-param name="label_class_name" select="$label_class_name1"/>
						<xsl:with-param name="value_class_name" select="$value_class_name1"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string($label2) != ''">
					<xsl:call-template name="ConditionalLabelWithValue">
						<xsl:with-param name="label" select="$label2"/>
						<xsl:with-param name="value" select="$value2"/>
						<xsl:with-param name="label_class_name" select="$label_class_name2"/>
						<xsl:with-param name="value_class_name" select="$value_class_name2"/>
					</xsl:call-template>
				</xsl:if>
			</tr>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*|@*|text()" mode="TitleCase">
		<xsl:call-template name="TitleCase">
			<xsl:with-param name="text" select="translate(., $AlphaUpperCase, $AlphaLowerCase)"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="TitleCase">
		<xsl:param name="text"/>
		
		<xsl:variable name="charsBeforeSpace">
			<xsl:choose>
				<xsl:when test="contains($text, ' ')">
					<xsl:value-of select="substring-before($text, ' ')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$text"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="charsAfterSpace">
			<xsl:if test="contains($text, ' ')">
				<xsl:value-of select="substring-after($text, ' ')"/>
			</xsl:if>
		</xsl:variable>
		
		<xsl:choose>
			<!-- Change for keeping NICS in upper case for RecordType Text  -->
				<xsl:when test="contains(translate($charsBeforeSpace, $AlphaLowerCase, $AlphaUpperCase),'NICS')">
					<xsl:value-of select="translate($charsBeforeSpace, $AlphaLowerCase, $AlphaUpperCase)" />
				</xsl:when>
			<xsl:otherwise>
				<!-- translate first char to upper-case -->
				<xsl:value-of select="translate(substring($charsBeforeSpace, 1, 1), $AlphaLowerCase, $AlphaUpperCase)" />

				<!-- translate the rest to lowercase -->
				<xsl:value-of select="translate(substring($charsBeforeSpace, 2), $AlphaUpperCase, $AlphaLowerCase)" />
			</xsl:otherwise>
		</xsl:choose>
		
		<!-- if there was any text following a space in the original string, process it -->
		<xsl:if test="string-length($charsAfterSpace) &gt; 0">
			<xsl:text>&#32;</xsl:text>
			<xsl:call-template name="TitleCase">
				<xsl:with-param name="text" select="$charsAfterSpace"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!-- Converts YYYY -->
	<xsl:template match="*" mode="FormatYYYYorNX">
		<xsl:param name="theValue" select="."/>
		<xsl:if test="$theValue">
			<xsl:text>&#160;</xsl:text>
			<xsl:choose> 
				<xsl:when test="$theValue='NX'">
					<xsl:text>NONEXPIRING</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<!-- YYYY -->
					<xsl:text>Exp.&#160;</xsl:text> 
					<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>&#160;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="left-trim">
	  <xsl:param name="s" />
	  <xsl:choose>
	    <xsl:when test="substring($s, 1, 1) = ''">
	      <xsl:value-of select="$s"/>
	    </xsl:when>
	    <xsl:when test="normalize-space(substring($s, 1, 1)) = ''">
	      <xsl:call-template name="left-trim">
	        <xsl:with-param name="s" select="substring($s, 2)" />
	      </xsl:call-template>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="$s" />
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:template>
 
	<xsl:template name="right-trim">
	  <xsl:param name="s" />
	  <xsl:choose>
	    <xsl:when test="substring($s, 1, 1) = ''">
	      <xsl:value-of select="$s"/>
	    </xsl:when>
	    <xsl:when test="normalize-space(substring($s, string-length($s))) = ''">
	      <xsl:call-template name="right-trim">
	        <xsl:with-param name="s" select="substring($s, 1, string-length($s) - 1)" />
	      </xsl:call-template>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="$s" />
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:template>
	 
	<xsl:template name="trim">
	  <xsl:param name="s" />
	  <xsl:call-template name="right-trim">
	    <xsl:with-param name="s">
	      <xsl:call-template name="left-trim">
	        <xsl:with-param name="s" select="$s" />
	      </xsl:call-template>
	    </xsl:with-param>
	  </xsl:call-template>
	</xsl:template>
  	
	<xsl:template name="true-false_to_Yes-No">
		<xsl:param name="true-false"/>
		<xsl:choose>
			<xsl:when test="$true-false='true'">
				<xsl:text>Yes</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>No</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="resolveConcConsCode">
		<xsl:param name="concConsCode"/>
		<xsl:choose>
			<xsl:when test="$concConsCode='C'">
				<xsl:text>Concurrent with</xsl:text>
			</xsl:when>
			<xsl:when test="$concConsCode='S'">
				<xsl:text>Consecutive to</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$concConsCode"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="personName" mode="FirstMiddleLastSuffix">
		<xsl:param name="givenName"></xsl:param>
		<xsl:param name="middleName"></xsl:param>
		<xsl:param name="lastName"></xsl:param>
		<xsl:param name="suffix"></xsl:param>
		<xsl:value-of select="$givenName"/>
		<xsl:if test="string-length($middleName) > 0">
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="$middleName" />
			<xsl:if test="string-length($middleName)=1">
				<xsl:text>.</xsl:text>
			</xsl:if>
		</xsl:if>
		<xsl:text>&#32;</xsl:text>
		<xsl:value-of select="$lastName" />
		<xsl:if test="$suffix">
			<xsl:text>&#32;</xsl:text>
			<xsl:value-of select="$suffix"/>
		</xsl:if>
	</xsl:template>

</xsl:transform>